@@ -1,4 +1,4 @@
-// $Id: Autofire.cc,v 1.16 2006/01/24 18:03:35 m9710797 Exp $
+// $Id: Autofire.cc 5993 2007-01-12 22:12:12Z m9710797 $
 
 #include "Autofire.hh"
 #include "IntegerSetting.hh"
@@ -45,9 +45,10 @@ void Autofire::update(const Setting& setting)
 	setClock();
 }
 
-byte Autofire::getSignal(const EmuTime& time)
+bool Autofire::getSignal(const EmuTime& time)
 {
-	return speedSetting->getValue() == 0 ? 0 : clock.getTicksTill(time) & 1;
+	return speedSetting->getValue() == 0 ?
+		false : clock.getTicksTill(time) & 1;
 }
 
 } // namespace openmsx
