@@ -1,4 +1,4 @@
-// $Id: CartridgeSlotManager.cc 6157 2007-03-11 22:22:34Z m9710797 $
+// $Id: CartridgeSlotManager.cc 6821 2007-08-08 08:27:27Z m9710797 $
 
 #include "CartridgeSlotManager.hh"
 #include "MSXMotherBoard.hh"
@@ -110,15 +110,17 @@ int CartridgeSlotManager::getSlot(int ps, int ss) const
 	return 0; // avoid warning
 }
 
-void CartridgeSlotManager::testRemoveExternalSlot(int ps) const
+void CartridgeSlotManager::testRemoveExternalSlot(
+	int ps, const HardwareConfig& allowed) const
 {
-	testRemoveExternalSlot(ps, -1);
+	testRemoveExternalSlot(ps, -1, allowed);
 }
 
-void CartridgeSlotManager::testRemoveExternalSlot(int ps, int ss) const
+void CartridgeSlotManager::testRemoveExternalSlot(
+	int ps, int ss, const HardwareConfig& allowed) const
 {
 	int slot = getSlot(ps, ss);
-	if (slots[slot].used()) {
+	if (slots[slot].used(&allowed)) {
 		throw MSXException("Slot still in use.");
 	}
 }
@@ -145,11 +147,11 @@ int CartridgeSlotManager::getSpecificSlot(int slot, int& ps, int& ss,
 	assert((0 <= slot) && (slot < MAX_SLOTS));
 
 	if (!slots[slot].exists()) {
-		throw MSXException(string("slot-") + (char)('a' + slot) +
+		throw MSXException(string("slot-") + char('a' + slot) +
 		                   " not defined.");
 	}
 	if (slots[slot].used()) {
-		throw MSXException(string("slot-") + (char)('a' + slot) +
+		throw MSXException(string("slot-") + char('a' + slot) +
 		                   " already in use.");
 	}
 	ps = slots[slot].ps;
@@ -163,7 +165,7 @@ int CartridgeSlotManager::getAnyFreeSlot(int& ps, int& ss,
 {
 	// search for the lowest free slot
 	int result = -1;
-	unsigned slotNum = (unsigned)-1;
+	unsigned slotNum = unsigned(-1);
 	for (int slot = 0; slot < MAX_SLOTS; ++slot) {
 		if (slots[slot].exists() && !slots[slot].used()) {
 			unsigned p = slots[slot].ps;
@@ -245,7 +247,7 @@ string CartCmd::execute(const vector<string>& tokens, const EmuTime& /*time*/)
 {
 	string result;
 	string cartname = tokens[0];
-	
+
 	// strip namespace qualification
 	//  TODO investigate whether it's a good idea to strip namespace at a
 	//       higher level for all commands. How does that interact with
@@ -271,7 +273,7 @@ string CartCmd::execute(const vector<string>& tokens, const EmuTime& /*time*/)
 	} else if ( (tokens[1] == "eject") || (tokens[1] == "-eject") ) {
 		// remove cartridge (or extension)
 		if (tokens[1] == "-eject") {
-			result += "Warning: use of '-eject' is deprecated, instead use the 'eject' subcommand";		
+			result += "Warning: use of '-eject' is deprecated, instead use the 'eject' subcommand";
 		}
 		const ExtensionConfig* extConf = getExtensionConfig(cartname);
 		if (extConf) {
