@@ -1,4 +1,4 @@
-// $Id: CommandLineParser.cc 5993 2007-01-12 22:12:12Z m9710797 $
+// $Id: CommandLineParser.cc 6835 2007-08-14 09:03:28Z m9710797 $
 
 #include "CommandLineParser.hh"
 #include "CLIOption.hh"
@@ -20,6 +20,7 @@
 #include "FileException.hh"
 #include "EnumSetting.hh"
 #include "HostCPU.hh"
+#include "GLUtil.hh"
 #include "Reactor.hh"
 #include <cassert>
 #include <iostream>
@@ -109,7 +110,21 @@ public:
 	virtual const std::string& optionHelp() const;
 };
 
-class NoMMXEXTOption : public CLIOption {
+class NoSSEOption : public CLIOption {
+public:
+	virtual bool parseOption(const std::string& option,
+		std::list<std::string>& cmdLine);
+	virtual const std::string& optionHelp() const;
+};
+
+class NoSSE2Option : public CLIOption {
+public:
+	virtual bool parseOption(const std::string& option,
+		std::list<std::string>& cmdLine);
+	virtual const std::string& optionHelp() const;
+};
+
+class NoPBOOption : public CLIOption {
 public:
 	virtual bool parseOption(const std::string& option,
 		std::list<std::string>& cmdLine);
@@ -131,8 +146,7 @@ private:
 // class CommandLineParser
 
 CommandLineParser::CommandLineParser(Reactor& reactor_)
-	: parseStatus(UNPARSED)
-	, reactor(reactor_)
+	: reactor(reactor_)
 	, settingsConfig(reactor.getCommandController().getSettingsConfig())
 	, output(reactor.getGlobalCliComm())
 	, helpOption(new HelpOption(*this))
@@ -142,7 +156,9 @@ CommandLineParser::CommandLineParser(Reactor& reactor_)
 	, machineOption(new MachineOption(*this))
 	, settingOption(new SettingOption(*this))
 	, noMMXOption(new NoMMXOption())
-	, noMMXEXTOption(new NoMMXEXTOption())
+	, noSSEOption(new NoSSEOption())
+	, noSSE2Option(new NoSSE2Option())
+	, noPBOOption(new NoPBOOption())
 	, testConfigOption(new TestConfigOption(*this))
 	, msxRomCLI(new MSXRomCLI(*this))
 	, cliExtension(new CliExtension(*this))
@@ -151,6 +167,7 @@ CommandLineParser::CommandLineParser(Reactor& reactor_)
 	, hdImageCLI(new HDImageCLI(*this))
 	, cdImageCLI(new CDImageCLI(*this))
 	, eventRecorderReplayerCLI(new MSXEventRecorderReplayerCLI(*this))
+	, parseStatus(UNPARSED)
 {
 	haveConfig = false;
 	haveSettings = false;
@@ -165,10 +182,14 @@ CommandLineParser::CommandLineParser(Reactor& reactor_)
 	registerOption("-script",     *scriptOption, 1, 1);
 	#ifdef ASM_X86
 	registerOption("-nommx",      *noMMXOption, 1, 1);
-	registerOption("-nommxext",   *noMMXEXTOption, 1, 1);
+	registerOption("-nosse",      *noSSEOption, 1, 1);
+	registerOption("-nosse2",     *noSSE2Option, 1, 1);
+	#endif
+	#ifdef COMPONENT_GL
+	registerOption("-nopbo",      *noPBOOption, 1, 1);
 	#endif
 	registerOption("-testconfig", *testConfigOption, 1, 1);
-	
+
 	registerFileTypes();
 }
 
@@ -559,6 +580,8 @@ bool VersionOption::parseOption(const string& /*option*/,
 		list<string>& /*cmdLine*/)
 {
 	cout << Version::FULL_VERSION << endl;
+	cout << "flavour: " << BUILD_FLAVOUR << endl;
+	cout << "components: " << BUILD_COMPONENTS << endl;
 	parser.parseStatus = CommandLineParser::EXIT;
 	return true;
 }
@@ -638,7 +661,7 @@ const string& SettingOption::optionHelp() const
 bool NoMMXOption::parseOption(const string& /*option*/,
 		list<string>& /*cmdLine*/)
 {
-	cout << "Disabling MMX " << endl;
+	cout << "Disabling MMX" << endl;
 	HostCPU::getInstance().forceDisableMMX();
 	return true;
 }
@@ -646,25 +669,63 @@ bool NoMMXOption::parseOption(const string& /*option*/,
 const string& NoMMXOption::optionHelp() const
 {
 	static const string text(
-		"Disables usage of MMX, including extensions (for debugging)");
+		"Disables usage of MMX, SSE and SSE2 (for debugging)");
 	return text;
 }
 
 
-// class NoMMXEXTOption
+// class NoSSEOption
 
-bool NoMMXEXTOption::parseOption(const string& /*option*/,
+bool NoSSEOption::parseOption(const string& /*option*/,
 		list<string>& /*cmdLine*/)
 {
-	cout << "Disabling MMX extensions" << endl;
-	HostCPU::getInstance().forceDisableMMXEXT();
+	cout << "Disabling SSE" << endl;
+	HostCPU::getInstance().forceDisableSSE();
 	return true;
 }
 
-const string& NoMMXEXTOption::optionHelp() const
+const string& NoSSEOption::optionHelp() const
 {
 	static const string text(
-		"Disables usage of MMX extensions (for debugging)");
+		"Disables usage of SSE and SSE2 (for debugging)");
+	return text;
+}
+
+
+// class NoSSE2Option
+
+bool NoSSE2Option::parseOption(const string& /*option*/,
+		list<string>& /*cmdLine*/)
+{
+	cout << "Disabling SSE2" << endl;
+	HostCPU::getInstance().forceDisableSSE2();
+	return true;
+}
+
+const string& NoSSE2Option::optionHelp() const
+{
+	static const string text(
+		"Disables usage of SSE2 (for debugging)");
+	return text;
+}
+
+
+// class NoPBOOption
+
+bool NoPBOOption::parseOption(const string& /*option*/,
+		list<string>& /*cmdLine*/)
+{
+	#ifdef COMPONENT_GL
+	cout << "Disabling PBO" << endl;
+	PixelBuffers::enabled = false;
+	#endif
+	return true;
+}
+
+const string& NoPBOOption::optionHelp() const
+{
+	static const string text(
+		"Disables usage of openGL PBO (for debugging)");
 	return text;
 }
 
