@@ -1,4 +1,4 @@
-// $Id: Connector.cc 4836 2005-11-11 20:53:06Z m9710797 $
+// $Id: Connector.cc 6623 2007-06-15 11:27:19Z m9710797 $
 
 #include "Connector.hh"
 #include "Pluggable.hh"
@@ -32,4 +32,9 @@ void Connector::unplug(const EmuTime& time)
 	plugged = dummy.get();
 }
 
+Pluggable& Connector::getPlugged() const
+{
+        return *plugged;
+}
+
 } // namespace openmsx
