@@ -1,4 +1,4 @@
-// $Id: DeviceFactory.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: DeviceFactory.cc 7175 2007-10-21 20:32:35Z m9710797 $
 
 #include "DeviceFactory.hh"
 #include "XMLElement.hh"
@@ -16,12 +16,14 @@
 #include "MSXFmPac.hh"
 #include "MSXAudio.hh"
 #include "MSXMoonSound.hh"
+#include "MSXYamahaSFG.hh"
 #include "MC6850.hh"
 #include "MSXKanji.hh"
 #include "MSXBunsetsu.hh"
 #include "MSXMemoryMapper.hh"
 #include "PanasonicRam.hh"
 #include "MSXRTC.hh"
+#include "PasswordCart.hh"
 #include "RomFactory.hh"
 #include "MSXPrinterPort.hh"
 #include "MSXSCCPlusCart.hh"
@@ -30,6 +32,10 @@
 #include "NationalFDC.hh"
 #include "TurboRFDC.hh"
 #include "SunriseIDE.hh"
+#include "GoudaSCSI.hh"
+#include "MegaSCSI.hh"
+#include "ESE_RAM.hh"
+#include "ESE_SCC.hh"
 #include "MSXMatsushita.hh"
 #include "MSXKanji12.hh"
 #include "MSXMidi.hh"
@@ -87,6 +93,8 @@ std::auto_ptr<MSXDevice> DeviceFactory::create(
 		result.reset(new MSXAudio(motherBoard, conf, time));
 	} else if (type == "MusicModuleMIDI") {
 		result.reset(new MC6850(motherBoard, conf, time));
+	} else if (type == "YamahaSFG") {
+		result.reset(new MSXYamahaSFG(motherBoard, conf, time));
 	} else if (type == "MoonSound") {
 		result.reset(new MSXMoonSound(motherBoard, conf, time));
 	} else if (type == "Kanji") {
@@ -99,6 +107,8 @@ std::auto_ptr<MSXDevice> DeviceFactory::create(
 		result.reset(new PanasonicRam(motherBoard, conf, time));
 	} else if (type == "RTC") {
 		result.reset(new MSXRTC(motherBoard, conf, time));
+	} else if (type == "PasswordCart") {
+		result.reset(new PasswordCart(motherBoard, conf, time));
 	} else if (type == "ROM") {
 		result = RomFactory::create(motherBoard, conf, time);
 	} else if (type == "PrinterPort") {
@@ -115,6 +125,16 @@ std::auto_ptr<MSXDevice> DeviceFactory::create(
 		result.reset(new TurboRFDC(motherBoard, conf, time));
 	} else if (type == "SunriseIDE") {
 		result.reset(new SunriseIDE(motherBoard, conf, time));
+	} else if (type == "GoudaSCSI") {
+		result.reset(new GoudaSCSI(motherBoard, conf, time));
+	} else if (type == "MegaSCSI") {
+		result.reset(new MegaSCSI(motherBoard, conf, time));
+	} else if (type == "ESERAM") {
+		result.reset(new ESE_RAM(motherBoard, conf, time));
+	} else if (type == "WaveSCSI") {
+		result.reset(new ESE_SCC(motherBoard, conf, time, true));
+	} else if (type == "ESESCC") {
+		result.reset(new ESE_SCC(motherBoard, conf, time, false));
 	} else if (type == "Matsushita") {
 		result.reset(new MSXMatsushita(motherBoard, conf, time));
 	} else if (type == "Kanji12") {
