@@ -1,4 +1,4 @@
-// $Id: EmuTime.cc 4364 2005-05-11 18:54:32Z m9710797 $
+// $Id: EmuTime.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "EmuTime.hh"
 #include <limits>
@@ -6,7 +6,7 @@
 
 namespace openmsx {
 
-const EmuTime EmuTime::zero((uint64)0);
+const EmuTime EmuTime::zero(uint64(0));
 const EmuTime EmuTime::infinity(std::numeric_limits<uint64>::max());
 
 std::ostream& operator<<(std::ostream &os, const EmuTime &et)
