@@ -1,4 +1,4 @@
-// $Id: IPSPatch.cc 5615 2006-09-08 09:07:05Z m9710797 $
+// $Id: IPSPatch.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "IPSPatch.hh"
 #include "File.hh"
@@ -93,7 +93,7 @@ void IPSPatch::copyBlock(unsigned src, byte* dst, unsigned num) const
 		int chunkOffset = src - chunkStart;
 		if (chunkOffset < 0) {
 			// start after src
-			assert(-chunkOffset < (int)num); // dont start past end
+			assert(-chunkOffset < int(num)); // dont start past end
 			chunkOffset = 0;
 		} else if (chunkOffset >= chunkSize) {
 			// chunk completely before src, skip
@@ -111,8 +111,8 @@ void IPSPatch::copyBlock(unsigned src, byte* dst, unsigned num) const
 			chunkSize -= overflow;
 		}
 		// copy
-		assert(chunkOffset < (int)it->second.size());
-		assert((chunkOffset + chunkSize) <= (int)it->second.size());
+		assert(chunkOffset < int(it->second.size()));
+		assert((chunkOffset + chunkSize) <= int(it->second.size()));
 		assert(src <= chunkStart);
 		assert((chunkStart + chunkSize) <= (src + num));
 		memcpy(dst + chunkStart - src, &it->second[chunkOffset],
