@@ -1,7 +1,7 @@
-// $Id: MSXBunsetsu.cc,v 1.20 2005/11/15 20:03:43 m9710797 Exp $
+// $Id: MSXBunsetsu.cc 5751 2006-10-05 19:34:54Z m9710797 $
 
 #include "MSXBunsetsu.hh"
-#include "CPU.hh"
+#include "CacheLine.hh"
 #include "Rom.hh"
 
 namespace openmsx {
@@ -58,8 +58,7 @@ void MSXBunsetsu::writeMem(word address, byte value, const EmuTime& /*time*/)
 
 const byte* MSXBunsetsu::getReadCacheLine(word start) const
 {
-	if ((start & CPU::CACHE_LINE_HIGH) ==
-	    (0xBFFF & CPU::CACHE_LINE_HIGH)) {
+	if ((start & CacheLine::HIGH) == (0xBFFF & CacheLine::HIGH)) {
 		return NULL;
 	} else {
 		return &(*bunsetsuRom)[start - 0x4000];
@@ -68,8 +67,7 @@ const byte* MSXBunsetsu::getReadCacheLine(word start) const
 
 byte* MSXBunsetsu::getWriteCacheLine(word start) const
 {
-	if ((start & CPU::CACHE_LINE_HIGH) ==
-	    (0xBFFF & CPU::CACHE_LINE_HIGH)) {
+	if ((start & CacheLine::HIGH) == (0xBFFF & CacheLine::HIGH)) {
 		return NULL;
 	} else {
 		return unmappedWrite;
