@@ -1,4 +1,4 @@
-// $Id: MSXDevice.cc 5814 2006-10-26 19:11:44Z arnoldmnl $
+// $Id: MSXDevice.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 #include "MSXDevice.hh"
 #include "XMLElement.hh"
@@ -11,6 +11,7 @@
 #include <set>
 #include <algorithm>
 #include <cassert>
+#include <cstring>
 
 using std::string;
 using std::vector;
@@ -23,16 +24,16 @@ byte MSXDevice::unmappedWrite[0x10000];
 
 MSXDevice::MSXDevice(MSXMotherBoard& motherBoard_, const XMLElement& config,
                      const EmuTime& /*time*/, const string& name)
-	: deviceConfig(config), externalSlotID(-1), motherBoard(motherBoard_)
-	, hardwareConfig(NULL)
+	: deviceConfig(config), motherBoard(motherBoard_)
+	, hardwareConfig(NULL), externalSlotID(-1)
 {
 	initName(name);
 }
 
 MSXDevice::MSXDevice(MSXMotherBoard& motherBoard_, const XMLElement& config,
                      const EmuTime& /*time*/)
-	: deviceConfig(config), externalSlotID(-1), motherBoard(motherBoard_)
-	, hardwareConfig(NULL)
+	: deviceConfig(config), motherBoard(motherBoard_)
+	, hardwareConfig(NULL), externalSlotID(-1)
 {
 	initName(deviceConfig.getId());
 }
@@ -192,7 +193,7 @@ void MSXDevice::registerSlots(const XMLElement& config)
 		}
 	}
 	if ( (0 > ss ) && (ss >= -128) ) {
-		if ( (0 <= ps) && (ps<4) 
+		if ( (0 <= ps) && (ps<4)
 			 && motherBoard.getCPUInterface().isExpanded(ps))
 			ss += 128;
 		else
@@ -276,6 +277,11 @@ void MSXDevice::reset(const EmuTime& /*time*/)
 	// nothing
 }
 
+byte MSXDevice::readIRQVector()
+{
+	return 0xFF;
+}
+
 void MSXDevice::powerDown(const EmuTime& /*time*/)
 {
 	// nothing
@@ -295,7 +301,7 @@ string MSXDevice::getName() const
 byte MSXDevice::readIO(word port, const EmuTime& /*time*/)
 {
 	(void)port;
-	PRT_DEBUG("MSXDevice::readIO (0x" << std::hex << (int)(port & 0xFF)
+	PRT_DEBUG("MSXDevice::readIO (0x" << std::hex << int(port & 0xFF)
 	          << std::dec << ") : No device implementation.");
 	return 0xFF;
 }
@@ -304,8 +310,8 @@ void MSXDevice::writeIO(word port, byte value, const EmuTime& /*time*/)
 {
 	(void)port;
 	(void)value;
-	PRT_DEBUG("MSXDevice::writeIO(port 0x" << std::hex << (int)(port & 0xFF)
-	          << std::dec << ",value " << (int)value
+	PRT_DEBUG("MSXDevice::writeIO(port 0x" << std::hex << int(port & 0xFF)
+	          << std::dec << ",value " << int(value)
 	          << ") : No device implementation.");
 	// do nothing
 }
@@ -320,7 +326,7 @@ byte MSXDevice::readMem(word address, const EmuTime& /*time*/)
 {
 	(void)address;
 	PRT_DEBUG("MSXDevice: read from unmapped memory " << std::hex <<
-	          (int)address << std::dec);
+	          int(address) << std::dec);
 	return 0xFF;
 }
 
@@ -334,7 +340,7 @@ void MSXDevice::writeMem(word address, byte /*value*/,
 {
 	(void)address;
 	PRT_DEBUG("MSXDevice: write to unmapped memory " << std::hex <<
-	          (int)address << std::dec);
+	          int(address) << std::dec);
 	// do nothing
 }
 
@@ -351,6 +357,12 @@ byte MSXDevice::peekMem(word address, const EmuTime& /*time*/) const
 	}
 }
 
+void MSXDevice::globalWrite(word /*address*/, byte /*value*/,
+                            const EmuTime& /*time*/)
+{
+	assert(false);
+}
+
 byte* MSXDevice::getWriteCacheLine(word /*start*/) const
 {
 	return NULL;	// uncacheable
