@@ -1,4 +1,4 @@
-// $Id: MSXDeviceSwitch.cc 5098 2006-01-28 16:36:24Z m9710797 $
+// $Id: MSXDeviceSwitch.cc 6805 2007-08-06 12:01:49Z m9710797 $
 
 #include "MSXDeviceSwitch.hh"
 #include "MSXCPUInterface.hh"
@@ -56,7 +56,7 @@ void MSXDeviceSwitch::registerDevice(byte id, MSXSwitchedDevice* device)
 	if (devices[id]) {
 		// TODO implement multiplexing
 		throw MSXException("Already have a switched device with id " +
-		                   StringOp::toString((int)id));
+		                   StringOp::toString(int(id)));
 	}
 	devices[id] = device;
 	if (count == 0) {
@@ -120,7 +120,7 @@ void MSXDeviceSwitch::writeIO(word port, byte value, const EmuTime& time)
 	port &= 0x0F;
 	if (port == 0x00) {
 		selected = value;
-		PRT_DEBUG("Switch " << (int)selected);
+		PRT_DEBUG("Switch " << int(selected));
 	} else if (devices[selected]) {
 		//PRT_DEBUG("Switch write device " << (int)selected << " port " << (int)port);
 		devices[selected]->writeIO(port, value, time);
