@@ -1,4 +1,4 @@
-// $Id: MSXKanji12.cc 5076 2006-01-25 19:26:32Z m9710797 $
+// $Id: MSXKanji12.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "MSXKanji12.hh"
 #include "Rom.hh"
@@ -48,7 +48,7 @@ byte MSXKanji12::peekIO(word port, const EmuTime& /*time*/) const
 	byte result;
 	switch (port & 0x0F) {
 		case 0:
-			result = static_cast<byte>(~ID);
+			result = byte(~ID);
 			break;
 		case 1:
 			result = 0x08; // TODO what is this
