@@ -1,4 +1,4 @@
-// $Id: MSXMotherBoard.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: MSXMotherBoard.cc 6821 2007-08-08 08:27:27Z m9710797 $
 
 #include "MSXMotherBoard.hh"
 #include "Reactor.hh"
@@ -36,6 +36,7 @@
 #include "Observer.hh"
 #include <cassert>
 #include <map>
+#include <iostream>
 
 using std::set;
 using std::map;
@@ -73,6 +74,7 @@ public:
 	void doPowerDown(const EmuTime& time);
 	void scheduleReset();
 	void doReset(const EmuTime& time);
+	byte readIRQVector();
 
 	const MachineConfig& getMachineConfig() const;
 	void loadMachine(const string& machine);
@@ -115,7 +117,10 @@ public:
 	MSXDevice* findDevice(const string& name);
 
 	MSXMotherBoard::SharedStuff& getSharedStuff(const string& name);
-	
+
+	string getUserName(const string& hwName);
+	void freeUserName(const string& hwName, const string& userName);
+
 private:
 	void deleteMachine();
 
@@ -131,13 +136,9 @@ private:
 	typedef vector<MSXDevice*> Devices;
 	Devices availableDevices;
 
-	bool powered;
-	bool needReset;
-	bool needPowerDown;
-	int blockedCounter;
-
 	typedef map<string, MSXMotherBoard::SharedStuff> SharedStuffMap;
 	SharedStuffMap sharedStuffMap;
+	map<string, set<string> > userNames;
 
 	auto_ptr<MachineConfig> machineConfig;
 	MSXMotherBoard::Extensions extensions;
@@ -169,6 +170,11 @@ private:
 	auto_ptr<RemoveExtCmd> removeExtCommand;
 	auto_ptr<MachineNameInfo> machineNameInfo;
 	BooleanSetting& powerSetting;
+
+	int blockedCounter;
+	bool powered;
+	bool needReset;
+	bool needPowerDown;
 };
 
 
@@ -242,11 +248,11 @@ private:
 MSXMotherBoardImpl::MSXMotherBoardImpl(MSXMotherBoard& self_, Reactor& reactor_)
 	: self(self_)
 	, reactor(reactor_)
+	, powerSetting(getGlobalSettings().getPowerSetting())
+	, blockedCounter(0)
 	, powered(false)
 	, needReset(false)
 	, needPowerDown(false)
-	, blockedCounter(0)
-	, powerSetting(getGlobalSettings().getPowerSetting())
 {
 	self.pimple.reset(this);
 
@@ -274,11 +280,16 @@ MSXMotherBoardImpl::~MSXMotherBoardImpl()
 
 void MSXMotherBoardImpl::deleteMachine()
 {
-	for (MSXMotherBoard::Extensions::reverse_iterator it = extensions.rbegin();
-	     it != extensions.rend(); ++it) {
-		delete *it;
+	while (!extensions.empty()) {
+		try {
+	 		removeExtension(*extensions.back());
+		} catch (MSXException& e) {
+			std::cerr << "Internal error: failed to remove "
+			             "extension while deleting a machine: "
+			          << e.getMessage() << std::endl;   
+			assert(false);
+		}
 	}
-	extensions.clear();
 
 	machineConfig.reset();
 }
@@ -356,6 +367,7 @@ ExtensionConfig& MSXMotherBoardImpl::loadExtension(const string& name)
 	}
 	ExtensionConfig& result = *extension;
 	extensions.push_back(extension.release());
+	self.getMSXCliComm().update(CliComm::EXTENSION, result.getName(), "add");
 	return result;
 }
 
@@ -394,6 +406,7 @@ void MSXMotherBoardImpl::removeExtension(const ExtensionConfig& extension)
 	MSXMotherBoard::Extensions::iterator it =
 		find(extensions.begin(), extensions.end(), &extension);
 	assert(it != extensions.end());
+	self.getMSXCliComm().update(CliComm::EXTENSION, extension.getName(), "remove");
 	delete &extension;
 	extensions.erase(it);
 }
@@ -652,6 +665,7 @@ void MSXMotherBoardImpl::removeDevice(MSXDevice& device)
 
 void MSXMotherBoardImpl::scheduleReset()
 {
+	if (!powered) return;
 	needReset = true;
 	exitCPULoopSync();
 }
@@ -670,6 +684,16 @@ void MSXMotherBoardImpl::doReset(const EmuTime& time)
 		new SimpleEvent<OPENMSX_BOOT_EVENT>());
 }
 
+byte MSXMotherBoardImpl::readIRQVector()
+{
+	byte result = 0xff;
+	for (Devices::iterator it = availableDevices.begin();
+	     it != availableDevices.end(); ++it) {
+		result &= (*it)->readIRQVector();
+	}
+	return result;
+}
+
 void MSXMotherBoardImpl::powerUp()
 {
 	if (powered) return;
@@ -768,6 +792,26 @@ MSXMotherBoard::SharedStuff& MSXMotherBoardImpl::getSharedStuff(
 	return sharedStuffMap[name];
 }
 
+string MSXMotherBoardImpl::getUserName(const string& hwName)
+{
+	set<string>& s = userNames[hwName];
+	unsigned n = 0;
+	string userName;
+	do {
+		userName = "untitled" + StringOp::toString(++n);
+	} while (s.find(userName) != s.end());
+	s.insert(userName);
+	return userName;
+}
+
+void MSXMotherBoardImpl::freeUserName(const string& hwName,
+                                      const string& userName)
+{
+	set<string>& s = userNames[hwName];
+	assert(s.find(userName) != s.end());
+	s.erase(userName);
+}
+
 
 // AddRemoveUpdate
 
@@ -1001,6 +1045,10 @@ void MSXMotherBoard::doReset(const EmuTime& time)
 {
 	pimple->doReset(time);
 }
+byte MSXMotherBoard::readIRQVector()
+{
+	return pimple->readIRQVector();
+}
 const MachineConfig& MSXMotherBoard::getMachineConfig() const
 {
 	return pimple->getMachineConfig();
@@ -1147,5 +1195,14 @@ MSXMotherBoard::SharedStuff& MSXMotherBoard::getSharedStuff(const string& name)
 {
 	return pimple->getSharedStuff(name);
 }
+string MSXMotherBoard::getUserName(const string& hwName)
+{
+	return pimple->getUserName(hwName);
+}
+void MSXMotherBoard::freeUserName(const string& hwName,
+                                  const string& userName)
+{
+	pimple->freeUserName(hwName, userName);
+}
 
 } // namespace openmsx
