@@ -1,4 +1,4 @@
-// $Id: MSXPPI.cc,v 1.82 2006/05/01 13:21:48 m9710797 Exp $
+// $Id: MSXPPI.cc 5925 2006-12-14 21:05:21Z manuelbi $
 
 #include "MSXPPI.hh"
 #include "Keyboard.hh"
@@ -25,11 +25,11 @@ MSXPPI::MSXPPI(MSXMotherBoard& motherBoard, const XMLElement& config,
 {
 	bool keyGhosting = deviceConfig.getChildDataAsBool("key_ghosting", true);
 	keyboard.reset(new Keyboard(motherBoard.getScheduler(),
-	                            motherBoard.getCommandController(),
-	                            motherBoard.getUserInputEventDistributor(),
+	                            motherBoard.getMSXCommandController(),
+	                            motherBoard.getMSXEventDistributor(),
 	                            keyGhosting));
-	i8255.reset(new I8255(*this, time));
-	click.reset(new KeyClick(motherBoard.getMixer(), config, time));
+	i8255.reset(new I8255(*this, time, motherBoard.getMSXCliComm()));
+	click.reset(new KeyClick(motherBoard.getMSXMixer(), config, time));
 
 	reset(time);
 }
@@ -47,7 +47,7 @@ void MSXPPI::reset(const EmuTime& time)
 void MSXPPI::powerDown(const EmuTime& /*time*/)
 {
 	getMotherBoard().getEventDistributor().distributeEvent(
-		new LedEvent(LedEvent::CAPS, false));
+		new LedEvent(LedEvent::CAPS, false, getMotherBoard()));
 }
 
 byte MSXPPI::readIO(word port, const EmuTime& time)
@@ -169,7 +169,8 @@ void MSXPPI::writeC1(nibble value, const EmuTime& time)
 	}
 	if ((prevBits ^ value) & 4) {
 		getMotherBoard().getEventDistributor().distributeEvent(
-			new LedEvent(LedEvent::CAPS, !(value & 4)));
+			new LedEvent(LedEvent::CAPS, !(value & 4),
+			             getMotherBoard()));
 	}
 	if ((prevBits ^ value) & 8) {
 		click->setClick(value & 8, time);
