@@ -1,4 +1,4 @@
-// $Id: MSXS1985.cc 4909 2005-12-03 18:58:10Z arnoldmnl $
+// $Id: MSXS1985.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "MSXS1985.hh"
 #include "Ram.hh"
@@ -42,7 +42,7 @@ byte MSXS1985::peekIO(word port, const EmuTime& /*time*/) const
 	byte result;
 	switch (port & 0x0F) {
 	case 0:
-		result = (byte)~ID;
+		result = byte(~ID);
 		break;
 	case 2:
 		result = (*ram)[address];
