@@ -1,4 +1,4 @@
-// $Id: MSXS1990.cc 5680 2006-09-22 21:07:46Z m9710797 $
+// $Id: MSXS1990.cc 6805 2007-08-06 12:01:49Z m9710797 $
 
 #include "MSXS1990.hh"
 #include "MSXCPU.hh"
@@ -74,7 +74,7 @@ void MSXS1990::writeIO(word port, byte value, const EmuTime& /*time*/)
 
 byte MSXS1990::readRegister(byte reg) const
 {
-	PRT_DEBUG("S1990: read reg " << (int)reg);
+	PRT_DEBUG("S1990: read reg " << int(reg));
 	switch (reg) {
 		case 5:
 			return firmwareSwitch->getStatus() ? 0x40 : 0x00;
