@@ -1,12 +1,8 @@
-// $Id: PluggableFactory.cc,v 1.20 2006/05/25 12:39:28 m9710797 Exp $
-
-#include "probed_defs.hh"
+// $Id: PluggableFactory.cc 5842 2006-11-04 18:47:26Z m9710797 $
 
 #include "PluggableFactory.hh"
 #include "PluggingController.hh"
 #include "MSXMotherBoard.hh"
-
-#include "JoyNet.hh"
 #include "Joystick.hh"
 #include "JoyTap.hh"
 #include "NinjaTap.hh"
@@ -18,6 +14,7 @@
 #include "Mouse.hh"
 #include "PrinterPortLogger.hh"
 #include "PrinterPortSimpl.hh"
+#include "Printer.hh"
 #include "RS232Tester.hh"
 #include "WavAudioInput.hh"
 #if	defined(_WIN32)
@@ -34,31 +31,27 @@ void PluggableFactory::createAll(PluggingController& controller,
 	EventDistributor& eventDistributor = motherBoard.getEventDistributor();
 	Scheduler& scheduler = motherBoard.getScheduler();
 	CommandController& commandController = motherBoard.getCommandController();
-	UserInputEventDistributor& userInputEventDistributor =
-		motherBoard.getUserInputEventDistributor();
+	MSXEventDistributor& msxEventDistributor =
+		motherBoard.getMSXEventDistributor();
 	// Input devices:
 	// TODO: Support hot-plugging of input devices:
 	// - additional key joysticks can be created by the user
 	// - real joysticks and mice can be hotplugged (USB)
-	controller.registerPluggable(new Mouse(motherBoard.getUserInputEventDistributor()));
-#ifdef	HAVE_SYS_SOCKET_H
-	controller.registerPluggable(new JoyNet(commandController));
-#endif
+	controller.registerPluggable(new Mouse(motherBoard.getMSXEventDistributor()));
 	controller.registerPluggable(new JoyTap(controller, "joytap"));
 	controller.registerPluggable(new NinjaTap(controller, "ninjatap"));
 	controller.registerPluggable(new KeyJoystick(
-		commandController, userInputEventDistributor, "keyjoystick1"));
+		commandController, msxEventDistributor, "keyjoystick1"));
 	controller.registerPluggable(new KeyJoystick(
-		commandController, userInputEventDistributor, "keyjoystick2"));
-	Joystick::registerAll(userInputEventDistributor, controller);
+		commandController, msxEventDistributor, "keyjoystick2"));
+	Joystick::registerAll(msxEventDistributor, controller);
 
 	// Dongles
 	controller.registerPluggable(new SETetrisDongle());
 	controller.registerPluggable(new MagicKey());
 
 	// Logging:
-	controller.registerPluggable(new PrinterPortLogger(
-		motherBoard.getCommandController()));
+	controller.registerPluggable(new PrinterPortLogger(commandController));
 	controller.registerPluggable(new MidiOutLogger(commandController));
 
 	// Serial communication:
@@ -66,7 +59,7 @@ void PluggableFactory::createAll(PluggingController& controller,
 		eventDistributor, scheduler, commandController));
 
 	// Sampled audio:
-	controller.registerPluggable(new PrinterPortSimpl(motherBoard.getMixer()));
+	controller.registerPluggable(new PrinterPortSimpl(motherBoard.getMSXMixer()));
 	controller.registerPluggable(new WavAudioInput(commandController));
 
 	// MIDI:
@@ -76,6 +69,10 @@ void PluggableFactory::createAll(PluggingController& controller,
 	MidiInNative::registerAll(eventDistributor, scheduler, controller);
 	MidiOutNative::registerAll(controller);
 #endif
+
+	// Printers
+	controller.registerPluggable(new ImagePrinterMSX(motherBoard));
+	controller.registerPluggable(new ImagePrinterEpson(motherBoard));
 }
 
 } // namespace openmsx
