@@ -1,4 +1,4 @@
-// $Id: PluggingController.cc 5854 2006-11-06 18:24:21Z m9710797 $
+// $Id: PluggingController.cc 7312 2007-11-25 09:28:03Z m9710797 $
 
 #include "PluggingController.hh"
 #include "RecordedCommand.hh"
@@ -127,6 +127,7 @@ PluggingController::~PluggingController()
 void PluggingController::registerConnector(Connector& connector)
 {
 	connectors.push_back(&connector);
+	cliComm.update(CliComm::CONNECTOR, connector.getName(), "add");
 }
 
 void PluggingController::unregisterConnector(Connector& connector)
@@ -135,6 +136,8 @@ void PluggingController::unregisterConnector(Connector& connector)
 	                               &connector);
 	assert(it != connectors.end());
 	connectors.erase(it);
+
+	cliComm.update(CliComm::CONNECTOR, connector.getName(), "remove");
 }
 
 
@@ -155,7 +158,7 @@ void PluggingController::unregisterPluggable(Pluggable* pluggable)
 }
 
 
-// === Commands ===
+// --- Commands ---
 //  plug command
 
 PlugCmd::PlugCmd(MSXCommandController& msxCommandController,
@@ -178,7 +181,7 @@ string PlugCmd::execute(const vector<string>& tokens, const EmuTime& time)
 		     it != pluggingController.connectors.end();
 		     ++it) {
 			result += ((*it)->getName() + ": " +
-				   (*it)->getPlugged().getName()) + '\n';
+				   (*it)->getPlugged().getName());
 		}
 		break;
 	}
@@ -188,7 +191,7 @@ string PlugCmd::execute(const vector<string>& tokens, const EmuTime& time)
 			throw CommandException("plug: " + tokens[1] + ": no such connector");
 		}
 		result += (connector->getName() + ": " +
-			   connector->getPlugged().getName()) + '\n';
+			   connector->getPlugged().getName());
 		break;
 	}
 	case 3: {
@@ -225,7 +228,7 @@ string PlugCmd::execute(const vector<string>& tokens, const EmuTime& time)
 string PlugCmd::help(const vector<string>& /*tokens*/) const
 {
 	return "Plugs a plug into a connector\n"
-	       " plug [connector] [plug]\n";
+	       " plug [connector] [plug]";
 }
 
 void PlugCmd::tabCompletion(vector<string>& tokens) const
@@ -286,7 +289,7 @@ string UnplugCmd::execute(const vector<string>& tokens, const EmuTime& time)
 string UnplugCmd::help(const vector<string>& /*tokens*/) const
 {
 	return "Unplugs a plug from a connector\n"
-	       " unplug [connector]\n";
+	       " unplug [connector]";
 }
 
 void UnplugCmd::tabCompletion(vector<string>& tokens) const
@@ -366,7 +369,7 @@ void PluggableInfo::execute(const vector<TclObject*>& tokens,
 string PluggableInfo::help(const vector<string>& /*tokens*/) const
 {
 	return "Shows a list of available pluggables. "
-	       "Or show info on a specific pluggable.\n";
+	       "Or show info on a specific pluggable.";
 }
 
 void PluggableInfo::tabCompletion(vector<string>& tokens) const
@@ -417,7 +420,7 @@ void ConnectorInfo::execute(const vector<TclObject*>& tokens,
 
 string ConnectorInfo::help(const vector<string>& /*tokens*/) const
 {
-	return "Shows a list of available connectors.\n";
+	return "Shows a list of available connectors.";
 }
 
 void ConnectorInfo::tabCompletion(vector<string>& tokens) const
