@@ -1,4 +1,4 @@
-// $Id: PrinterPortSimpl.cc,v 1.23 2005/11/11 20:53:05 m9710797 Exp $
+// $Id: PrinterPortSimpl.cc 5785 2006-10-18 15:57:18Z m9710797 $
 
 #include "PrinterPortSimpl.hh"
 #include "DACSound8U.hh"
@@ -6,7 +6,7 @@
 
 namespace openmsx {
 
-PrinterPortSimpl::PrinterPortSimpl(Mixer& mixer_)
+PrinterPortSimpl::PrinterPortSimpl(MSXMixer& mixer_)
 	: mixer(mixer_)
 {
 }
