@@ -1,4 +1,4 @@
-// $Id: Reactor.cc 6052 2007-02-05 19:10:09Z m9710797 $
+// $Id: Reactor.cc 6830 2007-08-11 17:29:58Z m9710797 $
 
 #include "Reactor.hh"
 #include "CommandLineParser.hh"
@@ -90,10 +90,7 @@ private:
 
 
 Reactor::Reactor()
-	: paused(false)
-	, blockedCounter(0)
-	, running(true)
-	, mbSem(1)
+	: mbSem(1)
 	, pauseSetting(getGlobalSettings().getPauseSetting())
 	, quitCommand(new QuitCommand(getCommandController(), *this))
 	, machineCommand(new MachineCommand(getCommandController(), *this))
@@ -105,6 +102,9 @@ Reactor::Reactor()
 	, machineInfo(new ConfigInfo(
 	       getGlobalCommandController().getOpenMSXInfoCommand(),
 	       "machines"))
+	, blockedCounter(0)
+	, paused(false)
+	, running(true)
 {
 	createMachineSetting();
 
@@ -335,6 +335,8 @@ void Reactor::run(CommandLineParser& parser)
 {
 	Display& display = getDisplay();
 	GlobalCommandController& commandController = getGlobalCommandController();
+	getDiskManipulator(); // make sure it gets instantiated
+	                      // (also on machines without disk drive)
 
 	// select initial machine before executing scripts
 	if (newMotherBoard.get()) {
@@ -599,7 +601,7 @@ void ConfigInfo::execute(const vector<TclObject*>& tokens,
 	case 3: {
 		try {
 			std::auto_ptr<XMLElement> config = HardwareConfig::loadConfig(
-				configName, tokens[2]->getString());
+				configName, tokens[2]->getString(), "dummy");
 			if (XMLElement* info = config->findChild("info")) {
 				const XMLElement::Children& children =
 					info->getChildren();
