@@ -1,4 +1,4 @@
-// $Id: RealTime.cc 5601 2006-09-06 13:55:13Z m9710797 $
+// $Id: RealTime.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "RealTime.hh"
 #include "Scheduler.hh"
@@ -50,7 +50,7 @@ RealTime::~RealTime()
 {
 	eventDistributor.unregisterEventListener(OPENMSX_FRAME_DRAWN_EVENT,  *this);
 	eventDistributor.unregisterEventListener(OPENMSX_FINISH_FRAME_EVENT, *this);
-	
+
 	powerSetting.detach(*this);
 	pauseSetting.detach(*this);
 	throttleManager.detach(*this);
@@ -70,7 +70,7 @@ EmuDuration RealTime::getEmuDuration(double realDur)
 bool RealTime::timeLeft(unsigned long long us, const EmuTime& time)
 {
 	unsigned long long realDuration =
-	   (unsigned long long)(getRealDuration(emuTime, time) * 1000000ULL);
+	   static_cast<unsigned long long>(getRealDuration(emuTime, time) * 1000000ULL);
 	unsigned long long currentRealTime = Timer::getTime();
 	return (currentRealTime + us) <
 	           (idealRealTime + realDuration + ALLOWED_LAG);
@@ -91,14 +91,14 @@ void RealTime::internalSync(const EmuTime& time, bool allowSleep)
 {
 	if (throttleManager.isThrottled()) {
 		unsigned long long realDuration =
-		    (unsigned long long)(getRealDuration(emuTime, time) *
-		                             1000000ULL);
+		    static_cast<unsigned long long>(
+		        getRealDuration(emuTime, time) * 1000000ULL);
 		idealRealTime += realDuration;
 		unsigned long long currentRealTime = Timer::getTime();
 		long long sleep = idealRealTime - currentRealTime;
 		if (allowSleep) {
 			//PRT_DEBUG("RT: want to sleep " << sleep << "us");
-			sleep += (long long)sleepAdjust;
+			sleep += static_cast<long long>(sleepAdjust);
 			long long delta = 0;
 			if (sleep > 0) {
 				//PRT_DEBUG("RT: Sleeping for " << sleep << "us");
