@@ -1,4 +1,4 @@
-// $Id: RenShaTurbo.cc,v 1.15 2006/01/18 22:29:44 m9710797 Exp $
+// $Id: RenShaTurbo.cc 5993 2007-01-12 22:12:12Z m9710797 $
 
 #include "RenShaTurbo.hh"
 #include "XMLElement.hh"
@@ -22,9 +22,9 @@ RenShaTurbo::~RenShaTurbo()
 {
 }
 
-byte RenShaTurbo::getSignal(const EmuTime& time)
+bool RenShaTurbo::getSignal(const EmuTime& time)
 {
-	return autofire.get() ? autofire->getSignal(time) : 0;
+	return autofire.get() ? autofire->getSignal(time) : false;
 }
 
 } // namespace openmsx
