@@ -1,7 +1,8 @@
-// $Id: Schedulable.cc,v 1.11 2005/11/13 08:49:47 m9710797 Exp $
+// $Id: Schedulable.cc 5736 2006-10-02 19:58:48Z m9710797 $
 
 #include "Schedulable.hh"
 #include "Scheduler.hh"
+#include <iostream>
 
 namespace openmsx {
 
@@ -15,6 +16,12 @@ Schedulable::~Schedulable()
 	removeSyncPoints();
 }
 
+void Schedulable::schedulerDeleted()
+{
+	std::cerr << "Internal error: Schedulable \"" << schedName()
+	          << "\" failed to unregister." << std::endl;
+}
+
 void Schedulable::setSyncPoint(const EmuTime& timestamp, int userData)
 {
 	scheduler.setSyncPoint(timestamp, *this, userData);
