@@ -1,10 +1,12 @@
-// $Id: ThrottleManager.cc,v 1.4 2006/01/02 23:27:12 mthuurne Exp $
+// $Id: ThrottleManager.cc 5713 2006-09-30 04:08:08Z mthuurne $
 
 #include "ThrottleManager.hh"
 #include "BooleanSetting.hh"
 
 namespace openmsx {
 
+// class ThrottleManager:
+
 ThrottleManager::ThrottleManager(CommandController& commandController)
 	: loading(0), throttle(true)
 {
@@ -55,4 +57,26 @@ void ThrottleManager::update(const Setting& /*setting*/)
 	updateStatus();
 }
 
+
+// class LoadingIndicator:
+
+LoadingIndicator::LoadingIndicator(ThrottleManager& throttleManager_)
+	: throttleManager(throttleManager_)
+	, isLoading(false)
+{
+}
+
+LoadingIndicator::~LoadingIndicator()
+{
+	update(false);
+}
+
+void LoadingIndicator::update(bool newState)
+{
+	if (isLoading != newState) {
+		isLoading = newState;
+		throttleManager.indicateLoadingState(isLoading);
+	}
+}
+
 } // namespace openmsx
