@@ -1,4 +1,4 @@
-// $Id: CasImage.cc 5920 2006-12-11 19:59:23Z m9710797 $
+// $Id: CasImage.cc 6766 2007-07-31 19:06:51Z m9710797 $
 
 #include "CasImage.hh"
 #include "File.hh"
@@ -52,6 +52,23 @@ EmuTime CasImage::getEndTime() const
 	return clk.getTime();
 }
 
+unsigned CasImage::getFrequency() const
+{
+	return OUTPUT_FREQUENCY;
+}
+
+void CasImage::fillBuffer(unsigned pos, int** bufs, unsigned num) const
+{
+	unsigned nbSamples = output.size();
+	if (pos < nbSamples) {
+		for (unsigned i = 0; i < num; ++i, ++pos) {
+			bufs[0][i] = (pos < nbSamples) ? output[pos] * 256 : 0;
+		}
+	} else {
+		bufs[0] = 0;
+	}
+}
+
 void CasImage::write0()
 {
 	output.push_back( 127);
