@@ -1,4 +1,4 @@
-// $Id: CassettePlayer.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: CassettePlayer.cc 7239 2007-11-06 20:28:03Z m9710797 $
 
 //TODO:
 // - specify prefix for auto file name generation when recording (setting?)
@@ -39,6 +39,8 @@
 #include "WavWriter.hh"
 #include "ThrottleManager.hh"
 #include "TclObject.hh"
+#include "DynamicClock.hh"
+#include "Clock.hh"
 #include <algorithm>
 #include <cassert>
 
@@ -52,6 +54,11 @@ namespace openmsx {
 static const unsigned RECORD_FREQ = 44100;
 static const double OUTPUT_AMP = 60.0;
 
+enum SyncType {
+	END_OF_TAPE,
+	SYNC_AUDIO_EMU
+};
+
 class TapeCommand : public RecordedCommand
 {
 public:
@@ -73,23 +80,25 @@ CassettePlayer::CassettePlayer(
 		MSXEventDistributor& msxEventDistributor,
 		EventDistributor& eventDistributor_,
 		MSXCliComm& cliComm_)
-	: SoundDevice(mixer, getName(), getDescription())
+	: SoundDevice(mixer, getName(), getDescription(), 1)
+	, Resample(msxCommandController_.getGlobalSettings(), 1)
 	, Schedulable(scheduler)
-	, state(STOP)
-	, motor(false), motorControl(true)
 	, tapeTime(EmuTime::zero)
 	, recTime(EmuTime::zero)
 	, prevTime(EmuTime::zero)
-	, lastOutput(false)
-	, sampcnt(0)
+	, playPos(0)
 	, msxCommandController(msxCommandController_)
-	, tapeCommand(new TapeCommand(msxCommandController, msxEventDistributor,
-	                              scheduler, *this))
-	, playTapeTime(EmuTime::zero)
 	, cliComm(cliComm_)
 	, eventDistributor(eventDistributor_)
+	, tapeCommand(new TapeCommand(msxCommandController, msxEventDistributor,
+	                              scheduler, *this))
 	, loadingIndicator(new LoadingIndicator(
 	       msxCommandController.getGlobalSettings().getThrottleManager()))
+	, sampcnt(0)
+	, state(STOP)
+	, lastOutput(false)
+	, motor(false), motorControl(true)
+	, syncScheduled(false)
 {
 	autoRunSetting.reset(new BooleanSetting(msxCommandController,
 		"autoruncassettes", "automatically try to run cassettes", false));
@@ -185,7 +194,6 @@ void CassettePlayer::checkInvariants() const
 {
 	switch (getState()) {
 	case STOP:
-		assert(isMuted());
 		assert(!recordImage.get());
 		break;
 	case PLAY:
@@ -194,7 +202,6 @@ void CassettePlayer::checkInvariants() const
 		assert(playImage.get());
 		break;
 	case RECORD:
-		assert(isMuted());
 		assert(!getImageName().empty());
 		assert(recordImage.get());
 		assert(!playImage.get());
@@ -244,14 +251,12 @@ void CassettePlayer::updateLoadingState(const EmuTime& time)
 {
 	// TODO also set loadingIndicator for RECORD?
 	// note: we don't use isRolling()
-	loadingIndicator->update(motor && (getState() == PLAY)); 
+	loadingIndicator->update(motor && (getState() == PLAY));
 
-	removeSyncPoint();
+	removeSyncPoint(END_OF_TAPE);
 	if ((motor || !motorControl) && (getState() == PLAY)) {
-		setSyncPoint(time + (playImage->getEndTime() - tapeTime));
+		setSyncPoint(time + (playImage->getEndTime() - tapeTime), END_OF_TAPE);
 	}
-
-	setMute((getState() != PLAY) || !isRolling());
 }
 
 void CassettePlayer::setImageName(const string& newImage)
@@ -277,12 +282,13 @@ void CassettePlayer::playTape(const string& filename, const EmuTime& time)
 	setImageName(filename);
 	rewind(time); // sets PLAY mode
 	autoRun();
+	setOutputRate(outputRate);
 }
 
 void CassettePlayer::rewind(const EmuTime& time)
 {
 	tapeTime = EmuTime::zero;
-	playTapeTime = EmuTime::zero;
+	playPos = 0;
 	setState(PLAY, time);
 }
 
@@ -343,7 +349,14 @@ void CassettePlayer::updatePlayPosition(const EmuTime& time)
 	assert(getState() == PLAY);
 	if (isRolling()) {
 		tapeTime += (time - prevTime);
-		playTapeTime = tapeTime;
+
+		if (!syncScheduled) {
+			// don't sync too often, this improves sound quality
+			syncScheduled = true;
+			Clock<1> next(time);
+			next += 1;
+			setSyncPoint(next.getTime(), SYNC_AUDIO_EMU);
+		}
 	}
 	prevTime = time;
 }
@@ -379,13 +392,13 @@ void CassettePlayer::setSignal(bool output, const EmuTime& time)
 		if (rest <= samples) {
 			// enough to fill next interval
 			partialOut += out * rest;
-			fillBuf(1, (int)partialOut);
+			fillBuf(1, int(partialOut));
 			samples -= rest;
 
 			// fill complete intervals
-			int count = (int)samples;
+			int count = int(samples);
 			if (count > 0) {
-				fillBuf(count, (int)out);
+				fillBuf(count, int(out));
 			}
 			samples -= count;
 
@@ -411,7 +424,7 @@ void CassettePlayer::fillBuf(size_t length, double x)
 	while (length) {
 		int len = std::min(length, BUF_SIZE - sampcnt);
 		for (int j = 0; j < len; ++j) {
-			buf[sampcnt++] = (int)y + 128;
+			buf[sampcnt++] = int(y) + 128;
 			y *= A;
 		}
 		length -= len;
@@ -460,24 +473,34 @@ void CassettePlayer::unplugHelper(const EmuTime& time)
 }
 
 
-void CassettePlayer::setVolume(int newVolume)
+void CassettePlayer::setOutputRate(unsigned newOutputRate)
 {
-	volume = newVolume;
+	outputRate = newOutputRate;
+	unsigned inputRate = playImage.get() ? playImage->getFrequency()
+	                                     : outputRate;
+	setInputRate(inputRate);
+	setResampleRatio(inputRate, outputRate);
 }
 
-void CassettePlayer::setSampleRate(int sampleRate)
+void CassettePlayer::generateChannels(int** buffers, unsigned num)
 {
-	delta = EmuDuration(1.0 / sampleRate);
+	if ((getState() != PLAY) || !isRolling()) {
+		buffers[0] = 0;
+		return;
+	}
+	playImage->fillBuffer(playPos, buffers, num);
+	playPos += num;
 }
 
-void CassettePlayer::updateBuffer(unsigned length, int* buffer,
+bool CassettePlayer::generateInput(int* buffer, unsigned num)
+{
+	return mixChannels(buffer, num);
+}
+
+bool CassettePlayer::updateBuffer(unsigned length, int* buffer,
      const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
 {
-	assert(getState() == PLAY);
-	while (length--) {
-		*(buffer++) = (((int)getSample(playTapeTime)) * volume) >> 15;
-		playTapeTime += delta;
-	}
+	return generateOutput(buffer, length);
 }
 
 
@@ -503,12 +526,30 @@ const std::string& CassettePlayer::schedName() const
 	static const string schedName = "CassettePlayer";
 	return schedName;
 }
- 
-void CassettePlayer::executeUntil(const EmuTime& time, int /*userData*/)
+
+void CassettePlayer::executeUntil(const EmuTime& time, int userData)
 {
-	// tape ended
-	cliComm.printWarning("Tape end reached... stopping. You may need to insert another tape image that contains side B. (Or you used the wrong loading command.)");
-	setState(STOP, time);
+	switch (userData) {
+	case END_OF_TAPE:
+		// tape ended
+		cliComm.printWarning(
+			"Tape end reached... stopping. "
+			"You may need to insert another tape image "
+			"that contains side B. (Or you used the wrong "
+			"loading command.)");
+		setState(STOP, time);
+		break;
+	case SYNC_AUDIO_EMU:
+		if (getState() == PLAY) {
+			updateStream(time);
+			updatePlayPosition(time);
+			DynamicClock clk(EmuTime::zero);
+			clk.setFreq(playImage->getFrequency());
+			playPos = clk.getTicksTill(tapeTime);
+		}
+		syncScheduled = false;
+		break;
+	}
 }
 
 
