@@ -1,4 +1,4 @@
-// $Id: CassettePort.cc 5854 2006-11-06 18:24:21Z m9710797 $
+// $Id: CassettePort.cc 6368 2007-04-24 20:13:13Z m9710797 $
 
 #include "CassettePort.hh"
 #include "CassettePlayer.hh"
@@ -48,11 +48,6 @@ CassetteDevice& CassettePortInterface::getPlugged() const
 
 // DummyCassettePort //
 
-DummyCassettePort::DummyCassettePort()
-	: CassettePortInterface()
-{
-}
-
 void DummyCassettePort::setMotor(bool /*status*/, const EmuTime& /*time*/)
 {
 	// do nothing
@@ -63,11 +58,11 @@ void DummyCassettePort::cassetteOut(bool /*output*/, const EmuTime& /*time*/)
 }
 bool DummyCassettePort::cassetteIn(const EmuTime& /*time*/)
 {
-	return true;	// TODO check on Turbo-R
+	return false;
 }
 bool DummyCassettePort::lastOut() const
 {
-  return false; // not relevant
+	return false; // not relevant
 }
 
 
@@ -76,8 +71,8 @@ bool DummyCassettePort::lastOut() const
 CassettePort::CassettePort(MSXMotherBoard& motherBoard)
 	: CassettePortInterface()
 	, pluggingController(motherBoard.getPluggingController())
-        , nextSample(0)
 	, prevTime(EmuTime::zero)
+	, nextSample(0)
 {
 	cassettePlayer.reset(new CassettePlayer(
 		motherBoard.getMSXCommandController(),
