@@ -1,8 +1,9 @@
-// $Id: WavImage.cc 5920 2006-12-11 19:59:23Z m9710797 $
+// $Id: WavImage.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "WavImage.hh"
 #include "MSXException.hh"
 #include "File.hh"
+#include "Math.hh"
 #include <SDL.h>
 
 using std::string;
@@ -43,16 +44,15 @@ WavImage::WavImage(const string& fileName)
 		free(buffer);
 		throw MSXException("Couldn't convert wav");
 	}
-	nbSamples = static_cast<unsigned>(audioCVT.len * audioCVT.len_ratio) / 2;
+	nbSamples = unsigned(audioCVT.len * audioCVT.len_ratio) / 2;
 
 	// calculate the average to subtract it later (simple DC filter)
 	if (nbSamples > 0) {
 		long long total = 0;
 		for (unsigned i = 0; i < nbSamples; ++i) {
-			total += buffer[i * 2] +
-			         (static_cast<signed char>(buffer[i * 2 + 1]) << 8);
+			total += getSample(i);
 		}
-		average = static_cast<short>(total / nbSamples);
+		average = short(total / nbSamples);
 	} else {
 		average = 0;
 	}
@@ -63,15 +63,18 @@ WavImage::~WavImage()
 	free(buffer);
 }
 
+int WavImage::getSample(unsigned pos) const
+{
+	return (pos < nbSamples)
+		? buffer[pos * 2] +
+		  (static_cast<signed char>(buffer[pos * 2 + 1]) << 8)
+		: 0;
+}
+
 short WavImage::getSampleAt(const EmuTime& time)
 {
 	unsigned pos = clock.getTicksTill(time);
-	int tmp = (pos < nbSamples)
-	        ? buffer[pos * 2] +
-	          (static_cast<signed char>(buffer[pos * 2 + 1]) << 8)
-	        : 0;
-	tmp -= average;
-	return tmp > 32767 ? 32767 : (tmp < -32768 ? -32768 : tmp);
+	return Math::clipIntToShort(getSample(pos) - average);
 }
 
 EmuTime WavImage::getEndTime() const
@@ -81,4 +84,20 @@ EmuTime WavImage::getEndTime() const
 	return clk.getTime();
 }
 
+unsigned WavImage::getFrequency() const
+{
+	return clock.getFreq();
+}
+
+void WavImage::fillBuffer(unsigned pos, int** bufs, unsigned num) const
+{
+	if (pos < nbSamples) {
+		for (unsigned i = 0; i < num; ++i) {
+			bufs[0][i] = getSample(pos + i);
+		}
+	} else {
+		bufs[0] = 0;
+	}
+}
+
 } // namespace openmsx
