@@ -1,4 +1,4 @@
-// $Id: GlobalCommandController.cc 6040 2007-02-03 19:46:06Z m9710797 $
+// $Id: GlobalCommandController.cc 6824 2007-08-08 15:20:19Z m9710797 $
 
 #include "GlobalCommandController.hh"
 #include "Command.hh"
@@ -177,7 +177,7 @@ CliConnection* GlobalCommandController::getConnection() const
 Interpreter& GlobalCommandController::getInterpreter()
 {
 	if (!interpreter.get()) {
-		interpreter.reset(new Interpreter(eventDistributor, reactor));
+		interpreter.reset(new Interpreter(eventDistributor));
 	}
 	return *interpreter;
 }
