@@ -1,4 +1,4 @@
-// $Id: Interpreter.cc 6127 2007-03-01 09:30:39Z m9710797 $
+// $Id: Interpreter.cc 6824 2007-08-08 15:20:19Z m9710797 $
 
 #include "Interpreter.hh"
 #include "EventDistributor.hh"
@@ -9,9 +9,6 @@
 #include "InterpreterOutput.hh"
 #include "openmsx.hh"
 #include "FileOperations.hh"
-#include "MSXMotherBoard.hh"
-#include "Reactor.hh"
-#include "MSXCommandController.hh"
 //#include <tk.h>
 
 using std::set;
@@ -60,9 +57,8 @@ void Interpreter::init(const char* programName)
 	Tcl_FindExecutable(programName);
 }
 
-Interpreter::Interpreter(EventDistributor& eventDistributor_, Reactor& reactor_)
+Interpreter::Interpreter(EventDistributor& eventDistributor_)
 	: eventDistributor(eventDistributor_)
-	, reactor(reactor_)
 {
 	interp = Tcl_CreateInterp();
 	Tcl_Preserve(interp);
@@ -117,8 +113,8 @@ int Interpreter::outputProc(ClientData clientData, const char* buf,
                  int toWrite, int* /*errorCodePtr*/)
 {
 	try {
-		InterpreterOutput* output = ((Interpreter*)clientData)->output;
-
+		InterpreterOutput* output =
+			static_cast<Interpreter*>(clientData)->output;
 		string text(buf, toWrite);
 		if (!text.empty() && output) {
 			output->output(text);
@@ -189,7 +185,7 @@ void Interpreter::getCommandNames(set<string>& result)
 		return;
 	}
 	result.insert(&argv[0], &argv[argc]);
-	Tcl_Free((char*)argv);
+	Tcl_Free(reinterpret_cast<char*>(argv));
 }
 
 bool Interpreter::isComplete(const string& command) const
@@ -325,7 +321,7 @@ void Interpreter::splitList(const string& list, vector<string>& result,
 		throw CommandException(message);
 	}
 	result.assign(argv, argv + argc);
-	Tcl_Free((char*)argv);
+	Tcl_Free(reinterpret_cast<char*>(argv));
 }
 
 bool Interpreter::signalEvent(shared_ptr<const Event> event)
