@@ -1,4 +1,4 @@
-// $Id: ExtensionConfig.cc 5993 2007-01-12 22:12:12Z m9710797 $
+// $Id: ExtensionConfig.cc 6749 2007-07-28 10:55:59Z m9710797 $
 
 #include "ExtensionConfig.hh"
 #include "XMLElement.hh"
@@ -16,9 +16,9 @@ namespace openmsx {
 
 ExtensionConfig::ExtensionConfig(MSXMotherBoard& motherBoard,
                                  const string& extensionName)
-	: HardwareConfig(motherBoard)
+	: HardwareConfig(motherBoard, extensionName)
 {
-	load("extensions", extensionName);
+	load("extensions");
 	setName(extensionName);
 }
 
@@ -26,7 +26,7 @@ ExtensionConfig::ExtensionConfig(
 		MSXMotherBoard& motherBoard,
 		const string& romfile, const string& slotname,
 		const vector<string>& options)
-	: HardwareConfig(motherBoard)
+	: HardwareConfig(motherBoard, "rom")
 {
 	vector<string> ipsfiles;
 	string mapper;
