@@ -1,11 +1,10 @@
-// $Id: HardwareConfig.cc 5854 2006-11-06 18:24:21Z m9710797 $
+// $Id: HardwareConfig.cc 6824 2007-08-08 15:20:19Z m9710797 $
 
 #include "HardwareConfig.hh"
 #include "XMLLoader.hh"
 #include "XMLElement.hh"
 #include "File.hh"
 #include "FileContext.hh"
-#include "FileException.hh"
 #include "FileOperations.hh"
 #include "MSXMotherBoard.hh"
 #include "CartridgeSlotManager.hh"
@@ -21,8 +20,9 @@ using std::string;
 
 namespace openmsx {
 
-HardwareConfig::HardwareConfig(MSXMotherBoard& motherBoard_)
+HardwareConfig::HardwareConfig(MSXMotherBoard& motherBoard_, const string& hwName_)
 	: motherBoard(motherBoard_)
+	, hwName(hwName_)
 {
 	for (int ps = 0; ps < 4; ++ps) {
 		for (int ss = 0; ss < 4; ++ss) {
@@ -32,10 +32,12 @@ HardwareConfig::HardwareConfig(MSXMotherBoard& motherBoard_)
 		expandedSlots[ps] = false;
 		allocatedPrimarySlots[ps] = -1;
 	}
+	userName = motherBoard.getUserName(hwName);
 }
 
 HardwareConfig::~HardwareConfig()
 {
+	motherBoard.freeUserName(hwName, userName);
 #ifndef NDEBUG
 	try {
 		testRemove();
@@ -80,11 +82,11 @@ void HardwareConfig::testRemove() const
 	for (int ps = 0; ps < 4; ++ps) {
 		for (int ss = 0; ss < 4; ++ss) {
 			if (externalSlots[ps][ss]) {
-				slotManager.testRemoveExternalSlot(ps, ss);
+				slotManager.testRemoveExternalSlot(ps, ss, *this);
 			}
 		}
 		if (externalPrimSlots[ps]) {
-			slotManager.testRemoveExternalSlot(ps);
+			slotManager.testRemoveExternalSlot(ps, *this);
 		}
 		if (expandedSlots[ps]) {
 			motherBoard.getCPUInterface().testUnsetExpanded(
@@ -105,16 +107,11 @@ void HardwareConfig::setConfig(std::auto_ptr<XMLElement> newConfig)
 }
 
 std::auto_ptr<XMLElement> HardwareConfig::loadConfig(
-		const string& path, const string& hwName)
+	const string& path, const string& hwName, const string& userName)
 {
 	SystemFileContext context;
-	string filename;
-	try {
-		filename = context.resolve(path + '/' + hwName + ".xml");
-	} catch (FileException& e) {
-		filename = context.resolve(
-			path + '/' + hwName + "/hardwareconfig.xml");
-	}
+	string filename = context.resolve(
+		path + '/' + hwName + "/hardwareconfig.xml");
 	try {
 		File file(filename);
 		std::auto_ptr<XMLElement> result = XMLLoader::loadXML(
@@ -122,8 +119,6 @@ std::auto_ptr<XMLElement> HardwareConfig::loadConfig(
 
 		string baseName = FileOperations::getBaseName(file.getURL());
 
-		// TODO get user name
-		string userName;
 		result->setFileContext(std::auto_ptr<FileContext>(
 			new ConfigFileContext(baseName, hwName, userName)));
 		return result;
@@ -134,9 +129,10 @@ std::auto_ptr<XMLElement> HardwareConfig::loadConfig(
 	}
 }
 
-void HardwareConfig::load(const string& path, const string& hwName)
+void HardwareConfig::load(const string& path)
 {
-	setConfig(loadConfig(path, hwName));
+	assert(!userName.empty());
+	setConfig(loadConfig(path, hwName, userName));
 }
 
 void HardwareConfig::parseSlots()
@@ -167,7 +163,7 @@ void HardwareConfig::parseSlots()
 			const string& secSlot = (*it2)->getAttribute("slot");
 			int ss = CartridgeSlotManager::getSlotNum(secSlot);
 			if (ss < 0) {
-				if ( (ss >= -128) && (0 <= ps) && (ps<4) 
+				if ( (ss >= -128) && (0 <= ps) && (ps<4)
 					 && motherBoard.getCPUInterface().isExpanded(ps))
 					ss += 128;
 				else {
