@@ -1,4 +1,4 @@
-// $Id: MachineConfig.cc 5070 2006-01-23 18:39:17Z m9710797 $
+// $Id: MachineConfig.cc 6749 2007-07-28 10:55:59Z m9710797 $
 
 #include "MachineConfig.hh"
 #include "XMLElement.hh"
@@ -7,9 +7,9 @@ namespace openmsx {
 
 MachineConfig::MachineConfig(MSXMotherBoard& motherBoard,
                              const std::string& machineName)
-	: HardwareConfig(motherBoard)
+	: HardwareConfig(motherBoard, machineName)
 {
-	load("machines", machineName);
+	load("machines");
 }
 
 const XMLElement& MachineConfig::getDevices() const
