@@ -1,4 +1,4 @@
-// $Id: SettingsConfig.cc 5779 2006-10-14 16:17:32Z m9710797 $
+// $Id: SettingsConfig.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "SettingsConfig.hh"
 #include "SettingsManager.hh"
@@ -12,7 +12,6 @@
 #include "GlobalCommandController.hh"
 #include "Command.hh"
 #include <memory>
-#include <cassert>
 
 using std::auto_ptr;
 using std::string;
@@ -97,7 +96,7 @@ void SettingsConfig::saveSetting(const string& filename)
 
 	File file(name, File::TRUNCATE);
 	string data = "<!DOCTYPE settings SYSTEM 'settings.dtd'>\n" + dump();
-	file.write((const byte*)data.c_str(), data.size());
+	file.write(data.c_str(), data.size());
 }
 
 void SettingsConfig::setSaveSettings(bool save)
