@@ -1,7 +1,8 @@
-// $Id: XMLLoader.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: XMLLoader.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "XMLLoader.hh"
 #include "XMLElement.hh"
+#include <libxml/xmlversion.h>
 
 using std::auto_ptr;
 using std::string;
@@ -20,7 +21,11 @@ XMLException::XMLException(const string& msg)
 auto_ptr<XMLElement> XMLLoader::loadXML(const string& filename,
                                         const string& systemID)
 {
+#if LIBXML_VERSION < 20600
 	xmlDocPtr doc = xmlParseFile(filename.c_str());
+#else
+	xmlDocPtr doc = xmlReadFile(filename.c_str(), NULL, 0);
+#endif
 	if (!doc) {
 		throw XMLException(filename + ": Document parsing failed");
 	}
@@ -34,7 +39,7 @@ auto_ptr<XMLElement> XMLLoader::loadXML(const string& filename,
 		throw XMLException(filename + ": Missing systemID.\n"
 			"You're probably using an old incompatible file format.");
 	}
-	string actualID = (const char*)intSubset->SystemID;
+	string actualID = reinterpret_cast<const char*>(intSubset->SystemID);
 	if (actualID != systemID) {
 		throw XMLException(filename + ": systemID doesn't match "
 			"(expected " + systemID + ", got " + actualID + ")\n"
@@ -51,11 +56,12 @@ auto_ptr<XMLElement> XMLLoader::loadXML(const string& filename,
 
 void XMLLoader::init(XMLElement& elem, xmlNodePtr node)
 {
-	elem.setName((const char*)node->name);
+	elem.setName(reinterpret_cast<const char*>(node->name));
 	for (xmlNodePtr x = node->children; x != NULL ; x = x->next) {
 		switch (x->type) {
 		case XML_TEXT_NODE:
-			elem.setData(elem.getData() + (const char*)x->content);
+			elem.setData(elem.getData() +
+			             reinterpret_cast<const char*>(x->content));
 			break;
 		case XML_ELEMENT_NODE: {
 			std::auto_ptr<XMLElement> child(new XMLElement(""));
@@ -71,8 +77,8 @@ void XMLLoader::init(XMLElement& elem, xmlNodePtr node)
 	for (xmlAttrPtr x = node->properties; x != NULL ; x = x->next) {
 		switch (x->type) {
 		case XML_ATTRIBUTE_NODE: {
-			string name  = (const char*)x->name;
-			string value = (const char*)x->children->content;
+			string name  = reinterpret_cast<const char*>(x->name);
+			string value = reinterpret_cast<const char*>(x->children->content);
 			elem.addAttribute(name, value);
 			break;
 		}
