@@ -1,4 +1,4 @@
-// $Id: CommandConsole.cc 5935 2006-12-16 17:05:46Z m9710797 $
+// $Id: CommandConsole.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "CommandConsole.hh"
 #include "CommandException.hh"
@@ -67,7 +67,7 @@ CommandConsole::CommandConsole(
 	      "\n"
 	      "Type 'help' to see a list of available commands "
 	      "(use <PgUp>/<PgDn> to scroll).\n"
-	      "Or read the commands.txt file that is shipped with openMSX.\n"
+	      "Or read the Console Command Reference in the manual.\n"
 	      "\n");
 
 	commandController.getInterpreter().setOutput(this);
@@ -396,8 +396,7 @@ void CommandConsole::normalKey(word chr)
 	if (!chr) return;
 	if (chr >= 0x100) return; // TODO: Support Unicode (how?).
 	resetScrollBack();
-	lines[0].insert(lines[0].begin() + cursorPosition,
-	                static_cast<char>(chr));
+	lines[0].insert(lines[0].begin() + cursorPosition, char(chr));
 	currentLine = lines[0];
 	++cursorPosition;
 }
