@@ -1,4 +1,4 @@
-// $Id: SDLConsole.cc 5204 2006-02-27 21:49:17Z m9710797 $
+// $Id: SDLConsole.cc 6914 2007-09-08 21:22:05Z m9710797 $
 
 /*  Written By: Garrett Banuk <mongoose@mongeese.org>
  *  Adapted to C++ and openMSX needs by David Heremans
@@ -12,7 +12,7 @@
 #include "Console.hh"
 #include "File.hh"
 #include "Timer.hh"
-#include <cassert>
+#include "MSXException.hh"
 #include <SDL.h>
 
 using std::string;
@@ -113,8 +113,15 @@ void SDLConsole::loadBackground(const string& filename)
 
 void SDLConsole::loadFont(const string& filename)
 {
-	File file(filename);
-	font.reset(new SDLFont(&file, outputScreen));
+	string filePath;
+	// Note: It is essential the File object is destroyed before the SDLFont
+	//       constructor is called, because if the file is open in read/write
+	//       mode, the image loading will fail.
+	{
+		File file(filename);
+		filePath = file.getLocalName();
+	}
+	font.reset(new SDLFont(filePath, outputScreen));
 }
 
 unsigned SDLConsole::getScreenW() const
