@@ -1,32 +1,14 @@
-// $Id: BreakPointBase.cc,v 1.1 2006/04/20 18:13:15 m9710797 Exp $
+// $Id: BreakPointBase.cc 5854 2006-11-06 18:24:21Z m9710797 $
 
 #include "BreakPointBase.hh"
 #include "TclObject.hh"
 #include "CommandException.hh"
-#include "CliComm.hh"
+#include "MSXCliComm.hh"
+#include "ScopedAssign.hh"
 
 namespace openmsx {
 
-template <typename T> class ScopedAssign
-{
-public:
-	ScopedAssign(T& var_, T newValue)
-		: var(var_)
-	{
-		oldValue = var;
-		var = newValue;
-	}
-	~ScopedAssign()
-	{
-		var = oldValue;
-	}
-private:
-	T& var;
-	T oldValue;
-};
-
-
-BreakPointBase::BreakPointBase(CliComm& cliComm_,
+BreakPointBase::BreakPointBase(MSXCliComm& cliComm_,
                                std::auto_ptr<TclObject> command_,
                                std::auto_ptr<TclObject> condition_)
 	: cliComm(cliComm_), command(command_), condition(condition_)
