@@ -1,6 +1,7 @@
-// $Id: CPU.cc,v 1.64 2005/11/10 18:44:42 m9710797 Exp $
+// $Id: CPU.cc 5965 2006-12-27 12:16:54Z m9710797 $
 
 #include "CPU.hh"
+#include "BreakPoint.hh"
 
 namespace openmsx {
 
@@ -94,7 +95,7 @@ void CPU::insertBreakPoint(std::auto_ptr<BreakPoint> bp_)
 {
 	BreakPoint* bp = bp_.release();
 	breakPoints.insert(std::make_pair(bp->getAddress(), bp));
-	exitCPULoop();
+	exitCPULoopSync();
 }
 
 void CPU::removeBreakPoint(const BreakPoint& bp)
@@ -108,7 +109,7 @@ void CPU::removeBreakPoint(const BreakPoint& bp)
 			break;
 		}
 	}
-	exitCPULoop();
+	exitCPULoopSync();
 }
 
 const CPU::BreakPoints& CPU::getBreakPoints() const
@@ -119,7 +120,16 @@ const CPU::BreakPoints& CPU::getBreakPoints() const
 void CPU::setPaused(bool paused_)
 {
 	paused = paused_;
-	exitCPULoop();
+	exitCPULoopSync();
+}
+
+void CPU::checkBreakPoints(std::pair<BreakPoints::const_iterator,
+                                     BreakPoints::const_iterator> range) const
+{
+	for (BreakPoints::const_iterator it = range.first;
+	     it != range.second; ++it) {
+		it->second->checkAndExecute();
+	}
 }
 
 } // namespace openmsx
