@@ -1,4 +1,4 @@
-// $Id: MSXCPUInterface.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: MSXCPUInterface.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "MSXCPUInterface.hh"
 #include "DummyDevice.hh"
@@ -27,6 +27,7 @@
 #include <iomanip>
 #include <algorithm>
 #include <iostream>
+#include <cstring>
 
 using std::auto_ptr;
 using std::ostringstream;
@@ -134,24 +135,25 @@ auto_ptr<MSXCPUInterface> MSXCPUInterface::create(
 	}
 }
 
-MSXCPUInterface::MSXCPUInterface(MSXMotherBoard& motherBoard)
-	: memoryDebug       (new MemoryDebug       (*this, motherBoard))
-	, slottedMemoryDebug(new SlottedMemoryDebug(*this, motherBoard))
-	, ioDebug           (new IODebug           (*this, motherBoard))
+MSXCPUInterface::MSXCPUInterface(MSXMotherBoard& motherBoard_)
+	: memoryDebug       (new MemoryDebug       (*this, motherBoard_))
+	, slottedMemoryDebug(new SlottedMemoryDebug(*this, motherBoard_))
+	, ioDebug           (new IODebug           (*this, motherBoard_))
 	, slotInfo        (new SlotInfo(
-		motherBoard.getMSXCommandController().getMachineInfoCommand(), *this))
+		motherBoard_.getMSXCommandController().getMachineInfoCommand(), *this))
 	, subSlottedInfo  (new SubSlottedInfo(
-		motherBoard.getMSXCommandController().getMachineInfoCommand(), *this))
+		motherBoard_.getMSXCommandController().getMachineInfoCommand(), *this))
 	, externalSlotInfo(new ExternalSlotInfo(
-		motherBoard.getMSXCommandController().getMachineInfoCommand(),
-		motherBoard.getSlotManager()))
+		motherBoard_.getMSXCommandController().getMachineInfoCommand(),
+		motherBoard_.getSlotManager()))
 	, inputPortInfo (new IOInfo(
-	        motherBoard.getMSXCommandController().getMachineInfoCommand(), *this, true))
+	        motherBoard_.getMSXCommandController().getMachineInfoCommand(), *this, true))
 	, outputPortInfo(new IOInfo(
-	        motherBoard.getMSXCommandController().getMachineInfoCommand(), *this, false))
-	, dummyDevice(motherBoard.getDummyDevice())
-	, msxcpu(motherBoard.getCPU())
-	, cliCommOutput(motherBoard.getMSXCliComm())
+	        motherBoard_.getMSXCommandController().getMachineInfoCommand(), *this, false))
+	, dummyDevice(motherBoard_.getDummyDevice())
+	, msxcpu(motherBoard_.getCPU())
+	, cliCommOutput(motherBoard_.getMSXCliComm())
+	, motherBoard(motherBoard_)
 {
 	for (int port = 0; port < 256; ++port) {
 		IO_In [port] = &dummyDevice;
@@ -212,15 +214,18 @@ void MSXCPUInterface::removeAllWatchPoints()
 	while (!watchPoints.empty()) {
 		removeWatchPoint(*watchPoints.back());
 	}
-	
+
 }
 
 byte MSXCPUInterface::readMemSlow(word address, const EmuTime& time)
 {
-	// execute read watches before actual read
-	if (unlikely(readWatchSet[address >> CacheLine::BITS]
-	                         [address &  CacheLine::LOW])) {
-		executeMemWatch(address, WatchPoint::READ_MEM);
+	// something special in this region?
+	if (unlikely(!allowReadCache[address >> CacheLine::BITS])) {
+		// execute read watches before actual read
+		if (readWatchSet[address >> CacheLine::BITS]
+		                [address &  CacheLine::LOW]) {
+			executeMemWatch(address, WatchPoint::READ_MEM);
+		}
 	}
 	if (unlikely((address == 0xFFFF) && isExpanded(primarySlotState[3]))) {
 		return 0xFF ^ subSlotRegister[primarySlotState[3]];
@@ -236,10 +241,22 @@ void MSXCPUInterface::writeMemSlow(word address, byte value, const EmuTime& time
 	} else {
 		visibleDevices[address>>14]->writeMem(address, value, time);
 	}
-	// execute write watches after actual write
-	if (unlikely(writeWatchSet[address >> CacheLine::BITS]
-	                          [address &  CacheLine::LOW])) {
-		executeMemWatch(address, WatchPoint::WRITE_MEM);
+	// something special in this region?
+	if (unlikely(!allowWriteCache[address >> CacheLine::BITS])) {
+		// slot-select-ignore writes (Super Lode Runner)
+		for (GlobalWrites::const_iterator it = globalWrites.begin();
+		     it != globalWrites.end(); ++it) {
+			// very primitive address selection mechanism,
+			// but more than enough for now
+			if (unlikely(it->addr == address)) {
+				it->device->globalWrite(address, value, time);
+			}
+		}
+		// execute write watches after actual write
+		if (writeWatchSet[address >> CacheLine::BITS]
+		                 [address &  CacheLine::LOW]) {
+			executeMemWatch(address, WatchPoint::WRITE_MEM);
+		}
 	}
 }
 
@@ -255,6 +272,10 @@ void MSXCPUInterface::setAllowedCache()
 		if (readWatchSet [i].any()) allowReadCache [i] = false;
 		if (writeWatchSet[i].any()) allowWriteCache[i] = false;
 	}
+	for (GlobalWrites::const_iterator it = globalWrites.begin();
+	     it != globalWrites.end(); ++it) {
+		allowWriteCache[it->addr >> CacheLine::BITS] = false;
+	}
 }
 
 void MSXCPUInterface::setExpanded(int ps)
@@ -486,6 +507,23 @@ void MSXCPUInterface::unregisterMemDevice(
 	}
 }
 
+void MSXCPUInterface::registerGlobalWrite(MSXDevice& device, word address)
+{
+	GlobalWriteInfo info = { &device, address };
+	globalWrites.push_back(info);
+	setAllowedCache();
+}
+
+void MSXCPUInterface::unregisterGlobalWrite(MSXDevice& device, word address)
+{
+	GlobalWriteInfo info = { &device, address };
+	GlobalWrites::iterator it =
+		find(globalWrites.begin(), globalWrites.end(), info);
+	assert(it != globalWrites.end());
+	globalWrites.erase(it);
+	setAllowedCache();
+}
+
 void MSXCPUInterface::updateVisible(int page)
 {
 	MSXDevice* newDevice = slotLayout[primarySlotState[page]]
@@ -512,6 +550,11 @@ void MSXCPUInterface::reset()
 	setPrimarySlots(0);
 }
 
+byte MSXCPUInterface::readIRQVector()
+{
+	return motherBoard.readIRQVector();
+}
+
 void MSXCPUInterface::setPrimarySlots(byte value)
 {
 	for (int page = 0; page < 4; ++page, value >>= 2) {
@@ -864,7 +907,7 @@ byte IODebug::read(unsigned address, const EmuTime& time)
 
 void IODebug::write(unsigned address, byte value, const EmuTime& time)
 {
-	interface.writeIO((word)address, value, time);
+	interface.writeIO(word(address), value, time);
 }
 
 
