@@ -1,4 +1,4 @@
-// $Id: WatchPoint.cc 5868 2006-11-08 19:25:30Z m9710797 $
+// $Id: WatchPoint.cc 6366 2007-04-24 19:05:58Z m9710797 $
 
 #include "WatchPoint.hh"
 #include "TclObject.hh"
@@ -13,7 +13,7 @@ WatchPoint::WatchPoint(MSXCliComm& cliComm,
                        std::auto_ptr<TclObject> condition,
                        Type type_, unsigned beginAddr_, unsigned endAddr_)
 	: BreakPointBase(cliComm, command, condition)
-	, type(type_), beginAddr(beginAddr_), endAddr(endAddr_)
+	, beginAddr(beginAddr_), endAddr(endAddr_), type(type_)
 {
 	assert(beginAddr <= endAddr);
 	id = ++lastId;
