@@ -1,4 +1,4 @@
-// $Id: CliConnection.cc 5731 2006-10-01 19:54:47Z m9710797 $
+// $Id: CliConnection.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 // TODO:
 // - To avoid any possible conflicts, anything called from "run" should be
@@ -59,9 +59,9 @@ CliConnection::CliConnection(CommandController& commandController_,
 	user_data.unknownLevel = 0;
 	user_data.object = this;
 	memset(&sax_handler, 0, sizeof(sax_handler));
-	sax_handler.startElement = (startElementSAXFunc)cb_start_element;
-	sax_handler.endElement   = (endElementSAXFunc)  cb_end_element;
-	sax_handler.characters   = (charactersSAXFunc)  cb_text;
+	sax_handler.startElement = cb_start_element;
+	sax_handler.endElement   = cb_end_element;
+	sax_handler.characters   = cb_text;
 
 	parser_context = xmlCreatePushParserCtxt(&sax_handler, &user_data, 0, 0, 0);
 
@@ -128,59 +128,62 @@ bool CliConnection::signalEvent(shared_ptr<const Event> event)
 	return true;
 }
 
-void CliConnection::cb_start_element(ParseState* user_data,
+void CliConnection::cb_start_element(void* user_data,
                      const xmlChar* name, const xmlChar** /*attrs*/)
 {
-	if (user_data->unknownLevel) {
-		++(user_data->unknownLevel);
+	ParseState* parseState = static_cast<ParseState*>(user_data);
+	if (parseState->unknownLevel) {
+		++(parseState->unknownLevel);
 		return;
 	}
-	switch (user_data->state) {
+	switch (parseState->state) {
 		case START:
-			if (strcmp((const char*)name, "openmsx-control") == 0) {
-				user_data->state = TAG_OPENMSX;
+			if (strcmp(reinterpret_cast<const char*>(name), "openmsx-control") == 0) {
+				parseState->state = TAG_OPENMSX;
 			} else {
-				++(user_data->unknownLevel);
+				++(parseState->unknownLevel);
 			}
 			break;
 		case TAG_OPENMSX:
-			if (strcmp((const char*)name, "command") == 0) {
-				user_data->state = TAG_COMMAND;
+			if (strcmp(reinterpret_cast<const char*>(name), "command") == 0) {
+				parseState->state = TAG_COMMAND;
 			} else {
-				++(user_data->unknownLevel);
+				++(parseState->unknownLevel);
 			}
 			break;
 		default:
-			++(user_data->unknownLevel);
+			++(parseState->unknownLevel);
 			break;
 	}
-	user_data->content.clear();
+	parseState->content.clear();
 }
 
-void CliConnection::cb_end_element(ParseState* user_data, const xmlChar* /*name*/)
+void CliConnection::cb_end_element(void* user_data, const xmlChar* /*name*/)
 {
-	if (user_data->unknownLevel) {
-		--(user_data->unknownLevel);
+	ParseState* parseState = static_cast<ParseState*>(user_data);
+	if (parseState->unknownLevel) {
+		--(parseState->unknownLevel);
 		return;
 	}
-	switch (user_data->state) {
+	switch (parseState->state) {
 		case TAG_OPENMSX:
-			user_data->object->end();
-			user_data->state = END;
+			parseState->object->end();
+			parseState->state = END;
 			break;
 		case TAG_COMMAND:
-			user_data->object->execute(user_data->content);
-			user_data->state = TAG_OPENMSX;
+			parseState->object->execute(parseState->content);
+			parseState->state = TAG_OPENMSX;
 			break;
 		default:
 			break;
 	}
 }
 
-void CliConnection::cb_text(ParseState* user_data, const xmlChar* chars, int len)
+void CliConnection::cb_text(void* user_data, const xmlChar* chars, int len)
 {
-	if (user_data->state == TAG_COMMAND) {
-		user_data->content.append((const char*)chars, len);
+	ParseState* parseState = static_cast<ParseState*>(user_data);
+	if (parseState->state == TAG_COMMAND) {
+		parseState->content.append(reinterpret_cast<const char*>(chars), len);
 	}
 }
 
@@ -232,6 +235,10 @@ void StdioConnection::close()
 #ifdef _WIN32
 // class PipeConnection
 
+// INVALID_HANDLE_VALUE is #defined as  (HANDLE)(-1)
+// but that gives a old-style-cast warning
+static const HANDLE OPENMSX_INVALID_HANDLE_VALUE = reinterpret_cast<HANDLE>(-1);
+
 PipeConnection::PipeConnection(CommandController& commandController,
                                EventDistributor& eventDistributor,
                                const string& name)
@@ -240,10 +247,10 @@ PipeConnection::PipeConnection(CommandController& commandController,
 	string pipeName = "\\\\.\\pipe\\" + name;
 	pipeHandle = CreateFileA(pipeName.c_str(), GENERIC_READ, 0, NULL,
 	                         OPEN_EXISTING, 0, NULL);
-	if (pipeHandle == INVALID_HANDLE_VALUE) {
+	if (pipeHandle == OPENMSX_INVALID_HANDLE_VALUE) {
 		char msg[256];
 		snprintf(msg, 255, "Error reopening pipefile '%s': error %u",
-		         pipeName.c_str(), (unsigned int)GetLastError());
+		         pipeName.c_str(), unsigned(GetLastError()));
 		throw FatalError(msg);
 	}
 
@@ -257,7 +264,7 @@ PipeConnection::~PipeConnection()
 
 void PipeConnection::run()
 {
-	while (pipeHandle != INVALID_HANDLE_VALUE) {
+	while (pipeHandle != OPENMSX_INVALID_HANDLE_VALUE) {
 		char buf[BUF_SIZE];
 		unsigned long bytesRead;
 		if (!ReadFile(pipeHandle, buf, BUF_SIZE, &bytesRead, NULL)) {
@@ -270,17 +277,17 @@ void PipeConnection::run()
 
 void PipeConnection::output(const std::string& message)
 {
-	if (pipeHandle != INVALID_HANDLE_VALUE) {
+	if (pipeHandle != OPENMSX_INVALID_HANDLE_VALUE) {
 		std::cout << message << std::flush;
 	}
 }
 
 void PipeConnection::close()
 {
-	if (pipeHandle != INVALID_HANDLE_VALUE) {
+	if (pipeHandle != OPENMSX_INVALID_HANDLE_VALUE) {
 		// TODO: Proper locking
 		HANDLE _pipeHandle = pipeHandle;
-		pipeHandle = INVALID_HANDLE_VALUE;
+		pipeHandle = OPENMSX_INVALID_HANDLE_VALUE;
 		CloseHandle(_pipeHandle);
 	}
 }
@@ -293,7 +300,7 @@ SocketConnection::SocketConnection(CommandController& commandController,
                                    EventDistributor& eventDistributor,
                                    SOCKET sd_)
 	: CliConnection(commandController, eventDistributor)
-	, sd(sd_), sem(1)
+	, sem(1), sd(sd_)
 {
 	start();
 }
@@ -309,7 +316,7 @@ void SocketConnection::run()
 	// No need to lock in this thread because we don't write to 'sd'
 	// and 'sd' only gets written to in this thread.
 	while (true) {
-		if (sd == INVALID_SOCKET) return;
+		if (sd == OPENMSX_INVALID_SOCKET) return;
 		char buf[BUF_SIZE];
 		int n = sock_recv(sd, buf, BUF_SIZE);
 		if (n > 0) {
@@ -330,7 +337,7 @@ void SocketConnection::output(const std::string& message)
 		int bytesSend;
 		{
 			ScopedLock lock(sem);
-			if (sd == INVALID_SOCKET) return;
+			if (sd == OPENMSX_INVALID_SOCKET) return;
 			bytesSend = sock_send(sd, &data[pos], bytesLeft);
 		}
 		if (bytesSend > 0) {
@@ -346,9 +353,9 @@ void SocketConnection::output(const std::string& message)
 void SocketConnection::close()
 {
 	ScopedLock lock(sem);
-	if (sd != INVALID_SOCKET) {
+	if (sd != OPENMSX_INVALID_SOCKET) {
 		SOCKET _sd = sd;
-		sd = INVALID_SOCKET;
+		sd = OPENMSX_INVALID_SOCKET;
 		sock_close(_sd);
 	}
 }
