@@ -1,4 +1,4 @@
-// $Id: GlobalCliComm.cc 6126 2007-02-28 22:37:02Z manuelbi $
+// $Id: GlobalCliComm.cc 7312 2007-11-25 09:28:03Z m9710797 $
 
 #include "GlobalCliComm.hh"
 #include "CommandException.hh"
@@ -44,8 +44,8 @@ GlobalCliComm::GlobalCliComm(GlobalCommandController& commandController_,
 	: updateCmd(new UpdateCmd(commandController_, *this))
 	, commandController(commandController_)
 	, eventDistributor(eventDistributor_)
-	, xmlOutput(false)
 	, sem(1)
+	, xmlOutput(false)
 {
 	commandController.setCliComm(this);
 
@@ -104,7 +104,8 @@ void GlobalCliComm::addConnection(auto_ptr<CliConnection> connection)
 }
 
 const char* const updateStr[CliComm::NUM_UPDATES] = {
-	"led", "setting", "hardware", "plug", "unplug", "media", "status"
+	"led", "setting", "hardware", "plug", "unplug", "media", "status", 
+		"extension", "sounddevice", "connector"
 };
 void GlobalCliComm::log(LogLevel level, const string& message)
 {
@@ -153,7 +154,7 @@ void GlobalCliComm::update(UpdateType type, const string& machine,
 			str += " machine=\"" + machine + '\"';
 		}
 		if (!name.empty()) {
-			str += " name=\"" + name + '\"';
+			str += " name=\"" + XMLElement::XMLEscape(name) + '\"';
 		}
 		str += '>' + XMLElement::XMLEscape(value) + "</update>\n";
 		for (Connections::const_iterator it = connections.begin();
