@@ -1,4 +1,4 @@
-// $Id: InputEventFactory.cc 6154 2007-03-11 09:31:48Z m9710797 $
+// $Id: InputEventFactory.cc 6421 2007-04-30 13:51:56Z m9710797 $
 
 #include "InputEventFactory.hh"
 #include "InputEvents.hh"
@@ -80,7 +80,7 @@ static EventPtr parseJoystickEvent(
 	if (components.size() != 3) {
 		throw CommandException("Invalid joystick event: " + str);
 	}
-	unsigned joystick = StringOp::stringToInt(components[0].substr(3));
+	unsigned joystick = StringOp::stringToInt(components[0].substr(3)) - 1;
 	if (StringOp::startsWith(components[1], "button")) {
 		unsigned button = StringOp::stringToInt(components[1].substr(6));
 		if (upDown(components[2])) {
