@@ -1,4 +1,4 @@
-// $Id: InputEventGenerator.cc 5731 2006-10-01 19:54:47Z m9710797 $
+// $Id: InputEventGenerator.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 #include "Command.hh"
 #include "InputEventGenerator.hh"
@@ -28,13 +28,13 @@ private:
 
 InputEventGenerator::InputEventGenerator(CommandController& commandController,
                                          EventDistributor& eventDistributor_)
-	: grabInput(new BooleanSetting(commandController, "grabinput",
+	: eventDistributor(eventDistributor_)
+	, grabInput(new BooleanSetting(commandController, "grabinput",
 		"This setting controls if openmsx takes over mouse and keyboard input",
 		false, Setting::DONT_SAVE))
-	, escapeGrabState(ESCAPE_GRAB_WAIT_CMD)
 	, escapeGrabCmd(new EscapeGrabCmd(commandController, *this))
+	, escapeGrabState(ESCAPE_GRAB_WAIT_CMD)
 	, keyRepeat(false)
-	, eventDistributor(eventDistributor_)
 {
 	setGrabInput(grabInput->getValue());
 	grabInput->attach(*this);
