@@ -1,4 +1,4 @@
-// $Id: Socket.cc 4863 2005-11-13 21:37:09Z m9710797 $
+// $Id: Socket.cc 6792 2007-08-04 12:18:59Z m9710797 $
 
 #include "Socket.hh"
 #include "MSXException.hh"
@@ -80,8 +80,11 @@ std::string sock_error()
 void sock_startup()
 {
 #ifdef _WIN32
+	// MAKEWORD is #define'd as ((WORD)(((BYTE)(a))|(((WORD)((BYTE)(b)))<<8)))
+	// but using that gives old-style-cast warnings
+	WORD w = 1 | (1 << 8); // MAKEWORD(1, 1)
 	WSAData wsaData;
-	if (WSAStartup(MAKEWORD(1, 1), &wsaData) != 0) {
+	if (WSAStartup(w, &wsaData) != 0) {
 		throw FatalError(sock_error());
 	}
 #else
@@ -135,7 +138,7 @@ int sock_recv(int sd, char* buf, size_t count)
 	// WinNT/2000 or on Unix.
 	int err;
 	int errlen = sizeof(err);
-	getsockopt(sd, SOL_SOCKET, SO_ERROR, (char*)&err, &errlen);
+	getsockopt(sd, SOL_SOCKET, SO_ERROR, reinterpret_cast<char*>(&err), &errlen);
 	if (err == WSAEWOULDBLOCK) return 0;
 	return -1;
 #else
@@ -152,7 +155,7 @@ int sock_send(int sd, const char* buf, size_t count)
 #ifdef _WIN32
 	int err;
 	int errlen = sizeof(err);
-	getsockopt(sd, SOL_SOCKET, SO_ERROR, (char*)&err, &errlen);
+	getsockopt(sd, SOL_SOCKET, SO_ERROR, reinterpret_cast<char*>(&err), &errlen);
 	if (err == WSAEWOULDBLOCK) return 0;
 	return -1;
 #else
