@@ -1,12 +1,10 @@
-// $Id: DiskImageCLI.cc,v 1.32 2006/03/15 20:47:21 m9710797 Exp $
+// $Id: DiskImageCLI.cc 6131 2007-03-02 12:00:24Z m9710797 $
 
 #include "DiskImageCLI.hh"
 #include "Reactor.hh"
 #include "CommandController.hh"
+#include "CommandLineParser.hh"
 #include "TclObject.hh"
-#include "GlobalSettings.hh"
-#include "XMLElement.hh"
-#include "FileContext.hh"
 #include "MSXException.hh"
 
 using std::list;
@@ -17,10 +15,10 @@ namespace openmsx {
 DiskImageCLI::DiskImageCLI(CommandLineParser& commandLineParser)
 	: commandController(commandLineParser.getReactor().getCommandController())
 {
-	commandLineParser.registerOption("-diska", this);
-	commandLineParser.registerOption("-diskb", this);
+	commandLineParser.registerOption("-diska", *this);
+	commandLineParser.registerOption("-diskb", *this);
 
-	commandLineParser.registerFileClass("diskimage", this);
+	commandLineParser.registerFileClass("diskimage", *this);
 	driveLetter = 'a';
 }
 
@@ -53,7 +51,7 @@ const string& DiskImageCLI::fileTypeHelp() const
 void DiskImageCLI::parse(const string& drive, const string& image,
                          list<string>& cmdLine)
 {
-	if (!commandController.hasCommand(drive)) {
+	if (!commandController.hasCommand(drive)) { // TODO WIP
 		throw MSXException("No drive named '" + drive + "'.");
 	}
 	TclObject command(commandController.getInterpreter());
