@@ -1,12 +1,11 @@
-// $Id: MSXFDC.cc,v 1.46 2006/04/12 17:59:55 m9710797 Exp $
+// $Id: MSXFDC.cc 6131 2007-03-02 12:00:24Z m9710797 $
 
 #include "MSXFDC.hh"
 #include "Rom.hh"
-#include "DiskDrive.hh"
+#include "RealDrive.hh"
 #include "XMLElement.hh"
 #include "StringOp.hh"
 #include "MSXException.hh"
-#include "MSXMotherBoard.hh"
 
 namespace openmsx {
 
@@ -25,18 +24,10 @@ MSXFDC::MSXFDC(MSXMotherBoard& motherBoard, const XMLElement& config,
 	for ( ; i < numDrives; ++i) {
 		if (singleSided) {
 			drives[i].reset(new SingleSidedDrive(
-				getMotherBoard().getCommandController(),
-				getMotherBoard().getEventDistributor(),
-				getMotherBoard().getScheduler(),
-				getMotherBoard().getFileManipulator(),
-				time));
+				getMotherBoard(), time));
 		} else {
 			drives[i].reset(new DoubleSidedDrive(
-				getMotherBoard().getCommandController(),
-				getMotherBoard().getEventDistributor(),
-				getMotherBoard().getScheduler(),
-				getMotherBoard().getFileManipulator(),
-				time));
+				getMotherBoard(), time));
 		}
 	}
 	for ( ; i < 4; ++i) {
