@@ -1,4 +1,4 @@
-// $Id: MSXtar.cc 6274 2007-04-07 21:31:24Z mthuurne $
+// $Id: MSXtar.cc 7401 2007-12-09 21:02:23Z mthuurne $
 
 #include "MSXtar.hh"
 #include "ReadDir.hh"
@@ -12,6 +12,7 @@
 #include <utime.h>
 #include <unistd.h>
 #include <cstdlib>
+#include <cstring>
 #include <algorithm>
 #include <cassert>
 
@@ -49,11 +50,11 @@ static inline void setlg(byte* x, unsigned y)
 }
 
 // functions to read DirEntries
-static inline unsigned rdsh(byte* x)
+static inline unsigned rdsh(const byte* x)
 {
 	return (x[0] << 0) + (x[1] << 8);
 }
-static inline unsigned rdlg(byte* x)
+static inline unsigned rdlg(const byte* x)
 {
 	return (x[0] << 0) + (x[1] << 8) + (x[2] << 16) + (x[3] << 24);
 }
@@ -79,7 +80,7 @@ unsigned MSXtar::sectorToCluster(unsigned sector)
   */
 void MSXtar::parseBootSector(const byte* buf)
 {
-	MSXBootSector* boot = (MSXBootSector*)buf;
+	const MSXBootSector* boot = reinterpret_cast<const MSXBootSector*>(buf);
 	unsigned nbSectors = rdsh(boot->nrsectors);
 	if (nbSectors == 0) { // TODO: check limits more accurately
 		throw MSXException("Illegal number of sectors: " +
@@ -141,7 +142,7 @@ void MSXtar::writeLogicalSector(unsigned sector, const byte* buf)
 {
 	assert(sector < partitionNbSectors);
 	unsigned fatSector = sector - 1;
-	if ((fatSector < (unsigned)sectorsPerFat) && !fatBuffer.empty()) {
+	if ((fatSector < sectorsPerFat) && !fatBuffer.empty()) {
 		// we have a cache and this is a sector of the 1st FAT
 		//   --> update cache
 		memcpy(&fatBuffer[SECTOR_SIZE * fatSector], buf, SECTOR_SIZE);
@@ -155,7 +156,7 @@ void MSXtar::readLogicalSector(unsigned sector, byte* buf)
 {
 	assert(sector < partitionNbSectors);
 	unsigned fatSector = sector - 1;
-	if ((fatSector < (unsigned)sectorsPerFat) && !fatBuffer.empty()) {
+	if ((fatSector < sectorsPerFat) && !fatBuffer.empty()) {
 		// we have a cache and this is a sector of the 1st FAT
 		//   --> read from cache
 		memcpy(buf, &fatBuffer[SECTOR_SIZE * fatSector], SECTOR_SIZE);
@@ -275,7 +276,7 @@ void MSXtar::setBootSector(byte* buf, unsigned nbSectors)
 		nbDirEntry = 112;
 		descriptor = 0xF9;
 	}
-	MSXBootSector* boot = (MSXBootSector*)buf;
+	MSXBootSector* boot = reinterpret_cast<MSXBootSector*>(buf);
 
 	setsh(boot->nrsectors, nbSectors);
 	setsh(boot->nrsides, nbSides);
@@ -309,7 +310,7 @@ void MSXtar::format()
 	}
 	writeLogicalSector(0, sectorbuf);
 
-	MSXBootSector* boot = (MSXBootSector*)sectorbuf;
+	MSXBootSector* boot = reinterpret_cast<MSXBootSector*>(sectorbuf);
 	byte descriptor = boot->descriptor[0];
 
 	// Assign default empty values to disk
@@ -424,7 +425,7 @@ unsigned MSXtar::findUsableIndexInSector(unsigned sector)
 {
 	byte buf[SECTOR_SIZE];
 	readLogicalSector(sector, buf);
-	MSXDirEntry* direntry = (MSXDirEntry*)buf;
+	MSXDirEntry* direntry = reinterpret_cast<MSXDirEntry*>(buf);
 
 	// find a not used (0x00) or delete entry (0xE5)
 	for (unsigned i = 0; i < 16; ++i) {
@@ -433,7 +434,7 @@ unsigned MSXtar::findUsableIndexInSector(unsigned sector)
 			return i;
 		}
 	}
-	return (unsigned)-1;
+	return unsigned(-1);
 }
 
 // This function returns the sector and dirindex for a new directory entry
@@ -451,7 +452,7 @@ MSXtar::DirEntry MSXtar::addEntryToDir(unsigned sector)
 		// add to the root directory
 		for (/* */ ; result.sector <= rootDirLast; result.sector++) {
 			result.index = findUsableIndexInSector(result.sector);
-			if (result.index != (unsigned)-1) {
+			if (result.index != unsigned(-1)) {
 				return result;
 			}
 		}
@@ -461,7 +462,7 @@ MSXtar::DirEntry MSXtar::addEntryToDir(unsigned sector)
 		// add to a subdir
 		while (true) {
 			result.index = findUsableIndexInSector(result.sector);
-			if (result.index != (unsigned)-1) {
+			if (result.index != unsigned(-1)) {
 				return result;
 			}
 			result.sector = getNextSector(result.sector);
@@ -527,7 +528,7 @@ unsigned MSXtar::addSubdir(
 	// load the sector
 	byte buf[SECTOR_SIZE];
 	readLogicalSector(result.sector, buf);
-	MSXDirEntry* direntries = (MSXDirEntry*)buf;
+	MSXDirEntry* direntries = reinterpret_cast<MSXDirEntry*>(buf);
 
 	MSXDirEntry& direntry = direntries[result.index];
 	direntry.attrib = T_MSX_DIR;
@@ -700,13 +701,13 @@ MSXtar::DirEntry MSXtar::findEntryInDir(
 {
 	DirEntry result;
 	result.sector = sector;
+	result.index = 0; // avoid warning (only some gcc versions complain)
 	while (result.sector) {
 		// read sector and scan 16 entries
 		readLogicalSector(result.sector, buf);
-		MSXDirEntry* direntries = (MSXDirEntry*)buf;
+		MSXDirEntry* direntries = reinterpret_cast<MSXDirEntry*>(buf);
 		for (result.index = 0; result.index < 16; ++result.index) {
-			if (string((char*)direntries[result.index].filename, 11)
-			     == name) {
+			if (string(direntries[result.index].filename, 11) == name) {
 				return result;
 			}
 		}
@@ -735,7 +736,7 @@ string MSXtar::addFileToDSK(const string& fullname, unsigned rootSector)
 	byte buf[SECTOR_SIZE];
 	DirEntry dirEntry = addEntryToDir(rootSector);
 	readLogicalSector(dirEntry.sector, buf);
-	MSXDirEntry* direntries = (MSXDirEntry*)buf;
+	MSXDirEntry* direntries = reinterpret_cast<MSXDirEntry*>(buf);
 	MSXDirEntry& direntry = direntries[dirEntry.index];
 	memset(&direntry, 0, sizeof(MSXDirEntry));
 	memcpy(&direntry, msxName.c_str(), 11);
@@ -779,7 +780,7 @@ string MSXtar::recurseDirFill(const string& dirName, unsigned sector)
 			DirEntry direntry = findEntryInDir(msxFileName, sector, buf);
 			if (direntry.sector != 0) {
 				// entry already exists ..
-				MSXDirEntry* direntries = (MSXDirEntry*)buf;
+				MSXDirEntry* direntries = reinterpret_cast<MSXDirEntry*>(buf);
 				MSXDirEntry& msxdirentry = direntries[direntry.index];
 				if (msxdirentry.attrib & T_MSX_DIR) {
 					// .. and is a directory
@@ -825,12 +826,13 @@ void MSXtar::changeTime(string resultFile, MSXDirEntry& direntry)
 	unsigned d = rdsh(direntry.date);
 	struct tm mtim;
 	struct utimbuf utim;
-	mtim.tm_sec  =  (t & 0x001f) << 1;
-	mtim.tm_min  =  (t & 0x03e0) >> 5;
-	mtim.tm_hour =  (t & 0xf800) >> 11;
-	mtim.tm_mday =  (d & 0x001f);
-	mtim.tm_mon  =  (d & 0x01e0) >> 5;
-	mtim.tm_year = ((d & 0xfe00) >> 9) + 80;
+	mtim.tm_sec   =  (t & 0x001f) << 1;
+	mtim.tm_min   =  (t & 0x07e0) >> 5;
+	mtim.tm_hour  =  (t & 0xf800) >> 11;
+	mtim.tm_mday  =  (d & 0x001f);
+	mtim.tm_mon   = ((d & 0x01e0) >> 5) - 1;
+	mtim.tm_year  = ((d & 0xfe00) >> 9) + 80;
+	mtim.tm_isdst = -1;
 	utim.actime  = mktime(&mtim);
 	utim.modtime = mktime(&mtim);
 	utime(resultFile.c_str(), &utim);
@@ -842,10 +844,10 @@ string MSXtar::dir()
 	for (unsigned sector = chrootSector; sector != 0; sector = getNextSector(sector)) {
 		byte buf[SECTOR_SIZE];
 		readLogicalSector(sector, buf);
-		MSXDirEntry* direntry = (MSXDirEntry*)buf;
+		MSXDirEntry* direntry = reinterpret_cast<MSXDirEntry*>(buf);
 		for (unsigned i = 0; i < 16; ++i) {
-			if ((direntry[i].filename[0] != 0xe5) &&
-			    (direntry[i].filename[0] != 0x00) &&
+			if ((direntry[i].filename[0] != char(0xe5)) &&
+			    (direntry[i].filename[0] != char(0x00)) &&
 			    (direntry[i].attrib != T_MSX_LFN)) {
 				// filename first (in condensed form for human readablitly)
 				string tmp = condensName(direntry[i]);
@@ -909,7 +911,7 @@ void MSXtar::chroot(const string& newRootDir, bool createDir)
 			getTimeDate(now, t, d);
 			chrootSector = addSubdir(simple, t, d, chrootSector);
 		} else {
-			MSXDirEntry* direntries = (MSXDirEntry*)buf;
+			MSXDirEntry* direntries = reinterpret_cast<MSXDirEntry*>(buf);
 			MSXDirEntry& direntry = direntries[entry.index];
 			if (!(direntry.attrib & T_MSX_DIR)) {
 				throw MSXException(firstpart + " is not a directory.");
@@ -946,10 +948,10 @@ void MSXtar::recurseDirExtract(const string& dirName, unsigned sector)
 	for (/* */ ; sector != 0; sector = getNextSector(sector)) {
 		byte buf[SECTOR_SIZE];
 		readLogicalSector(sector, buf);
-		MSXDirEntry* direntry = (MSXDirEntry*)buf;
+		MSXDirEntry* direntry = reinterpret_cast<MSXDirEntry*>(buf);
 		for (unsigned i = 0; i < 16; ++i) {
-			if ((direntry[i].filename[0] != 0xe5) &&
-			    (direntry[i].filename[0] != 0x00) &&
+			if ((direntry[i].filename[0] != char(0xe5)) &&
+			    (direntry[i].filename[0] != char(0x00)) &&
 			    (direntry[i].filename[0] != '.')) {
 				string filename = condensName(direntry[i]);
 				string fullname = filename;
@@ -978,26 +980,24 @@ static const char* const PARTAB_HEADER= "\353\376\220MSX_IDE ";
   */
 static bool isPartitionTableSector(byte* buf)
 {
-	return strncmp((char*)buf, PARTAB_HEADER, 11) == 0;
+	return memcmp(buf, PARTAB_HEADER, 11) == 0;
 }
 
 bool MSXtar::hasPartitionTable()
 {
 	byte buf[SECTOR_SIZE];
-	assert(partitionOffset == 0);
-	readLogicalSector(0, buf);
+	disk.readLogicalSector(0, buf);
 	return isPartitionTableSector(buf);
 }
 
 bool MSXtar::hasPartition(unsigned partition)
 {
 	byte buf[SECTOR_SIZE];
-	assert(partitionOffset == 0);
-	readLogicalSector(0, buf);
+	disk.readLogicalSector(0, buf);
 	if (!isPartitionTableSector(buf)) {
 		return false;
 	}
-	Partition* p = (Partition*)(buf + 14 + (30 - partition) * 16);
+	Partition* p = reinterpret_cast<Partition*>(buf + 14 + (30 - partition) * 16);
 	if (rdlg(p->start4) == 0) {
 		return false;
 	}
@@ -1011,10 +1011,10 @@ bool MSXtar::usePartition(unsigned partition)
 	byte partitionTable[SECTOR_SIZE];
 	partitionOffset = 0;
 	partitionNbSectors = disk.getNbSectors();
-	readLogicalSector(0, partitionTable);
+	disk.readLogicalSector(0, partitionTable);
 	bool hasPartitionTable = isPartitionTableSector(partitionTable);
 	if (hasPartitionTable) {
-		Partition* p = (Partition*)
+		Partition* p = reinterpret_cast<Partition*>
 			(partitionTable + 14 + (30 - partition) * 16);
 		if (rdlg(p->start4) != 0) {
 			partitionOffset = rdlg(p->start4);
@@ -1028,7 +1028,7 @@ bool MSXtar::usePartition(unsigned partition)
 	}
 
 	byte bootSector[SECTOR_SIZE];
-	readLogicalSector(0, bootSector);
+	disk.readLogicalSector(partitionOffset, bootSector);
 	parseBootSectorFAT(bootSector);
 	return hasPartitionTable;
 }
@@ -1054,13 +1054,14 @@ void MSXtar::createDiskFile(std::vector<unsigned> sizes)
 	// create the partition table if needed
 	if (sizes.size() > 1) {
 		memset(buf, 0, SECTOR_SIZE);
-		strncpy((char*)buf, PARTAB_HEADER, 11);
+		memcpy(buf, PARTAB_HEADER, 11);
 		buf[SECTOR_SIZE - 2] = 0x55;
 		buf[SECTOR_SIZE - 1] = 0xAA;
 
 		partitionOffset = 1;
 		for (unsigned i = 0; (i < sizes.size()) && (i < 30); ++i) {
-			Partition* p = (Partition*)(buf + (14 + (30 - i) * 16));
+			Partition* p = reinterpret_cast<Partition*>
+				(buf + (14 + (30 - i) * 16));
 			unsigned startCylinder, startHead, startSector;
 			unsigned endCylinder, endHead, endSector;
 			logicalToCHS(partitionOffset,
