@@ -1,7 +1,7 @@
-// $Id: PhilipsFDC.cc,v 1.29 2005/11/12 20:32:42 m9710797 Exp $
+// $Id: PhilipsFDC.cc 6023 2007-01-29 21:16:49Z m9710797 $
 
 #include "PhilipsFDC.hh"
-#include "CPU.hh"
+#include "CacheLine.hh"
 #include "DriveMultiplexer.hh"
 #include "WD2793.hh"
 #include "XMLElement.hh"
@@ -54,6 +54,11 @@ byte PhilipsFDC::readMem(word address, const EmuTime& time)
 byte PhilipsFDC::peekMem(word address, const EmuTime& time) const
 {
 	byte value;
+	// FDC registers are mirrored in
+	//   0x3FF8-0x3FFF
+	//   0x7FF8-0x7FFF
+	//   0xBFF8-0xBFFF
+	//   0xFFF8-0xFFFF
 	switch (address & 0x3FFF) {
 	case 0x3FF8:
 		value = controller->peekStatusReg(time);
@@ -99,8 +104,8 @@ byte PhilipsFDC::peekMem(word address, const EmuTime& time) const
 		break;
 
 	default:
-		if (address < 0x8000) {
-			// ROM only visible in 0x0000-0x7FFF
+		if ((0x4000 <= address) && (address < 0x8000)) {
+			// ROM only visible in 0x4000-0x7FFF
 			value = MSXFDC::peekMem(address, time);
 		} else {
 			value = 255;
@@ -116,11 +121,10 @@ const byte* PhilipsFDC::getReadCacheLine(word start) const
 {
 	// if address overlap 0x7ff8-0x7ffb then return NULL,
 	// else normal ROM behaviour
-	if ((start & 0x3FF8 & CPU::CACHE_LINE_HIGH) ==
-	    (0x3FF8 & CPU::CACHE_LINE_HIGH)) {
+	if ((start & 0x3FF8 & CacheLine::HIGH) == (0x3FF8 & CacheLine::HIGH)) {
 		return NULL;
-	} else if (start < 0x8000) {
-		// ROM visible in 0x0000-0x7FFF
+	} else if ((0x4000 <= start) && (start < 0x8000)) {
+		// ROM visible in 0x4000-0x7FFF
 		return MSXFDC::getReadCacheLine(start);
 	} else {
 		return unmappedRead;
@@ -178,7 +182,7 @@ void PhilipsFDC::writeMem(word address, byte value, const EmuTime& time)
 
 byte* PhilipsFDC::getWriteCacheLine(word address) const
 {
-	if ((address & 0x3FF8) == (0x3FF8 & CPU::CACHE_LINE_HIGH)) {
+	if ((address & 0x3FF8) == (0x3FF8 & CacheLine::HIGH)) {
 		return NULL;
 	} else {
 		return unmappedWrite;
