@@ -1,4 +1,4 @@
-// $Id: RamDSKDiskImage.cc,v 1.7 2006/02/06 21:05:40 m9710797 Exp $
+// $Id: RamDSKDiskImage.cc 5811 2006-10-25 21:52:34Z manuelbi $
 
 #include "RamDSKDiskImage.hh"
 #include "MSXtar.hh"
@@ -7,7 +7,7 @@
 namespace openmsx {
 
 RamDSKDiskImage::RamDSKDiskImage(unsigned size)
-	: SectorBasedDisk("-ramdsk")
+	: SectorBasedDisk("ramdsk")
 {
 	nbSectors = size / SECTOR_SIZE;
 	diskdata = new byte[size];
