@@ -1,4 +1,4 @@
-// $Id: TurboRFDC.cc,v 1.26 2005/09/12 17:09:23 m9710797 Exp $
+// $Id: TurboRFDC.cc 6000 2007-01-13 16:13:29Z m9710797 $
 
 /*
  * Based on code from NLMSX written by Frits Hilderink
@@ -9,7 +9,7 @@
 #include "Rom.hh"
 #include "MSXCPU.hh"
 #include "MSXMotherBoard.hh"
-#include "CPU.hh"
+#include "CacheLine.hh"
 
 namespace openmsx {
 
@@ -55,6 +55,8 @@ byte TurboRFDC::readMem(word address, const EmuTime& time)
 			result = peekMem(address, time);
 			break;
 		}
+		//std::cout << "TurboRFDC read 0x" << std::hex << (int)address <<
+		//                           " 0x" << (int)result << std::dec << std::endl;
 	} else {
 		result = peekMem(address, time);
 	}
@@ -93,13 +95,12 @@ byte TurboRFDC::peekMem(word address, const EmuTime& time) const
 	} else {
 		result = 0xFF;
 	}
-	//PRT_DEBUG("TurboRFDC: read 0x" << hex << (int)address << " 0x" << (int)result << dec);
 	return result;
 }
 
 const byte* TurboRFDC::getReadCacheLine(word start) const
 {
-	if ((start & 0x3FF0) == (0x3FF0 & CPU::CACHE_LINE_HIGH)) {
+	if ((start & 0x3FF0) == (0x3FF0 & CacheLine::HIGH)) {
 		return NULL;
 	} else if ((0x4000 <= start) && (start < 0x8000)) {
 		return &memory[start & 0x3FFF];
@@ -110,12 +111,13 @@ const byte* TurboRFDC::getReadCacheLine(word start) const
 
 void TurboRFDC::writeMem(word address, byte value, const EmuTime& time)
 {
-	//PRT_DEBUG("TurboRFDC: write 0x" << hex << (int)address << " 0x" << (int)value << dec);
 	if ((address == 0x6000) || (address == 0x7FF0) || (address == 0x7FFE)) {
 		getMotherBoard().getCPU().invalidateMemCache(0x4000, 0x4000);
 		memory = &(*rom)[0x4000 * (value & blockMask)];
 		return;
 	} else {
+		//std::cout << "TurboRFDC write 0x" << std::hex << (int)address <<
+		//                            " 0x" << (int)value << std::dec << std::endl;
 		switch (address & 0x3FFF) {
 		case 0x3FF2:
 		case 0x3FF8:
@@ -147,10 +149,10 @@ void TurboRFDC::writeMem(word address, byte value, const EmuTime& time)
 
 byte* TurboRFDC::getWriteCacheLine(word address) const
 {
-	if ((address == (0x6000 & CPU::CACHE_LINE_HIGH)) ||
-	    (address == (0x7FF0 & CPU::CACHE_LINE_HIGH)) ||
-	    (address == (0x7FFE & CPU::CACHE_LINE_HIGH)) ||
-	    ((address & 0x3FF0) == (0x3FF0 & CPU::CACHE_LINE_HIGH))) {
+	if ((address == (0x6000 & CacheLine::HIGH)) ||
+	    (address == (0x7FF0 & CacheLine::HIGH)) ||
+	    (address == (0x7FFE & CacheLine::HIGH)) ||
+	    ((address & 0x3FF0) == (0x3FF0 & CacheLine::HIGH))) {
 		return NULL;
 	} else {
 		return unmappedWrite;
