@@ -1,4 +1,4 @@
-// $Id: WD2793.cc 5071 2006-01-23 19:35:27Z m9710797 $
+// $Id: WD2793.cc 6805 2007-08-06 12:01:49Z m9710797 $
 
 #include "WD2793.hh"
 #include "DiskDrive.hh"
@@ -748,7 +748,7 @@ void WD2793::startType4Cmd(const EmuTime& time)
 	byte flags = commandReg & 0x0F;
 	if (flags & (N2R_IRQ | R2N_IRQ)) {
 		// all flags not yet supported
-		PRT_DEBUG("WD2793 type 4 cmd, unimplemented bits " << (int)flags);
+		PRT_DEBUG("WD2793 type 4 cmd, unimplemented bits " << int(flags));
 	}
 
 	if (flags == 0x00) {
