@@ -1,4 +1,4 @@
-// $Id: XSADiskImage.cc 5146 2006-02-06 21:05:40Z m9710797 $
+// $Id: XSADiskImage.cc 6445 2007-05-08 08:15:41Z m9710797 $
 
 #include "XSADiskImage.hh"
 #include "File.hh"
@@ -86,7 +86,7 @@ void XSADiskImage::chkheader()
 	outbufpos = outbuf;
 
 	// skip original filename
-	while (charin());
+	while (charin()) /*empty*/;
 }
 
 // the actual decompression algorithm itself
@@ -134,7 +134,7 @@ int XSADiskImage::rdstrlen()
 // read string pos
 int XSADiskImage::rdstrpos()
 {
-	huf_node *hufpos = &huftbl[2*TBLSIZE - 2];
+	HufNode* hufpos = &huftbl[2*TBLSIZE - 2];
 
 	while (hufpos->child1) {
 		if (bitin()) {
@@ -202,7 +202,7 @@ void XSADiskImage::inithufinfo()
 void XSADiskImage::mkhuftbl()
 {
 	// Initialize the huffman tree
-	huf_node *hufpos = huftbl;
+	HufNode* hufpos = huftbl;
 	for (int i = 0; i != TBLSIZE; ++i) {
 		(hufpos++)->weight = 1+(tblsizes[i] >>= 1);
 	}
@@ -211,7 +211,8 @@ void XSADiskImage::mkhuftbl()
 	}
 	// Place the nodes in the correct manner in the tree
 	while (huftbl[2*TBLSIZE-2].weight == -1) {
-		huf_node  *l1pos, *l2pos;
+		HufNode* l1pos;
+		HufNode* l2pos;
 		for (hufpos=huftbl; !(hufpos->weight); ++hufpos) {
 			// nothing
 		}
