@@ -1,4 +1,4 @@
-// $Id: CompressedFileAdapter.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: CompressedFileAdapter.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 #include <sys/types.h>
 #include <unistd.h>
@@ -25,7 +25,7 @@ string CompressedFileAdapter::tmpDir;
 
 
 CompressedFileAdapter::CompressedFileAdapter(auto_ptr<FileBase> file_)
-	: file(file_), buf(0), pos(0), localName(0)
+	: file(file_), buf(0), localName(0), pos(0)
 {
 }
 
@@ -52,14 +52,14 @@ void CompressedFileAdapter::fillBuffer()
 	}
 }
 
-void CompressedFileAdapter::read(byte* buffer, unsigned num)
+void CompressedFileAdapter::read(void* buffer, unsigned num)
 {
 	fillBuffer();
 	memcpy(buffer, &buf[pos], num);
 	pos += num;
 }
 
-void CompressedFileAdapter::write(const byte* /*buffer*/, unsigned /*num*/)
+void CompressedFileAdapter::write(const void* /*buffer*/, unsigned /*num*/)
 {
 	throw FileException("Writing to compressed files not yet supported");
 }
