@@ -1,4 +1,4 @@
-// $Id: File.cc 5076 2006-01-25 19:26:32Z m9710797 $
+// $Id: File.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "File.hh"
 #include "FileBase.hh"
@@ -53,12 +53,12 @@ File::~File()
 {
 }
 
-void File::read(byte* buffer, unsigned num)
+void File::read(void* buffer, unsigned num)
 {
 	file->read(buffer, num);
 }
 
-void File::write(const byte* buffer, unsigned num)
+void File::write(const void* buffer, unsigned num)
 {
 	file->write(buffer, num);
 }
