@@ -1,7 +1,8 @@
-// $Id: FileBase.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: FileBase.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "FileBase.hh"
 #include <algorithm>
+#include <cstring>
 
 using std::string;
 
@@ -22,10 +23,10 @@ byte* FileBase::mmap(bool writeBack)
 	if (!mmem) {
 		mmapWrite = writeBack;
 		mmapSize = getSize();
-		mmem = new byte[mmapSize];
+		mmem = malloc(mmapSize);
 		read(mmem, mmapSize);
 	}
-	return mmem;
+	return static_cast<byte*>(mmem);
 }
 
 void FileBase::munmap()
@@ -35,7 +36,7 @@ void FileBase::munmap()
 			seek(0);
 			write(mmem, mmapSize);
 		}
-		delete[] mmem;
+		free(mmem);
 		mmem = NULL;
 	}
 }
