@@ -1,4 +1,4 @@
-// $Id: FileOperations.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: FileOperations.cc 6824 2007-08-08 15:20:19Z m9710797 $
 
 #ifdef	_WIN32
 #define WIN32_LEAN_AND_MEAN
@@ -26,7 +26,6 @@
 #include "build-info.hh"
 #include "FileOperations.hh"
 #include "FileException.hh"
-#include "openmsx.hh"
 #include "StringOp.hh"
 #include <sstream>
 #include <cerrno>
@@ -283,7 +282,7 @@ string getUserHomeDir(const string& username)
 			FARPROC funcp = GetProcAddress(sh32dll, "SHGetSpecialFolderPathA");
 			if (funcp) {
 				char p[MAX_PATH + 1];
-				int res = ((BOOL(*)(HWND, LPSTR, int, BOOL))funcp)(0, p, CSIDL_PERSONAL, 1);
+				int res = reinterpret_cast<BOOL(*)(HWND, LPSTR, int, BOOL)>(funcp)(0, p, CSIDL_PERSONAL, 1);
 				if (res == TRUE) {
 					userDir = getConventionalPath(p);
 				}
@@ -414,10 +413,10 @@ bool exists(const string& filename)
 }
 
 static int getNextNum(dirent* d, const string& prefix, const string& extension,
-                      const unsigned int nofdigits)
+                      const unsigned nofdigits)
 {
-	const unsigned int extensionlen = extension.length();
-	const unsigned int prefixlen = prefix.length();
+	const unsigned extensionlen = extension.length();
+	const unsigned prefixlen = prefix.length();
 	string name(d->d_name);
 
 	if ((name.length() != (prefixlen + nofdigits + extensionlen)) ||
@@ -437,7 +436,7 @@ static int getNextNum(dirent* d, const string& prefix, const string& extension,
 string getNextNumberedFileName(
 	const string& directory, const string& prefix, const string& extension)
 {
-	const unsigned int nofdigits = 4;
+	const unsigned nofdigits = 4;
 
 	int max_num = 0;
 
