@@ -1,4 +1,4 @@
-// $Id: ReadDir.cc,v 1.4 2006/05/28 19:19:29 m9710797 Exp $
+// $Id: ReadDir.cc 5945 2006-12-19 19:20:18Z m9710797 $
 
 #include "ReadDir.hh"
 
@@ -24,4 +24,9 @@ struct dirent* ReadDir::getEntry()
 	return readdir(dir);
 }
 
+bool ReadDir::isValid() const
+{
+	return dir;
+}
+
 } // namespace openmsx
