@@ -1,4 +1,4 @@
-// $Id: AbstractIDEDevice.cc 5975 2007-01-05 13:44:57Z m9710797 $
+// $Id: AbstractIDEDevice.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "AbstractIDEDevice.hh"
 #include "MSXMotherBoard.hh"
@@ -186,8 +186,7 @@ word AbstractIDEDevice::readData(const EmuTime& /*time*/)
 void AbstractIDEDevice::readNextBlock()
 {
 	bufferLeft = readBlockStart(
-		buffer, std::min(static_cast<unsigned>(sizeof(buffer)), transferCount)
-		);
+		buffer, std::min<unsigned>(sizeof(buffer), transferCount));
 	assert((bufferLeft & 1) == 0);
 	transferPntr = buffer;
 	transferCount -= bufferLeft;
@@ -222,7 +221,7 @@ void AbstractIDEDevice::writeData(word value, const EmuTime& /*time*/)
 void AbstractIDEDevice::writeNextBlock()
 {
 	transferPntr = buffer;
-	bufferLeft = std::min(static_cast<unsigned>(sizeof(buffer)), transferCount);
+	bufferLeft = std::min<unsigned>(sizeof(buffer), transferCount);
 	transferCount -= bufferLeft;
 }
 
