@@ -1,8 +1,9 @@
-// $Id: CDImageCLI.cc,v 1.1 2006/05/31 19:24:12 m9710797 Exp $
+// $Id: CDImageCLI.cc 5779 2006-10-14 16:17:32Z m9710797 $
 
 #include "CDImageCLI.hh"
 #include "Reactor.hh"
 #include "CommandController.hh"
+#include "CommandLineParser.hh"
 #include "TclObject.hh"
 #include "MSXException.hh"
 
@@ -14,7 +15,7 @@ namespace openmsx {
 CDImageCLI::CDImageCLI(CommandLineParser& commandLineParser)
 	: commandController(commandLineParser.getReactor().getCommandController())
 {
-	commandLineParser.registerOption("-cda", this);
+	commandLineParser.registerOption("-cda", *this);
 	// TODO: offer more options in case you want to specify 2 hard disk images?
 }
 
@@ -22,7 +23,7 @@ bool CDImageCLI::parseOption(const string& option, list<string>& cmdLine)
 {
 	string cd = option.substr(1); // cda
 	string filename = getArgument(option, cmdLine);
-	if (!commandController.hasCommand(cd)) {
+	if (!commandController.hasCommand(cd)) { // TODO WIP
 		throw MSXException("No CDROM named '" + cd + "'.");
 	}
 	TclObject command(commandController.getInterpreter());
