@@ -1,4 +1,4 @@
-// $Id: HDImageCLI.cc 5779 2006-10-14 16:17:32Z m9710797 $
+// $Id: HDImageCLI.cc 6572 2007-06-01 22:09:15Z manuelbi $
 
 #include "HDImageCLI.hh"
 #include "Reactor.hh"
@@ -34,7 +34,7 @@ bool HDImageCLI::parseOption(const string& option, list<string>& cmdLine)
 }
 const string& HDImageCLI::optionHelp() const
 {
-	static const string text("Use hard disk image in argument for the IDE extension");
+	static const string text("Use hard disk image in argument for the IDE or SCSI extensions");
 	return text;
 }
 
