@@ -1,4 +1,4 @@
-// $Id: Joystick.cc 6088 2007-02-16 20:38:53Z m9710797 $
+// $Id: Joystick.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 #include "Joystick.hh"
 #include "PluggingController.hh"
@@ -27,19 +27,21 @@ void Joystick::registerAll(MSXEventDistributor& eventDistributor,
 
 Joystick::Joystick(MSXEventDistributor& eventDistributor_, unsigned joyNum_)
 	: eventDistributor(eventDistributor_)
+	, name(string("joystick") + char('1' + joyNum_))
+	, desc(string(SDL_JoystickName(joyNum_)))
+	, joystick(SDL_JoystickOpen(joyNum_))
 	, joyNum(joyNum_)
-	, joystick(0)
 {
-	PRT_DEBUG("Creating a Joystick object for joystick " << joyNum);
-	assert(joyNum < (unsigned)SDL_NumJoysticks());
-	name = string("joystick") + (char)('1' + joyNum);
-	desc = string(SDL_JoystickName(joyNum));
 }
 
 Joystick::~Joystick()
 {
+	if (getConnector()) {
+		// still plugged in
+		eventDistributor.unregisterEventListener(*this);
+	}
 	if (joystick) {
-		closeJoystick();
+		SDL_JoystickClose(joystick);
 	}
 }
 
@@ -56,8 +58,6 @@ const string& Joystick::getDescription() const
 
 void Joystick::plugHelper(Connector& /*connector*/, const EmuTime& /*time*/)
 {
-	PRT_DEBUG("Opening joystick " << SDL_JoystickName(joyNum));
-	joystick = SDL_JoystickOpen(joyNum);
 	if (!joystick) {
 		throw PlugException("Failed to open joystick device");
 	}
@@ -69,15 +69,8 @@ void Joystick::plugHelper(Connector& /*connector*/, const EmuTime& /*time*/)
 }
 
 void Joystick::unplugHelper(const EmuTime& /*time*/)
-{
-	closeJoystick();
-}
-
-void Joystick::closeJoystick()
 {
 	eventDistributor.unregisterEventListener(*this);
-	SDL_JoystickClose(joystick);
-	joystick = 0;
 }
 
 
