@@ -1,4 +1,4 @@
-// $Id: Keyboard.cc 5779 2006-10-14 16:17:32Z m9710797 $
+// $Id: Keyboard.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include <cstdio>
 #include <cstdlib>
@@ -69,8 +69,8 @@ private:
 	virtual const string& schedName() const;
 
 	Keyboard& keyboard;
-	char last;
 	string text;
+	char last;
 };
 
 
@@ -190,8 +190,8 @@ void Keyboard::signalEvent(shared_ptr<const Event> event,
 		// an unwanted pressing of <return> in MSX after typing
 		// "set console off" in the console.
 		const KeyEvent& keyEvent = checked_cast<const KeyEvent&>(*event);
-		Keys::KeyCode key = (Keys::KeyCode)
-			((int)keyEvent.getKeyCode() & (int)Keys::K_MASK);
+		Keys::KeyCode key = static_cast<Keys::KeyCode>
+			(int(keyEvent.getKeyCode()) & int(Keys::K_MASK));
 		if (key != Keys::K_CAPSLOCK) {
 			processKey(type == OPENMSX_KEY_DOWN_EVENT, key);
 		} else {
