@@ -1,4 +1,4 @@
-// $Id: SETetrisDongle.cc 4836 2005-11-11 20:53:06Z m9710797 $
+// $Id: SETetrisDongle.cc 7309 2007-11-25 09:18:04Z m9710797 $
 
 #include "SETetrisDongle.hh"
 
@@ -13,14 +13,14 @@ SETetrisDongle::SETetrisDongle()
 //Pluggable
 const std::string& SETetrisDongle::getName() const
 {
-	static const std::string NAME = "tetris2-protection";
-	return NAME;
+	static const std::string name = "tetris2-protection";
+	return name;
 }
 
 const std::string& SETetrisDongle::getDescription() const
 {
-	static const std::string DESC = "SETetrisDongledongle";
-	return DESC;
+	static const std::string desc = "Tetris II Special Edition dongle";
+	return desc;
 }
 
 void SETetrisDongle::plugHelper(
