@@ -1,4 +1,4 @@
-// $Id: main.cc 5854 2006-11-06 18:24:21Z m9710797 $
+// $Id: main.cc 7371 2007-12-08 04:52:22Z mthuurne $
 
 /*
  *  openmsx - the MSX emulator that aims for perfection
@@ -39,6 +39,14 @@ static void initializeSDL()
 	if (SDL_Init(flags) < 0) {
 		throw FatalError(string("Couldn't init SDL: ") + SDL_GetError());
 	}
+
+// In SDL 1.2.9 and before SDL_putenv has different semantics and is not
+// guaranteed to exist on all platforms.
+#if SDL_VERSION_ATLEAST(1, 2, 10)
+	// On Mac OS X, send key combos like Cmd+H and Cmd+M to Cocoa, so it can
+	// perform the corresponding actions.
+	SDL_putenv(const_cast<char*>("SDL_ENABLEAPPEVENTS=1"));
+#endif
 }
 
 static void unexpectedExceptionHandler()
