@@ -1,4 +1,4 @@
-// $Id: CheckedRam.cc 5751 2006-10-05 19:34:54Z m9710797 $
+// $Id: CheckedRam.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "CheckedRam.hh"
 #include "Ram.hh"
@@ -99,7 +99,7 @@ void CheckedRam::callUMRCallBack(unsigned addr)
 	if (!callback.empty()) {
 		TclObject command(commandController.getInterpreter());
 		command.addListElement(callback);
-		command.addListElement(static_cast<int>(addr));
+		command.addListElement(int(addr));
 		command.addListElement(ram.get()->getName());
 		try {
 			command.executeCommand();
