@@ -1,4 +1,4 @@
-// $Id: MSXMegaRam.cc,v 1.28 2006/03/06 03:08:24 mthuurne Exp $
+// $Id: MSXMegaRam.cc 5614 2006-09-07 21:43:54Z manuelbi $
 
 /*
  * Adriano Camargo Rodrigues da Cunha wrote:
@@ -30,26 +30,18 @@
 #include "MSXMotherBoard.hh"
 #include "Ram.hh"
 #include "Rom.hh"
+#include "Math.hh"
 
 
 namespace openmsx {
 
-static int roundUpPow2(int a)
-{
-	int result = 1;
-	while (a > result) {
-		result <<= 1;
-	}
-	return result;
-}
-
 MSXMegaRam::MSXMegaRam(MSXMotherBoard& motherBoard, const XMLElement& config,
                        const EmuTime& time)
 	: MSXDevice(motherBoard, config, time)
 {
 	int size = config.getChildDataAsInt("size");
 	numBlocks = size / 8;	// 8kb blocks
-	maskBlocks = roundUpPow2(numBlocks) - 1;
+	maskBlocks = Math::powerOfTwo(numBlocks) - 1;
 	ram.reset(new Ram(motherBoard, getName() + " RAM", "Mega-RAM",
 	                  numBlocks * 0x2000));
 	if (config.findChild("rom")) {
