@@ -1,4 +1,4 @@
-// $Id: PanasonicMemory.cc 5993 2007-01-12 22:12:12Z m9710797 $
+// $Id: PanasonicMemory.cc 6366 2007-04-24 19:05:58Z m9710797 $
 
 #include "PanasonicMemory.hh"
 #include "MSXMotherBoard.hh"
@@ -17,10 +17,10 @@ static const XMLElement& getRomConfig(MSXMotherBoard& motherBoard)
 }
 
 PanasonicMemory::PanasonicMemory(MSXMotherBoard& motherBoard)
-	: rom(new Rom(motherBoard, "PanasonicRom", "Turbo-R main ROM",
+	: msxcpu(motherBoard.getCPU())
+	, rom(new Rom(motherBoard, "PanasonicRom", "Turbo-R main ROM",
 	              getRomConfig(motherBoard)))
 	, ram(NULL), dram(false)
-	, msxcpu(motherBoard.getCPU())
 {
 }
 
