@@ -1,8 +1,8 @@
-// $Id: RomCrossBlaim.cc,v 1.12 2005/11/12 21:53:20 m9710797 Exp $
+// $Id: RomCrossBlaim.cc 5751 2006-10-05 19:34:54Z m9710797 $
 
 #include "RomCrossBlaim.hh"
 #include "Rom.hh"
-#include "CPU.hh"
+#include "CacheLine.hh"
 
 namespace openmsx {
 
@@ -31,7 +31,7 @@ void RomCrossBlaim::writeMem(word address, byte value, const EmuTime& /*time*/)
 
 byte* RomCrossBlaim::getWriteCacheLine(word address) const
 {
-	if (address == (0x4045 & CPU::CACHE_LINE_HIGH)) {
+	if (address == (0x4045 & CacheLine::HIGH)) {
 		return NULL;
 	} else {
 		return unmappedWrite;
