@@ -1,4 +1,4 @@
-// $Id: RomFactory.cc 5818 2006-10-29 19:08:39Z m9710797 $
+// $Id: RomFactory.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "RomFactory.hh"
 #include "RomTypes.hh"
@@ -10,11 +10,14 @@
 #include "RomGeneric16kB.hh"
 #include "RomKonami4.hh"
 #include "RomKonami5.hh"
+#include "RomKonamiKeyboardMaster.hh"
 #include "RomAscii8kB.hh"
 #include "RomAscii8_8.hh"
 #include "RomAscii16kB.hh"
 #include "RomPadial8kB.hh"
 #include "RomPadial16kB.hh"
+#include "RomSuperLodeRunner.hh"
+#include "RomMSXDOS2.hh"
 #include "RomHydlide2.hh"
 #include "RomRType.hh"
 #include "RomCrossBlaim.hh"
@@ -78,7 +81,7 @@ static RomType guessRomType(const Rom& rom)
 		//  with this instruction to the mapper-registers-addresses
 		//  occur.
 
-		unsigned int typeGuess[] = {0,0,0,0,0,0};
+		unsigned typeGuess[] = {0,0,0,0,0,0};
 		for (int i=0; i<size-3; i++) {
 			if (data[i] == 0x32) {
 				word value = data[i+1]+(data[i+2]<<8);
@@ -119,7 +122,7 @@ static RomType guessRomType(const Rom& rom)
 		RomType type = ROM_GENERIC_8KB; // 0
 		for (int i=ROM_GENERIC_8KB; i <= ROM_ASCII16; i++) {
 			if ((typeGuess[i]) && (typeGuess[i]>=typeGuess[type])) {
-				type = (RomType)i;
+				type = static_cast<RomType>(i);
 			}
 		}
 		// in case of doubt we go for type 0
@@ -217,6 +220,9 @@ auto_ptr<MSXDevice> RomFactory::create(
 	case ROM_KONAMI:
 		return auto_ptr<MSXDevice>(
 			new RomKonami4(motherBoard, config, time, rom));
+	case ROM_KBDMASTER:
+		return auto_ptr<MSXDevice>(
+			new RomKonamiKeyboardMaster(motherBoard, config, time, rom));
 	case ROM_ASCII8:
 		return auto_ptr<MSXDevice>(
 			new RomAscii8kB(motherBoard, config, time, rom));
@@ -229,6 +235,12 @@ auto_ptr<MSXDevice> RomFactory::create(
 	case ROM_PADIAL16:
 		return auto_ptr<MSXDevice>(
 			new RomPadial16kB(motherBoard, config, time, rom));
+	case ROM_SUPERLODERUNNER:
+		return auto_ptr<MSXDevice>(
+			new RomSuperLodeRunner(motherBoard, config, time, rom));
+	case ROM_MSXDOS2:
+		return auto_ptr<MSXDevice>(
+			new RomMSXDOS2(motherBoard, config, time, rom));
 	case ROM_R_TYPE:
 		return auto_ptr<MSXDevice>(
 			new RomRType(motherBoard, config, time, rom));
