@@ -1,7 +1,7 @@
-// $Id: RomHarryFox.cc,v 1.12 2005/11/12 21:53:21 m9710797 Exp $
+// $Id: RomHarryFox.cc 5751 2006-10-05 19:34:54Z m9710797 $
 
 #include "RomHarryFox.hh"
-#include "CPU.hh"
+#include "CacheLine.hh"
 #include "Rom.hh"
 
 namespace openmsx {
@@ -33,8 +33,8 @@ void RomHarryFox::writeMem(word address, byte value, const EmuTime& /*time*/)
 
 byte* RomHarryFox::getWriteCacheLine(word address) const
 {
-	if ((address == (0x6000 & CPU::CACHE_LINE_HIGH)) ||
-	    (address == (0x7000 & CPU::CACHE_LINE_HIGH))) {
+	if ((address == (0x6000 & CacheLine::HIGH)) ||
+	    (address == (0x7000 & CacheLine::HIGH))) {
 		return NULL;
 	} else {
 		return unmappedWrite;
