@@ -1,4 +1,4 @@
-// $Id: RomMajutsushi.cc 5785 2006-10-18 15:57:18Z m9710797 $
+// $Id: RomMajutsushi.cc 6457 2007-05-10 20:53:43Z manuelbi $
 
 // Mapper for "Hai no Majutsushi" from Konami.
 // It's a Konami4 mapper with a DAC.
@@ -14,8 +14,8 @@ RomMajutsushi::RomMajutsushi(
 	MSXMotherBoard& motherBoard, const XMLElement& config,
 	const EmuTime& time, std::auto_ptr<Rom> rom)
 	: RomKonami4(motherBoard, config, time, rom)
-	, dac(new DACSound8U(motherBoard.getMSXMixer(), getName(),
-		"Majutsushi DAC", config, time))
+	, dac(new DACSound8U(motherBoard.getMSXMixer(), "Majutsushi-DAC",
+		"Hai no Majutsushi's DAC", config, time))
 {
 }
 
