@@ -1,4 +1,4 @@
-// $Id: RomSynthesizer.cc 5785 2006-10-18 15:57:18Z m9710797 $
+// $Id: RomSynthesizer.cc 6457 2007-05-10 20:53:43Z manuelbi $
 
 /* On Sat, 3 Apr 2004, Manuel Pazos wrote:
  *
@@ -36,8 +36,8 @@ RomSynthesizer::RomSynthesizer(
 	setRom (2, 1);
 	setBank(3, unmappedRead);
 
-	dac.reset(new DACSound8U(motherBoard.getMSXMixer(), getName(),
-	                         "Konami Synthesizer DAC", config, time));
+	dac.reset(new DACSound8U(motherBoard.getMSXMixer(), "Synthesizer-DAC",
+	                         "Konami Synthesizer's DAC", config, time));
 
 	reset(time);
 }
