@@ -1,4 +1,4 @@
-// $Id: I8254.cc,v 1.13 2006/01/23 19:35:25 m9710797 Exp $
+// $Id: I8254.cc 5975 2007-01-05 13:44:57Z m9710797 $
 
 #include <cassert>
 #include "I8254.hh"
@@ -151,9 +151,11 @@ I8254::Counter::Counter(Scheduler& scheduler, ClockPinListener* listener,
 void I8254::Counter::reset(const EmuTime& time)
 {
 	currentTime = time;
-	ltchCtrl = ltchCntr = false;
-	readOrder = writeOrder = LOW;
-	control = 0x30;	// Write BOTH / mode 0 / binary mode
+	ltchCtrl = false;
+	ltchCntr = false;
+	readOrder  = LOW;
+	writeOrder = LOW;
+	control = 0x30; // Write BOTH / mode 0 / binary mode
 	active = false;
 	counting = true;
 }
