@@ -1,4 +1,4 @@
-// $Id: MidiInNative.cc 5732 2006-10-02 07:00:04Z m9710797 $
+// $Id: MidiInNative.cc 6793 2007-08-04 13:08:55Z m9710797 $
 
 #if defined(_WIN32)
 #include "MidiInNative.hh"
@@ -42,7 +42,7 @@ MidiInNative::MidiInNative(EventDistributor& eventDistributor_,
 {
 	name = w32_midiInGetVFN(num);
 	desc = w32_midiInGetRDN(num);
-	
+
 	eventDistributor.registerEventListener(OPENMSX_MIDI_IN_NATIVE_EVENT, *this);
 }
 
@@ -57,7 +57,7 @@ MidiInNative::~MidiInNative()
 void MidiInNative::plugHelper(Connector& connector_, const EmuTime& time)
 {
 	devidx = w32_midiInOpen(name.c_str(), thrdid);
-	if (devidx == (unsigned)-1) {
+	if (devidx == unsigned(-1)) {
 		throw PlugException("Failed to open " + name);
 	}
 
@@ -141,7 +141,7 @@ void MidiInNative::run()
 				procShortMsg(msg.lParam);
 				break;
 			case MM_MIM_LONGDATA:
-				procLongMsg((LPMIDIHDR)msg.lParam);
+				procLongMsg(reinterpret_cast<LPMIDIHDR>(msg.lParam));
 				break;
 			case MM_MIM_ERROR:
 			case MM_MIM_LONGERROR:
@@ -152,7 +152,7 @@ void MidiInNative::run()
 				break;
 		}
 	}
-	thrdid = (unsigned)NULL;
+	thrdid = 0;
 }
 
 // MidiInDevice
