@@ -1,11 +1,11 @@
-// $Id: MidiInReader.cc 5731 2006-10-01 19:54:47Z m9710797 $
+// $Id: MidiInReader.cc 6564 2007-05-31 17:23:56Z m9710797 $
 
 #include "MidiInReader.hh"
 #include "MidiInConnector.hh"
 #include "EventDistributor.hh"
 #include "Scheduler.hh"
 #include "FilenameSetting.hh"
-#include <cstring>
+#include <cstdio>
 #include <cerrno>
 
 using std::string;
