@@ -1,4 +1,4 @@
-// $Id: MidiOutNative.cc 4836 2005-11-11 20:53:06Z m9710797 $
+// $Id: MidiOutNative.cc 6793 2007-08-04 13:08:55Z m9710797 $
 
 #if defined(_WIN32)
 
@@ -34,7 +34,7 @@ MidiOutNative::~MidiOutNative()
 void MidiOutNative::plugHelper(Connector& connector, const EmuTime& time)
 {
 	devidx = w32_midiOutOpen(name.c_str());
-	if (devidx == (unsigned)-1) {
+	if (devidx == unsigned(-1)) {
 		throw PlugException("Failed to open " + name);
 	}
 }
