@@ -1,7 +1,7 @@
-// $Id: FilenameSetting.cc,v 1.16 2005/12/08 21:06:36 m9710797 Exp $
+// $Id: FilenameSetting.cc 5770 2006-10-12 11:09:22Z m9710797 $
 
 #include "FilenameSetting.hh"
-#include "CommandController.hh"
+#include "Completer.hh"
 #include "FileContext.hh"
 
 namespace openmsx {
@@ -14,7 +14,7 @@ FilenameSettingPolicy::FilenameSettingPolicy(CommandController& commandControlle
 void FilenameSettingPolicy::tabCompletion(std::vector<std::string>& tokens) const
 {
 	SystemFileContext context;
-	getCommandController().completeFileName(tokens, context);
+	Completer::completeFileName(tokens, context);
 }
 
 std::string FilenameSettingPolicy::getTypeString() const
