@@ -1,4 +1,4 @@
-// $Id: Setting.cc,v 1.16 2006/07/17 21:46:12 m9710797 Exp $
+// $Id: Setting.cc 5922 2006-12-11 21:58:43Z m9710797 $
 
 #include "Setting.hh"
 #include "Observer.hh"
@@ -24,11 +24,21 @@ Setting::~Setting()
 {
 }
 
+const string& Setting::getName() const
+{
+	return name;
+}
+
+string Setting::getDescription() const
+{
+	return description;
+}
+
 void Setting::notify() const
 {
 	Subject<Setting>::notify();
-	commandController.getCliComm().update(CliComm::SETTING, getName(),
-	                           getValueString());
+	commandController.getCliComm().update(
+		CliComm::SETTING, getName(), getValueString());
 }
 
 bool Setting::needLoadSave() const
@@ -36,9 +46,9 @@ bool Setting::needLoadSave() const
 	return save;
 }
 
-void Setting::setDontSaveValue(const std::string& dontSave_)
+void Setting::setDontSaveValue(const std::string& dontSaveValue_)
 {
-	dontSave = dontSave_;
+	dontSaveValue = dontSaveValue_;
 }
 
 void Setting::sync(XMLElement& config) const
@@ -56,7 +66,7 @@ void Setting::sync(XMLElement& config) const
 		// check for non-saveable value
 		// (mechanism can be generalize later when needed)
 		string tmp = getValueString();
-		if (tmp == dontSave) tmp = getRestoreValueString();
+		if (tmp == dontSaveValue) tmp = getRestoreValueString();
 		elem.setData(tmp);
 	}
 }
