@@ -1,4 +1,4 @@
-// $Id: StringSetting.cc 4926 2005-12-08 21:06:36Z m9710797 $
+// $Id: StringSetting.cc 6330 2007-04-21 08:23:51Z m9710797 $
 
 #include "StringSetting.hh"
 
@@ -32,10 +32,9 @@ string StringSettingPolicy::getTypeString() const
 
 StringSetting::StringSetting(CommandController& commandController,
                              const string& name, const string& description,
-                             const string& initialValue)
+                             const string& initialValue, SaveSetting save)
 	: SettingImpl<StringSettingPolicy>(
-		commandController, name, description, initialValue,
-		Setting::SAVE)
+		commandController, name, description, initialValue, save)
 {
 }
 
