@@ -1,4 +1,4 @@
-// $Id: AY8910.cc 6004 2007-01-19 20:48:18Z m9710797 $
+// $Id: AY8910.cc 6815 2007-08-07 13:12:12Z m9710797 $
 
 /*
  * Emulation of the AY-3-8910
@@ -18,7 +18,10 @@
 #include "XMLElement.hh"
 #include "MSXException.hh"
 #include "StringOp.hh"
+#include "FloatSetting.hh"
 #include <cassert>
+#include <cmath>
+#include <cstring>
 
 using std::string;
 
@@ -35,10 +38,15 @@ private:
 };
 
 
+// The step clock for the tone and noise generators is the chip clock
+// divided by 8; for the envelope generator of the AY-3-8910, it is half
+// that much (clock/16).
+static const double NATIVE_FREQ_DOUBLE = (3579545.0 / 2) / 8;
+static const int NATIVE_FREQ_INT = int(NATIVE_FREQ_DOUBLE + 0.5);
+
 // Fixed point representation of 1.
 static const int FP_UNIT = 0x8000;
 
-static const int CLOCK = 3579545 / 2;
 static const int PORT_A_DIRECTION = 0x40;
 static const int PORT_B_DIRECTION = 0x80;
 enum Register {
@@ -48,6 +56,37 @@ enum Register {
 	AY_ECOARSE = 12, AY_ESHAPE = 13, AY_PORTA = 14, AY_PORTB = 15
 };
 
+// Perlin noise
+
+static float n[256 + 3];
+
+static void initDetune()
+{
+	for (int i = 0; i < 256; ++i) {
+		n[i] = float(rand()) / (RAND_MAX / 2) - 1.0f; 
+	}
+	n[256] = n[0];
+	n[257] = n[1];
+	n[258] = n[2];
+}
+static float noiseValue(float x)
+{
+	// cubic hermite spline interpolation
+	assert(0.0f <= x);
+	int xi = int(x);
+	float xf = x - xi;
+	xi &= 255;
+	float n0 = n[xi + 0];
+	float n1 = n[xi + 1];
+	float n2 = n[xi + 2];
+	float n3 = n[xi + 3];
+	float a = n3 - n2 + n1 - n0;
+	float b = n0 - n1 - a;
+	float c = n2 - n0;
+	float d = n1;
+	return ((a * xf + b) * xf + c) * xf + d;
+}
+
 
 // Generator:
 
@@ -58,56 +97,86 @@ AY8910::Generator::Generator()
 
 inline void AY8910::Generator::reset(byte output)
 {
-	period = 0;
 	count = 0;
 	this->output = output;
 }
 
-inline void AY8910::Generator::setPeriod(int value, unsigned int updateStep)
+inline void AY8910::Generator::setPeriod(int value)
 {
-	// A note about the period of tones, noise and envelope: for speed
-	// reasons, we count down from the period to 0, but careful studies of the
-	// chip output prove that it instead counts up from 0 until the counter
-	// becomes greater or equal to the period. This is an important difference
-	// when the program is rapidly changing the period to modulate the sound.
-	// To compensate for the difference, when the period is changed we adjust
-	// our internal counter.
+	// Careful studies of the chip output prove that it instead counts up from
+	// 0 until the counter becomes greater or equal to the period. This is an
+	// important difference when the program is rapidly changing the period to
+	// modulate the sound.
 	// Also, note that period = 0 is the same as period = 1. This is mentioned
 	// in the YM2203 data sheets. However, this does NOT apply to the Envelope
 	// period. In that case, period = 0 is half as period = 1.
-	const int old = period;
-	if (value == 0) value = 1;
-	period = value * updateStep;
-	count += period - old;
-	if (count <= 0) count = 1;
+	period = value == 0 ? 1 : value;
+}
+
+inline byte AY8910::Generator::getOutput()
+{
+	return output;
 }
 
 
 // ToneGenerator:
 
-template <bool enabled>
-inline int AY8910::ToneGenerator::advance(int duration)
+AY8910::ToneGenerator::ToneGenerator()
+	: parent(NULL), vibratoCount(0), detuneCount(0)
 {
-	int highDuration = 0;
-	if (enabled && output) highDuration += count;
-	count -= duration;
-	if (count <= 0) {
+}
+
+inline void AY8910::ToneGenerator::setParent(AY8910& parent)
+{
+	this->parent = &parent;
+}
+
+inline int AY8910::ToneGenerator::getDetune()
+{
+	int result = 0;
+	double vibPerc = parent->vibratoPercent->getValue();
+	if (vibPerc != 0.0) {
+		int vibratoPeriod = int(
+			NATIVE_FREQ_DOUBLE
+			/ parent->vibratoFrequency->getValue());
+		vibratoCount += period;
+		vibratoCount %= vibratoPeriod;
+		result += int(
+			sin((M_PI * 2 * vibratoCount) / vibratoPeriod)
+			* vibPerc * 0.01 * period);
+	}
+	double detunePerc = parent->detunePercent->getValue();
+	if (detunePerc != 0.0) {
+		double detunePeriod = NATIVE_FREQ_DOUBLE /
+			parent->detuneFrequency->getValue();
+		detuneCount += period;
+		double noiseIdx = detuneCount / detunePeriod;
+		double noise = noiseValue(noiseIdx);
+		noise += noiseValue(2.0 * noiseIdx) / 2.0;
+		result += int(noise * detunePerc * 0.01 * period);
+	}
+	return result;
+}
+
+inline void AY8910::ToneGenerator::advance()
+{
+	count++;
+	if (count >= period) {
+		count = getDetune();
+		output ^= 1;
+	}
+}
+
+inline void AY8910::ToneGenerator::advance(int duration)
+{
+	if (count > period) count = period;
+	count += duration;
+	if (count >= period) {
 		// Calculate number of output transitions.
-		int cycles = 1 + (-count) / period;
-		if (enabled) {
-			// Full square waves: output is 1 half of the time;
-			// which half doesn't matter.
-			highDuration += period * (cycles / 2);
-		}
-		if (cycles & 1) {
-			// Half a square wave.
-			output ^= 1;
-			if (enabled && output) highDuration += period;
-		}
-		count += period * cycles;
+		int cycles = count / period;
+		count -= period * cycles; // equivalent to count %= period;
+		output ^= cycles & 1;
 	}
-	if (enabled && output) highDuration -= count;
-	return highDuration;
 }
 
 
@@ -124,24 +193,16 @@ inline void AY8910::NoiseGenerator::reset()
 	random = 1;
 }
 
-inline byte AY8910::NoiseGenerator::getOutput()
+inline void AY8910::NoiseGenerator::advance()
 {
-	return output;
-}
-
-inline int AY8910::NoiseGenerator::advanceToFlip(int duration)
-{
-	int left = duration;
-	while (true) {
-		if (count > left) {
-			// Exit: end of interval.
-			count -= left;
-			return duration;
-		}
-		left -= count;
-		count = period;
+	count++;
+	if (count >= period) {
+		count = 0;
 		// Is noise output going to change?
-		const bool flip = (random + 1) & 2; // bit0 ^ bit1
+		if ((random + 1) & 2) { // bit0 ^ bit1
+			// Exit: output flip.
+			output ^= 0x38;
+		}
 		// The Random Number Generator of the 8910 is a 17-bit shift register.
 		// The input to the shift register is bit0 XOR bit2 (bit0 is the
 		// output).
@@ -161,21 +222,16 @@ inline int AY8910::NoiseGenerator::advanceToFlip(int duration)
 		//       TODO: Benchmark on other modern CPUs.
 		//if (random & 1) random ^= 0x28000;
 		//random >>= 1;
-		random =  (random >> 1)
-		       ^ ((random & 1) << 14)
-		       ^ ((random & 1) << 16);
-		if (flip) {
-			// Exit: output flip.
-			output ^= 0x38;
-			return duration - left;
-		}
+		random = (random >> 1) ^ ((random & 1) << 14) ^ ((random & 1) << 16);
 	}
 }
 
 inline void AY8910::NoiseGenerator::advance(int duration)
 {
-	int cycles = (duration + period - count) / period;
-	count += cycles * period - duration;
+	if (count > period) count = period;
+	count += duration;
+	int cycles = count / period;
+	count -= cycles * period; // equivalent to count %= period
 	// See advanceToFlip for explanation of noise algorithm.
 	for (; cycles >= 4405; cycles -= 4405) {
 		random ^= (random >> 10)
@@ -219,10 +275,10 @@ AY8910::Amplitude::Amplitude(const XMLElement& config)
 	envChan[1] = false;
 	envChan[2] = false;
 	envVolume = 0;
-	setMasterVolume(0); // avoid UMR
+	setMasterVolume(32768);
 }
 
-inline unsigned int AY8910::Amplitude::getVolume(byte chan)
+inline unsigned AY8910::Amplitude::getVolume(byte chan)
 {
 	return vol[chan];
 }
@@ -249,9 +305,10 @@ inline void AY8910::Amplitude::setMasterVolume(int volume)
 	// volumes
 
 	double out = volume; // avoid clipping
+	double factor = pow(0.5, 0.25); // 1/sqrt(sqrt(2)) ~= 1/(1.5dB)
 	for (int i = 31; i > 0; --i) {
-		envVolTable[i] = (unsigned)(out + 0.5); // round to nearest;
-		out *= 0.841395141645195;               // 1/(10^(1.5/20)) = 1/(1.5dB)
+		envVolTable[i] = unsigned(out + 0.5); // round to nearest;
+		out *= factor;
 	}
 	envVolTable[0] = 0;
 	volTable[0] = 0;
@@ -294,21 +351,13 @@ inline AY8910::Envelope::Envelope(Amplitude& amplitude)
 
 inline void AY8910::Envelope::reset()
 {
-	period = 0;
 	count = 0;
 }
 
-inline void AY8910::Envelope::setPeriod(int value, unsigned int updateStep)
+inline void AY8910::Envelope::setPeriod(int value)
 {
 	// twice as fast as AY8910
-	const int old = period;
-	if (value == 0) {
-		period = updateStep / 2;
-	} else {
-		period = value * updateStep;
-	}
-	count += period - old;
-	if (count <= 0) count = 1;
+	period = value == 0 ? FP_UNIT / 2 : value * FP_UNIT;
 }
 
 inline byte AY8910::Envelope::getVolume()
@@ -343,7 +392,7 @@ inline void AY8910::Envelope::setShape(byte shape)
 		hold = shape & 0x01;
 		alternate = shape & 0x02;
 	}
-	count = period;
+	count = 0;
 	step = 0x1F;
 	holding = false;
 	amplitude.setEnvelopeVolume(getVolume());
@@ -357,11 +406,12 @@ inline bool AY8910::Envelope::isChanging()
 inline void AY8910::Envelope::advance(int duration)
 {
 	if (!holding) {
-		count -= duration;
-		if (count <= 0) {
-			const int steps = 1 + (-count) / period;
+		if (count > period) count = period;
+		count += duration * FP_UNIT;
+		if (count >= period) {
+			const int steps = count / period;
 			step -= steps;
-			count += steps * period;
+			count -= steps * period; // equivalent to count %= period;
 
 			// Check current envelope position.
 			if (step < 0) {
@@ -388,17 +438,39 @@ inline void AY8910::Envelope::advance(int duration)
 
 AY8910::AY8910(MSXMotherBoard& motherBoard, AY8910Periphery& periphery_,
                const XMLElement& config, const EmuTime& time)
-	: SoundDevice(motherBoard.getMSXMixer(), "PSG", "PSG")
+	: SoundDevice(motherBoard.getMSXMixer(), "PSG", "PSG", 3)
+	, Resample(motherBoard.getGlobalSettings(), 1)
 	, cliComm(motherBoard.getMSXCliComm())
 	, periphery(periphery_)
+	, debuggable(new AY8910Debuggable(motherBoard, *this))
 	, amplitude(config)
 	, envelope(amplitude)
-	, debuggable(new AY8910Debuggable(motherBoard, *this))
 	, warningPrinted(false)
 {
+	initDetune();
+
+	for (int chan = 0; chan < 3; chan++) {
+		tone[chan].setParent(*this);
+	}
+
 	// make valgrind happy
 	memset(regs, 0, sizeof(regs));
-	setSampleRate(44100);
+	setOutputRate(44100);
+
+	const string& name = getName();
+	CommandController& commandController = motherBoard.getCommandController();
+	vibratoPercent.reset(new FloatSetting(commandController,
+		name + "_vibrato_percent", "controls strength of vibrato effect",
+		0.0, 0.0, 10.0));
+	vibratoFrequency.reset(new FloatSetting(commandController,
+		name + "_vibrato_frequency", "frequency of vibrato effect in Hertz",
+		5, 1.0, 10.0));
+	detunePercent.reset(new FloatSetting(commandController,
+		name + "_detune_percent", "controls strength of detune effect",
+		0.0, 0.0, 10.0));
+	detuneFrequency.reset(new FloatSetting(commandController,
+		name + "_detune_frequency", "frequency of detune effect in Hertz",
+		5.0, 1.0, 100.0));
 
 	reset(time);
 	registerSound(config);
@@ -499,25 +571,22 @@ void AY8910::wrtReg(byte reg, byte value, const EmuTime& time)
 	case AY_BCOARSE:
 	case AY_CFINE:
 	case AY_CCOARSE:
-		tone[reg / 2].setPeriod(
-			regs[reg & ~1] + 256 * (regs[reg | 1] & 0x0F), updateStep);
+		tone[reg / 2].setPeriod(regs[reg & ~1] + 256 * (regs[reg | 1] & 0x0F));
 		break;
 	case AY_NOISEPER:
 		// half the frequency of tone generation
-		noise.setPeriod(value & 0x1F, updateStep * 2);
+		noise.setPeriod(2 * (value & 0x1F));
 		break;
 	case AY_AVOL:
 	case AY_BVOL:
 	case AY_CVOL:
 		amplitude.setChannelVolume(reg - AY_AVOL, value);
-		checkMute();
 		break;
 	case AY_EFINE:
 	case AY_ECOARSE:
 		// also half the frequency of tone generation, but handled
 		// inside Envelope::setPeriod()
-		envelope.setPeriod(
-			regs[AY_EFINE] + 256 * regs[AY_ECOARSE], updateStep);
+		envelope.setPeriod(regs[AY_EFINE] + 256 * regs[AY_ECOARSE]);
 		break;
 	case AY_ESHAPE:
 		envelope.setShape(value);
@@ -534,7 +603,6 @@ void AY8910::wrtReg(byte reg, byte value, const EmuTime& time)
 			periphery.writeB(regs[AY_PORTB], time);
 		}
 		oldEnable = value;
-		checkMute();
 		break;
 	case AY_PORTA:
 		if (regs[AY_ENABLE] & PORT_A_DIRECTION) { // output
@@ -549,38 +617,14 @@ void AY8910::wrtReg(byte reg, byte value, const EmuTime& time)
 	}
 }
 
-void AY8910::checkMute()
+void AY8910::setOutputRate(unsigned sampleRate)
 {
-	setMute(((regs[AY_AVOL] | regs[AY_BVOL] | regs[AY_CVOL]) & 0x1F) == 0);
-}
-
-void AY8910::setVolume(int volume)
-{
-	amplitude.setMasterVolume(volume);
-	// recalculate volume for all channels
-	for (int i = 0; i < 3; ++i) {
-		amplitude.setChannelVolume(i, regs[AY_AVOL + i]);
-	}
+	setInputRate(NATIVE_FREQ_INT);
+	setResampleRatio(NATIVE_FREQ_DOUBLE, sampleRate);
 }
 
 
-void AY8910::setSampleRate(int sampleRate)
-{
-	// The step clock for the tone and noise generators is the chip clock
-	// divided by 8; for the envelope generator of the AY-3-8910, it is half
-	// that much (clock/16).
-	// Here we calculate the number of steps which happen during one sample
-	// at the given sample rate. No. of events = sample rate / (clock/8).
-	// FP_UNIT is a multiplier used to turn the fraction into a fixed point
-	// number.
-
-	// !! look out for overflow !!
-	updateStep = (FP_UNIT * sampleRate) / (CLOCK / 8);
-}
-
-
-void AY8910::updateBuffer(unsigned length, int* buffer,
-     const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
+void AY8910::generateChannels(int** bufs, unsigned length)
 {
 	/*
 	static long long totalSamples = 0, noiseOff = 0, toneOff = 0, bothOff = 0;
@@ -610,6 +654,17 @@ void AY8910::updateBuffer(unsigned length, int* buffer,
 	}
 	*/
 
+	if (((regs[AY_AVOL] | regs[AY_BVOL] | regs[AY_CVOL]) & 0x1F) == 0) {
+		// optimization: all channels volume 0
+		for (int i = 0; i < 3; ++i) {
+			tone[i].advance(length);
+			bufs[i] = 0;
+		}
+		noise.advance(length);
+		envelope.advance(length);
+		return;
+	}
+
 	byte chanEnable = regs[AY_ENABLE];
 	// Disable channels with volume 0: since the sample value doesn't matter,
 	// we can use the fastest path.
@@ -621,91 +676,75 @@ void AY8910::updateBuffer(unsigned length, int* buffer,
 	// Advance tone generators for channels that have tone disabled.
 	for (byte chan = 0; chan < 3; chan++) {
 		if (chanEnable & (0x01 << chan)) { // disabled
-			tone[chan].advance<false>(length * FP_UNIT);
+			tone[chan].advance(length);
 		}
 	}
 	// Noise enabled on any channel?
 	bool anyNoise = (chanEnable & 0x38) != 0x38;
 	if (!anyNoise) {
-		noise.advance(length * FP_UNIT);
+		noise.advance(length);
 	}
 	// Envelope enabled on any channel?
 	bool enveloping = amplitude.anyEnvelope() && envelope.isChanging();
 	if (!enveloping) {
-		envelope.advance(length * FP_UNIT);
+		envelope.advance(length);
 	}
 
 	// Calculate samples.
-	while (length) {
-		// semiVol keeps track of how long each square wave stays
-		// in the 1 position during the sample period.
-		int semiVol[3] = { 0, 0, 0 };
-		int left = FP_UNIT;
-		do {
-			// The 8910 has three outputs, each output is the mix of one of
-			// the three tone generators and of the (single) noise generator.
-			// The two are mixed BEFORE going into the DAC. The formula to mix
-			// each channel is:
-			//   (ToneOn | ToneDisable) & (NoiseOn | NoiseDisable),
-			//   where ToneOn and NoiseOn are the current generator state
-			//   and ToneDisable and NoiseDisable come from the enable reg.
-			// Note that this means that if both tone and noise are disabled,
-			// the output is 1, not 0, and can be modulated by changing the
-			// volume.
-
-			// Update state of noise generator.
-			byte chanFlags;
-			int nextEvent;
-			if (anyNoise) {
-				// Next event is end of this sample or noise flip.
-				chanFlags = noise.getOutput() | chanEnable;
-				nextEvent = noise.advanceToFlip(left);
-			} else {
-				// Next event is end of this sample.
-				chanFlags = chanEnable;
-				nextEvent = FP_UNIT;
-			}
-
-			// Mix tone generators with noise generator.
-			for (byte chan = 0; chan < 3; chan++, chanFlags >>= 1) {
-				if ((chanFlags & 0x09) == 0x08) {
-					// Square wave: alternating between 0 and 1.
-					semiVol[chan] += tone[chan].advance<true>(nextEvent);
-				} else if ((chanFlags & 0x09) == 0x09) {
-					// Channel disabled: always 1.
-					semiVol[chan] += nextEvent;
-				} else if ((chanFlags & 0x09) == 0x00) {
-					// Tone enabled, but suppressed by noise state.
-					tone[chan].advance<false>(nextEvent);
-				} else { // (chanFlags & 0x09) == 0x01
-					// Tone disabled, noise state is 0.
-					// Nothing to do.
-				}
-			}
-
-			left -= nextEvent;
-		} while (left > 0);
+	for (unsigned i = 0; i < length; ++i) {
+		// The 8910 has three outputs, each output is the mix of one of
+		// the three tone generators and of the (single) noise generator.
+		// The two are mixed BEFORE going into the DAC. The formula to mix
+		// each channel is:
+		//   (ToneOn | ToneDisable) & (NoiseOn | NoiseDisable),
+		//   where ToneOn and NoiseOn are the current generator state
+		//   and ToneDisable and NoiseDisable come from the enable reg.
+		// Note that this means that if both tone and noise are disabled,
+		// the output is 1, not 0, and can be modulated by changing the
+		// volume.
 
+		// Update state of noise generator.
+		byte chanFlags = chanEnable;
+		if (anyNoise) {
+			chanFlags |= noise.getOutput();
+			noise.advance();
+		}
 		// Update envelope.
-		if (enveloping) envelope.advance(FP_UNIT);
+		if (enveloping) envelope.advance(1);
 
-		// Calculate D/A converter output.
-		// TODO: Is it easy to detect when multiple samples have the same
-		//       value? (make nextEvent depend on tone events as well?)
-		//       At 44KHz, value typically changes once every 4 to 5 samples.
-		int chA = (semiVol[0] * amplitude.getVolume(0)) / FP_UNIT;
-		int chB = (semiVol[1] * amplitude.getVolume(1)) / FP_UNIT;
-		int chC = (semiVol[2] * amplitude.getVolume(2)) / FP_UNIT;
-		/*
-		static int prevSample = 0;
-		if (chA + chB + chC == prevSample) sameSample += 3;
-		else prevSample = chA + chB + chC;
-		*/
-		*(buffer++) = chA + chB + chC;
-		length--;
+		// Mix tone generators with noise generator.
+		for (byte chan = 0; chan < 3; chan++, chanFlags >>= 1) {
+			int* out = &bufs[chan][i];
+			if ((chanFlags & 0x09) == 0x08) {
+				// Square wave: alternating between 0 and 1.
+				*out = tone[chan].getOutput() * amplitude.getVolume(chan);
+				tone[chan].advance();
+			} else if ((chanFlags & 0x09) == 0x09) {
+				// Channel disabled: always 1.
+				*out = amplitude.getVolume(chan);
+			} else if ((chanFlags & 0x09) == 0x00) {
+				// Tone enabled, but suppressed by noise state.
+				*out = 0;
+				tone[chan].advance();
+			} else { // (chanFlags & 0x09) == 0x01
+				// Tone disabled, noise state is 0.
+				*out = 0;
+			}
+		}
 	}
 }
 
+bool AY8910::generateInput(int* buffer, unsigned num)
+{
+	return mixChannels(buffer, num);
+}
+
+bool AY8910::updateBuffer(unsigned length, int* buffer,
+     const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
+{
+	return generateOutput(buffer, length);
+}
+
 
 // SimpleDebuggable
 
