@@ -1,8 +1,9 @@
-// $Id: AudioInputConnector.cc 4836 2005-11-11 20:53:06Z m9710797 $
+// $Id: AudioInputConnector.cc 7304 2007-11-22 22:07:39Z m9710797 $
 
 #include "AudioInputConnector.hh"
 #include "DummyAudioInputDevice.hh"
 #include "PluggingController.hh"
+#include "AudioInputDevice.hh"
 
 namespace openmsx {
 
@@ -21,7 +22,7 @@ AudioInputConnector::~AudioInputConnector()
 
 const std::string& AudioInputConnector::getDescription() const
 {
-	static const std::string desc("Auddio input connector.");
+	static const std::string desc("Audio input connector.");
 	return desc;
 }
 
@@ -31,14 +32,9 @@ const std::string& AudioInputConnector::getClass() const
 	return className;
 }
 
-AudioInputDevice& AudioInputConnector::getPlugged() const
-{
-	return static_cast<AudioInputDevice&>(*plugged);
-}
-
 short AudioInputConnector::readSample(const EmuTime& time) const
 {
-	return getPlugged().readSample(time);
+	return static_cast<AudioInputDevice&>(getPlugged()).readSample(time);
 }
 
 } // namespace openmsx
