@@ -1,4 +1,4 @@
-// $Id: DACSound16S.cc 5785 2006-10-18 15:57:18Z m9710797 $
+// $Id: DACSound16S.cc 6656 2007-06-23 10:33:52Z m9710797 $
 
 #include "DACSound16S.hh"
 
@@ -7,7 +7,8 @@ namespace openmsx {
 DACSound16S::DACSound16S(MSXMixer& mixer, const std::string& name,
                          const std::string& desc, const XMLElement& config,
                          const EmuTime& /*time*/)
-	: SoundDevice(mixer, name, desc)
+	: SoundDevice(mixer, name, desc, 1)
+	, start(EmuTime::zero) // dummy
 {
 	lastWrittenValue = 0;
 	prevValue = prevA = prevB = 0;
@@ -19,14 +20,9 @@ DACSound16S::~DACSound16S()
 	unregisterSound();
 }
 
-void DACSound16S::setVolume(int newVolume)
+void DACSound16S::setOutputRate(unsigned sampleRate)
 {
-	volume = newVolume;
-}
-
-void DACSound16S::setSampleRate(int /*sampleRate*/)
-{
-	// nothing
+	setInputRate(sampleRate);
 }
 
 void DACSound16S::reset(const EmuTime& time)
@@ -40,13 +36,10 @@ void DACSound16S::writeDAC(short value, const EmuTime& time)
 
 	if (value == lastWrittenValue) return;
 	lastWrittenValue = value;
-
-	queue.push_back(Sample(time, (value * volume) >> 15));
-	setMute(false);
+	queue.push_back(Sample(time, value));
 }
 
-void DACSound16S::updateBuffer(unsigned length, int* buffer,
-     const EmuTime& start, const EmuDuration& sampDur)
+void DACSound16S::generateChannels(int** bufs, unsigned num)
 {
 	// purge samples before start
 	Queue::iterator it = queue.begin();
@@ -56,12 +49,20 @@ void DACSound16S::updateBuffer(unsigned length, int* buffer,
 		queue.erase(queue.begin(), it);
 	}
 
+	/* Old implementation commented out, remove this code later
+	if (queue.empty() && (prevValue == 0)) {
+		// optimization: nothing interesting will happen this time, so
+		// return early
+		bufs[0] = 0;
+		return;
+	}
+
 	EmuDuration halfDur = sampDur / 2;
 	int64 durA = halfDur.length();
 	int64 durB = sampDur.length() - durA;
 
 	EmuTime curr = start;
-	while (length--) {
+	for (unsigned i = 0; i < num; ++i) {
 		// 2x oversampling
 		EmuTime nextA = curr + halfDur;
 		EmuTime nextB = curr + sampDur;
@@ -90,12 +91,30 @@ void DACSound16S::updateBuffer(unsigned length, int* buffer,
 
 		// 4th order symmetrical FIR filter (1 3 3 1)
 		int value = (prevA + sampB + 3 * (prevB + sampA)) / 8;
-		*(buffer++) = value;
+		bufs[0][i] = value;
 		prevA = sampA;
 		prevB = sampB;
 	}
+	*/
+	
+	// BlipBuffer based implementation
+	EmuTime stop = start + sampDur * num;
+	while (!queue.empty() && (queue.front().time < stop)) {
+		double t = (queue.front().time - start).div(sampDur);
+		blip.update(BlipBuffer::TimeIndex(t), queue.front().value);
+		queue.pop_front();
+	}
+	if (!blip.readSamples(bufs[0], num)) {
+		bufs[0] = 0;
+	}
+}
 
-	setMute(queue.empty() && (prevValue == 0));
+bool DACSound16S::updateBuffer(unsigned length, int* buffer,
+     const EmuTime& start_, const EmuDuration& sampDur_)
+{
+	start = start_;
+	sampDur = sampDur_;
+	return mixChannels(buffer, length);
 }
 
 } // namespace openmsx
