@@ -1,4 +1,4 @@
-// $Id: DACSound8U.cc 5785 2006-10-18 15:57:18Z m9710797 $
+// $Id: DACSound8U.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "DACSound8U.hh"
 
@@ -13,7 +13,7 @@ DACSound8U::DACSound8U(MSXMixer& mixer, const std::string& name,
 
 void DACSound8U::writeDAC(byte value, const EmuTime& time)
 {
-	DACSound16S::writeDAC(((short)value - 0x80) << 8, time);
+	DACSound16S::writeDAC((short(value) - 0x80) << 8, time);
 }
 
 } // namespace openmsx
