@@ -1,4 +1,4 @@
-// $Id: DirectXSoundDriver.cc 5924 2006-12-14 20:50:54Z m9710797 $
+// $Id: DirectXSoundDriver.cc 6798 2007-08-04 15:35:56Z m9710797 $
 
 #ifdef _WIN32
 
@@ -94,7 +94,7 @@ DirectXSoundDriver::DirectXSoundDriver(unsigned sampleRate, unsigned samples)
 	             | DSBCAPS_CTRLFREQUENCY      | DSBCAPS_CTRLPAN
 	             | DSBCAPS_CTRLVOLUME         | DSBCAPS_GLOBALFOCUS;
 	desc.dwBufferBytes = bufferSize;
-	desc.lpwfxFormat = (LPWAVEFORMATEX)&pcmwf;
+	desc.lpwfxFormat = reinterpret_cast<LPWAVEFORMATEX>(&pcmwf);
 
 	if (IDirectSound_CreateSoundBuffer(
 			directSound, &desc, &primaryBuffer, NULL) != DS_OK) {
@@ -154,6 +154,11 @@ unsigned DirectXSoundDriver::getSamples() const
 	return fragmentSize;
 }
 
+// #define MAKE_HRESULT(s,f,c) ((HRESULT)(((unsigned long)(s)<<31)|((unsigned long)(f)<<16)|((unsigned long)(c))))
+// #define MAKE_DSHRESULT(code) MAKE_HRESULT(1, _FACDS, code)
+// #define DSERR_BUFFERLOST     MAKE_DSHRESULT(150)
+static const HRESULT OPENMSX_DSERR_BUFFERLOST = (1u << 31) | (_FACDS << 16) | 150;
+
 void DirectXSoundDriver::dxClear()
 {
 	void *audioBuffer1, *audioBuffer2;
@@ -161,7 +166,7 @@ void DirectXSoundDriver::dxClear()
 	if (IDirectSoundBuffer_Lock(
 			primaryBuffer, 0, bufferSize,
 			&audioBuffer1, &audioSize1,
-			&audioBuffer2, &audioSize2, 0) == DSERR_BUFFERLOST) {
+			&audioBuffer2, &audioSize2, 0) == OPENMSX_DSERR_BUFFERLOST) {
 		IDirectSoundBuffer_Restore(primaryBuffer);
 	} else {
 		memset(audioBuffer1, 0, audioSize1);
@@ -199,7 +204,7 @@ void DirectXSoundDriver::dxWriteOne(short* buffer, unsigned lockSize)
 		if (IDirectSoundBuffer_Lock(
 				primaryBuffer, bufferOffset, lockSize,
 				&audioBuffer1, &audioSize1, &audioBuffer2,
-				&audioSize2, 0) == DSERR_BUFFERLOST) {
+				&audioSize2, 0) == OPENMSX_DSERR_BUFFERLOST) {
 			IDirectSoundBuffer_Restore(primaryBuffer);
 			IDirectSoundBuffer_Lock(
 				primaryBuffer, bufferOffset, lockSize,
@@ -210,7 +215,7 @@ void DirectXSoundDriver::dxWriteOne(short* buffer, unsigned lockSize)
 
 	memcpy(audioBuffer1, buffer, audioSize1);
 	if (audioBuffer2) {
-		memcpy(audioBuffer2, (byte*)buffer + audioSize1, audioSize2);
+		memcpy(audioBuffer2, reinterpret_cast<byte*>(buffer) + audioSize1, audioSize2);
 	}
 	IDirectSoundBuffer_Unlock(primaryBuffer, audioBuffer1, audioSize1,
 			audioBuffer2, audioSize2);
@@ -229,7 +234,7 @@ double DirectXSoundDriver::uploadBuffer(short* buffer, unsigned count)
 		bufferOffset = (readPos + bufferSize / 2) % bufferSize;
 
 		if (IDirectSoundBuffer_Play(primaryBuffer, 0, 0,
-					DSBPLAY_LOOPING) == DSERR_BUFFERLOST) {
+					DSBPLAY_LOOPING) == OPENMSX_DSERR_BUFFERLOST) {
 			IDirectSoundBuffer_Play(
 					primaryBuffer, 0, 0, DSBPLAY_LOOPING);
 		}
