@@ -1,4 +1,4 @@
-// $Id: KeyClick.cc,v 1.11 2005/11/10 18:39:50 m9710797 Exp $
+// $Id: KeyClick.cc 5785 2006-10-18 15:57:18Z m9710797 $
 
 #include "KeyClick.hh"
 #include "DACSound8U.hh"
@@ -6,7 +6,8 @@
 
 namespace openmsx {
 
-KeyClick::KeyClick(Mixer& mixer, const XMLElement& config, const EmuTime& time)
+KeyClick::KeyClick(MSXMixer& mixer, const XMLElement& config,
+                   const EmuTime& time)
 	: dac(new DACSound8U(mixer, "keyclick", "1-bit click generator",
 	                     config, time))
 {
