@@ -1,4 +1,4 @@
-// $Id: MSXMixer.cc 6091 2007-02-17 14:01:15Z m9710797 $
+// $Id: MSXMixer.cc 7311 2007-11-25 09:27:47Z m9710797 $
 
 #include "MSXMixer.hh"
 #include "Mixer.hh"
@@ -10,9 +10,14 @@
 #include "ThrottleManager.hh"
 #include "GlobalSettings.hh"
 #include "IntegerSetting.hh"
-#include "EnumSetting.hh"
+#include "StringSetting.hh"
+#include "BooleanSetting.hh"
 #include "AviRecorder.hh"
+#include "Math.hh"
+#include "CliComm.hh"
 #include <algorithm>
+#include <cmath>
+#include <cstring>
 #include <cassert>
 
 using std::remove;
@@ -49,6 +54,7 @@ MSXMixer::MSXMixer(Mixer& mixer_, Scheduler& scheduler,
 	, soundDeviceInfo(new SoundDeviceInfoTopic(
 	              msxCommandController.getMachineInfoCommand(), *this))
 	, recorder(0)
+	, synchronousCounter(0)
 {
 	sampleRate = 0;
 	fragmentSize = 0;
@@ -77,71 +83,84 @@ MSXMixer::~MSXMixer()
 	mute(); // calls Mixer::unregisterMixer()
 }
 
-void MSXMixer::registerSound(SoundDevice& device, short volume,
-                             ChannelMode::Mode mode)
+void MSXMixer::registerSound(SoundDevice& device, double volume,
+                             int balance, unsigned numChannels)
 {
+	// TODO read volume/balance(mode) from config file
 	const string& name = device.getName();
 	SoundDeviceInfo info;
+	info.defaultVolume = volume;
 	info.volumeSetting = new IntegerSetting(msxCommandController,
 		name + "_volume", "the volume of this sound chip", 75, 0, 100);
+	info.balanceSetting = new IntegerSetting(msxCommandController,
+		name + "_balance", "the balance of this sound chip",
+		balance, -100, 100);
 
-	// once we're stereo, stay stereo. Once mono, stay mono.
-	// we could also choose not to offer any modeSetting in case we have
-	// a stereo mode initially. You can't query the mode then, though.
-	string defaultMode;
-	EnumSetting<ChannelMode::Mode>::Map modeMap;
-	if (mode == ChannelMode::STEREO) {
-		defaultMode = "stereo";
-		modeMap[defaultMode] = ChannelMode::STEREO;
-	} else {
-		defaultMode = "mono";
-		modeMap[defaultMode] = ChannelMode::MONO;
-		modeMap["left"] = ChannelMode::MONO_LEFT;
-		modeMap["right"] = ChannelMode::MONO_RIGHT;
-	}
-	modeMap["off"] = ChannelMode::OFF;
-	info.modeSetting = new EnumSetting<ChannelMode::Mode>(msxCommandController,
-		name + "_mode", "the channel mode of this sound chip",
-		modeMap[defaultMode], modeMap, Setting::DONT_SAVE);
-	info.modeSetting->setValue(mode);
-
-	info.mode = mode;
-	info.normalVolume = (volume * 100 * 100) / (75 * 75);
-	info.modeSetting->attach(*this);
 	info.volumeSetting->attach(*this);
-	infos[&device] = info;
+	info.balanceSetting->attach(*this);
 
-	devices[mode].push_back(&device);
-	device.setSampleRate(sampleRate);
-	device.setVolume((info.normalVolume * info.volumeSetting->getValue() *
-	                   masterVolume.getValue()) / (100 * 100));
+	for (unsigned i = 0; i < numChannels; ++i) {
+		SoundDeviceInfo::ChannelSettings channelSettings;
+		string ch_name = name + "_ch" + StringOp::toString(i + 1);
 
-	unsigned required = infos.size() * 8192 * 2;
-	if (mixBuffer.size() < required) {
-		mixBuffer.resize(required);
+		channelSettings.recordSetting = new StringSetting(
+			msxCommandController, ch_name + "_record",
+			"filename to record this channel to",
+			"", Setting::DONT_SAVE);
+		channelSettings.recordSetting->attach(*this);
+
+		channelSettings.muteSetting = new BooleanSetting(
+			msxCommandController, ch_name + "_mute",
+			"sets mute-status of individual sound channels",
+			false, Setting::DONT_SAVE);
+		channelSettings.muteSetting->attach(*this);
+
+		info.channelSettings.push_back(channelSettings);
 	}
+
+	infos[&device] = info;
+	device.setOutputRate(sampleRate);
+
+	Infos::iterator it = infos.find(&device);
+	assert(it != infos.end());
+	updateVolumeParams(it);
+
+	msxCommandController.getCliComm().update(CliComm::SOUNDDEVICE, device.getName(), "add");
 }
 
 void MSXMixer::unregisterSound(SoundDevice& device)
 {
-	// note: no need to shrink mixBuffer
-
 	Infos::iterator it = infos.find(&device);
 	assert(it != infos.end());
-
-	ChannelMode::Mode mode = it->second.mode;
-	vector<SoundDevice*> &dev = devices[mode];
-	dev.erase(remove(dev.begin(), dev.end(), &device), dev.end());
 	it->second.volumeSetting->detach(*this);
 	delete it->second.volumeSetting;
-	it->second.modeSetting->detach(*this);
-	delete it->second.modeSetting;
+	it->second.balanceSetting->detach(*this);
+	delete it->second.balanceSetting;
+	for (vector<SoundDeviceInfo::ChannelSettings>::const_iterator it2 =
+	            it->second.channelSettings.begin();
+	     it2 != it->second.channelSettings.end(); ++it2) {
+		it2->recordSetting->detach(*this);
+		delete it2->recordSetting;
+		it2->muteSetting->detach(*this);
+		delete it2->muteSetting;
+	}
 	infos.erase(it);
+	msxCommandController.getCliComm().update(CliComm::SOUNDDEVICE, device.getName(), "remove");
+}
+
+void MSXMixer::setSynchronousMode(bool synchronous)
+{
+	if (synchronous) {
+		++synchronousCounter;
+	} else {
+		assert(synchronousCounter > 0);
+		--synchronousCounter;
+	}
 }
 
 void MSXMixer::updateStream(const EmuTime& time)
 {
-	if ((!muteCount && fragmentSize) || recorder) {
+	if ((!muteCount && fragmentSize) || synchronousCounter) {
 		updateStream2(time);
 	}
 }
@@ -155,18 +174,17 @@ void MSXMixer::updateStream2(const EmuTime& time)
 
 	short mixBuffer[8192 * 2];
 	count = std::min(8192u, count);
-	double factor;
-	if (!muteCount && fragmentSize) {
-		generate(mixBuffer, count, prevTime, interval1);
-		factor = mixer.uploadBuffer(*this, mixBuffer, count);
-	} else {
-		assert(recorder);
-		memset(mixBuffer, 0, count * 2 * sizeof(short));
-		factor = 1.0;
-	}
+	assert((!muteCount && fragmentSize) || synchronousCounter);
+	generate(mixBuffer, count, prevTime, interval1);
 	prevTime += interval1 * count;
-	if (recorder) {
-		recorder->addWave(count, mixBuffer);
+	double factor = 1.0;
+	if (!muteCount && fragmentSize) {
+		factor = mixer.uploadBuffer(*this, mixBuffer, count);
+	}
+	if (synchronousCounter) {
+		if (recorder) {
+			recorder->addWave(count, mixBuffer);
+		}
 		factor = 1.0;
 	}
 	if (factor != 1.0) {
@@ -182,53 +200,43 @@ void MSXMixer::updateStream2(const EmuTime& time)
 void MSXMixer::generate(short* output, unsigned samples,
 	const EmuTime& start, const EmuDuration& sampDur)
 {
-	assert(!muteCount && fragmentSize);
+	assert((!muteCount && fragmentSize) || synchronousCounter);
 	assert(samples <= 8192);
 
-	int modeOffset[ChannelMode::NB_MODES];
-	int unmuted = 0;
-	int* buffer = &mixBuffer[0];
-	for (int mode = 0; mode < ChannelMode::NB_MODES -1; mode++) { // -1 for OFF mode
-		modeOffset[mode] = unmuted;
-		for (vector<SoundDevice*>::const_iterator it =
-		           devices[mode].begin();
-		     it != devices[mode].end(); ++it) {
-			if (!(*it)->isMuted()) {
-				(*it)->updateBuffer(samples, buffer,
-				                    start, sampDur);
-				++unmuted;
-				buffer += 8192 * 2;
+	int mixBuf[2 * samples];
+	int tmpBuf[2 * samples];
+	memset(mixBuf, 0, 2 * samples * sizeof(int));
+
+	for (Infos::const_iterator it = infos.begin();
+	     it != infos.end(); ++it) {
+		SoundDevice& device = *it->first;
+		if (device.updateBuffer(samples, tmpBuf,
+					start, sampDur)) {
+			if (!device.isStereo()) {
+				int l1 = it->second.left1;
+				int r1 = it->second.right1;
+				for (unsigned i = 0; i < samples; ++i) {
+					mixBuf[2 * i + 0] += (l1 * tmpBuf[i]) >> 8;
+					mixBuf[2 * i + 1] += (r1 * tmpBuf[i]) >> 8;
+				}
+			} else {
+				int l1 = it->second.left1;
+				int r1 = it->second.right1;
+				int l2 = it->second.left2;
+				int r2 = it->second.right2;
+				for (unsigned i = 0; i < samples; ++i) {
+					int in1 = tmpBuf[2 * i + 0];
+					int in2 = tmpBuf[2 * i + 1];
+					mixBuf[2 * i + 0] += (l1 * in1 + l2 * in2) >> 8;
+					mixBuf[2 * i + 1] += (r1 * in1 + r2 * in2) >> 8;
+				}
 			}
 		}
 	}
 
 	for (unsigned j = 0; j < samples; ++j) {
-		buffer = &mixBuffer[0];
-		int buf = 0;
-		int both = 0;
-		while (buf < modeOffset[ChannelMode::MONO + 1]) {
-			both  += buffer[j];
-			buffer += 8192 * 2;
-			++buf;
-		}
-		int left = both;
-		while (buf < modeOffset[ChannelMode::MONO_LEFT + 1]) {
-			left  += buffer[j];
-			buffer += 8192 * 2;
-			++buf;
-		}
-		int right = both;
-		while (buf < modeOffset[ChannelMode::MONO_RIGHT + 1]) {
-			right += buffer[j];
-			buffer += 8192 * 2;
-			++buf;
-		}
-		while (buf < unmuted) {
-			left  += buffer[2 * j + 0];
-			right += buffer[2 * j + 1];
-			buffer += 8192 * 2;
-			++buf;
-		}
+		int left  = mixBuf[2 * j + 0];
+		int right = mixBuf[2 * j + 1];
 
 		// DC removal filter
 		//   y(n) = x(n) - x(n-1) + R * y(n-1)
@@ -241,14 +249,8 @@ void MSXMixer::generate(short* output, unsigned samples,
 		outRight  = right - prevRight + ((1022 * outRight) >> 10);
 		prevRight = right;
 
-		// clip
-		if      (outLeft  > 32767)  outLeft  =  32767;
-		else if (outLeft  < -32768) outLeft  = -32768;
-		if      (outRight > 32767)  outRight =  32767;
-		else if (outRight < -32768) outRight = -32768;
-
-		output[2 * j + 0] = static_cast<short>(outLeft);
-		output[2 * j + 1] = static_cast<short>(outRight);
+		output[2 * j + 0] = Math::clipIntToShort(outLeft);
+		output[2 * j + 1] = Math::clipIntToShort(outRight);
 	}
 }
 
@@ -274,7 +276,7 @@ void MSXMixer::unmute()
 
 void MSXMixer::reInit()
 {
-	if (recorder) {
+	if (synchronousCounter) {
 		// do as if speed=100
 		interval1 = EmuDuration(1.0 / sampleRate);
 	} else {
@@ -289,7 +291,7 @@ void MSXMixer::reInit()
 		prevTime = getScheduler().getCurrentTime();
 		EmuDuration interval2 = interval1 * fragmentSize;
 		setSyncPoint(prevTime + interval2);
-	} else if (recorder) {
+	} else if (synchronousCounter) {
 		prevTime = getScheduler().getCurrentTime();
 		EmuDuration interval2 = interval1 * 512;
 		setSyncPoint(prevTime + interval2);
@@ -303,12 +305,9 @@ void MSXMixer::setMixerParams(unsigned newFragmentSize, unsigned newSampleRate)
 	if (sampleRate != newSampleRate) {
 		sampleRate = newSampleRate;
 		needReInit = true;
-		for (int mode = 0; mode < ChannelMode::NB_MODES; ++mode) {
-			for (vector<SoundDevice*>::const_iterator it =
-				 devices[mode].begin();
-			     it != devices[mode].end(); ++it) {
-				(*it)->setSampleRate(sampleRate);
-			}
+		for (Infos::const_iterator it = infos.begin();
+		     it != infos.end(); ++it) {
+			it->first->setOutputRate(sampleRate);
 		}
 	}
 
@@ -320,9 +319,12 @@ void MSXMixer::setMixerParams(unsigned newFragmentSize, unsigned newSampleRate)
 	if (needReInit) reInit();
 }
 
-void MSXMixer::setRecorder(AviRecorder* recorder_)
+void MSXMixer::setRecorder(AviRecorder* newRecorder)
 {
-	recorder = recorder_;
+	if (bool(recorder) != bool(newRecorder)) {
+		setSynchronousMode(newRecorder);
+	}
+	recorder = newRecorder;
 	reInit();
 }
 
@@ -334,50 +336,108 @@ unsigned MSXMixer::getSampleRate() const
 void MSXMixer::update(const Setting& setting)
 {
 	if (&setting == &masterVolume) {
-		updateMasterVolume(masterVolume.getValue());
+		updateMasterVolume();
 	} else if (&setting == &speedSetting) {
 		reInit();
-	} else if (dynamic_cast<const EnumSetting<ChannelMode::Mode>* >(&setting)) {
-		Infos::iterator it = infos.begin();
-		while (it != infos.end() && it->second.modeSetting != &setting) {
-			++it;
-		}
-		assert(it != infos.end());
-		SoundDeviceInfo &info = it->second;
-		ChannelMode::Mode oldmode = info.mode;
-		info.mode = info.modeSetting->getValue();
-		vector<SoundDevice*> &dev = devices[oldmode];
-		dev.erase(remove(dev.begin(), dev.end(), it->first), dev.end());
-		devices[info.mode].push_back(it->first);
 	} else if (dynamic_cast<const IntegerSetting*>(&setting)) {
 		Infos::iterator it = infos.begin();
-		while (it != infos.end() && it->second.volumeSetting != &setting) {
+		while (it != infos.end() &&
+		       it->second.volumeSetting != &setting &&
+		       it->second.balanceSetting != &setting) {
 			++it;
 		}
 		assert(it != infos.end());
-		const SoundDeviceInfo& info = it->second;
-		it->first->setVolume(
-		     (masterVolume.getValue() * info.volumeSetting->getValue() *
-		      info.normalVolume) / (100 * 100));
+		updateVolumeParams(it);
+	} else if (dynamic_cast<const StringSetting*>(&setting)) {
+		changeRecordSetting(setting);
+	} else if (dynamic_cast<const BooleanSetting*>(&setting)) {
+		changeMuteSetting(setting);
 	} else {
 		assert(false);
 	}
 }
 
+void MSXMixer::changeRecordSetting(const Setting& setting)
+{
+	for (Infos::iterator it = infos.begin(); it != infos.end(); ++it) {
+		unsigned channel = 0;
+		for (vector<SoundDeviceInfo::ChannelSettings>::const_iterator it2 =
+			    it->second.channelSettings.begin();
+		     it2 != it->second.channelSettings.end();
+		     ++it2, ++channel) {
+			if (it2->recordSetting == &setting) {
+				it->first->recordChannel(
+					channel, it2->recordSetting->getValue());
+				return;
+			}
+		}
+	}
+	assert(false);
+}
+
+void MSXMixer::changeMuteSetting(const Setting& setting)
+{
+	for (Infos::iterator it = infos.begin(); it != infos.end(); ++it) {
+		unsigned channel = 0;
+		for (vector<SoundDeviceInfo::ChannelSettings>::const_iterator it2 =
+			    it->second.channelSettings.begin();
+		     it2 != it->second.channelSettings.end();
+		     ++it2, ++channel) {
+			if (it2->muteSetting == &setting) {
+				it->first->muteChannel(
+					channel, it2->muteSetting->getValue());
+				return;
+			}
+		}
+	}
+	assert(false);
+}
+
 void MSXMixer::update(const ThrottleManager& /*throttleManager*/)
 {
 	reInit();
 }
 
-// 0 <= mastervolume <= 100
-void MSXMixer::updateMasterVolume(int masterVolume)
+void MSXMixer::updateVolumeParams(Infos::iterator it)
 {
-	for (Infos::const_iterator it = infos.begin();
-	     it != infos.end(); ++it) {
-		const SoundDeviceInfo& info = it->second;
-		it->first->setVolume(
-		     (info.normalVolume * info.volumeSetting->getValue() *
-		      masterVolume) / (100 * 100));
+	SoundDeviceInfo& info = it->second;
+	int mVolume = masterVolume.getValue();
+	int dVolume = info.volumeSetting->getValue();
+	double volume = info.defaultVolume * mVolume * dVolume / (100.0 * 100.0);
+	int balance = info.balanceSetting->getValue();
+	double l1, r1, l2, r2;
+	if (it->first->isStereo()) {
+		if (balance < 0) {
+			double b = (balance + 100.0) / 100.0;
+			l1 = volume;
+			r1 = 0.0;
+			l2 = volume * sqrt(std::max(0.0, 1.0 - b));
+			r2 = volume * sqrt(std::max(0.0,       b));
+		} else {
+			double b = balance / 100.0;
+			l1 = volume * sqrt(std::max(0.0, 1.0 - b));
+			r1 = volume * sqrt(std::max(0.0,       b));
+			l2 = 0.0;
+			r2 = volume;
+		}
+	} else {
+		// make sure that in case of rounding errors
+		// we don't take sqrt() of negative numbers
+		double b = (balance + 100.0) / 200.0;
+		l1 = volume * sqrt(std::max(0.0, 1.0 - b));
+		r1 = volume * sqrt(std::max(0.0,       b));
+		l2 = r2 = 0.0; // dummy
+	}
+	info.left1  = int(l1 * 256);
+	info.right1 = int(r1 * 256);
+	info.left2  = int(l2 * 256);
+	info.right2 = int(r2 * 256);
+}
+
+void MSXMixer::updateMasterVolume()
+{
+	for (Infos::iterator it = infos.begin(); it != infos.end(); ++it) {
+		updateVolumeParams(it);
 	}
 }
 
@@ -387,7 +447,7 @@ void MSXMixer::executeUntil(const EmuTime& time, int /*userData*/)
 		updateStream2(time);
 		EmuDuration interval2 = interval1 * fragmentSize;
 		setSyncPoint(time + interval2);
-	} else if (recorder) {
+	} else if (synchronousCounter) {
 		updateStream2(time);
 		EmuDuration interval2 = interval1 * 512;
 		setSyncPoint(time + interval2);
@@ -403,7 +463,7 @@ const std::string& MSXMixer::schedName() const
 
 // Sound device info
 
-SoundDevice* MSXMixer::getSoundDevice(const string& name)
+SoundDevice* MSXMixer::findDevice(const string& name) const
 {
 	for (Infos::const_iterator it = infos.begin();
 	     it != infos.end(); ++it) {
@@ -432,7 +492,7 @@ void SoundDeviceInfoTopic::execute(const vector<TclObject*>& tokens,
 		}
 		break;
 	case 3: {
-		SoundDevice* device = mixer.getSoundDevice(tokens[2]->getString());
+		SoundDevice* device = mixer.findDevice(tokens[2]->getString());
 		if (!device) {
 			throw CommandException("Unknown sound device");
 		}
