@@ -1,11 +1,10 @@
-// $Id: MSXMoonSound.cc 6187 2007-03-21 23:06:21Z m9710797 $
+// $Id: MSXMoonSound.cc 6698 2007-07-02 10:42:35Z m9710797 $
 
 #include "MSXMoonSound.hh"
 #include "YMF262.hh"
 #include "YMF278.hh"
 #include "XMLElement.hh"
-#include "MSXMotherBoard.hh"
-#include "MSXMixer.hh"
+#include <cassert>
 
 namespace openmsx {
 
