@@ -1,4 +1,4 @@
-// $Id: MSXPSG.cc,v 1.50 2005/12/27 11:03:51 m9710797 Exp $
+// $Id: MSXPSG.cc 5993 2007-01-12 22:12:12Z m9710797 $
 
 #include "MSXPSG.hh"
 #include "AY8910.hh"
@@ -43,7 +43,7 @@ void MSXPSG::reset(const EmuTime& time)
 void MSXPSG::powerDown(const EmuTime& /*time*/)
 {
 	getMotherBoard().getEventDistributor().distributeEvent(
-		new LedEvent(LedEvent::KANA, false));
+		new LedEvent(LedEvent::KANA, false, getMotherBoard()));
 }
 
 byte MSXPSG::readIO(word /*port*/, const EmuTime& time)
@@ -76,7 +76,7 @@ void MSXPSG::writeIO(word port, byte value, const EmuTime& time)
 byte MSXPSG::readA(const EmuTime& time)
 {
 	byte joystick = ports[selectedPort]->read(time) |
-	                ((renShaTurbo.getSignal(time)) << 4);
+	                ((renShaTurbo.getSignal(time)) ? 0x10 : 0x00);
 	byte cassetteInput = cassette.cassetteIn(time) ? 0x80 : 0x00;
 	byte keyLayout = keyLayoutBit ? 0x40 : 0x00;
 	return joystick | keyLayout | cassetteInput;
@@ -92,7 +92,8 @@ void MSXPSG::writeB(byte value, const EmuTime& time)
 
 	if ((prev ^ value) & 0x80) {
 		getMotherBoard().getEventDistributor().distributeEvent(
-			new LedEvent(LedEvent::KANA, !(value & 0x80)));
+			new LedEvent(LedEvent::KANA, !(value & 0x80),
+			             getMotherBoard()));
 	}
 	prev = value;
 }
