@@ -1,4 +1,4 @@
-// $Id: Mixer.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: Mixer.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 #include "Mixer.hh"
 #include "MSXMixer.hh"
@@ -16,9 +16,9 @@
 namespace openmsx {
 
 Mixer::Mixer(CommandController& commandController_)
-	: muteCount(0)
-	, commandController(commandController_)
+	: commandController(commandController_)
 	, pauseSetting(commandController.getGlobalSettings().getPauseSetting())
+	, muteCount(0)
 {
 	// default values
 #ifdef _WIN32
@@ -151,7 +151,7 @@ void Mixer::muteHelper()
 		(*it)->setMixerParams(samples, frequency);
 		msxMute = true; // mute all but the first MSXMixer
 	}
-	
+
 	if (mute) {
 		driver->mute();
 	} else {
@@ -189,7 +189,7 @@ void Mixer::update(const Setting& setting)
 			unmute();
 		}
 	} else if ((&setting == samplesSetting.get()) ||
-	           (&setting == soundDriverSetting.get()) || 
+	           (&setting == soundDriverSetting.get()) ||
 	           (&setting == frequencySetting.get())) {
 		reloadDriver();
 	} else {
