@@ -1,17 +1,9 @@
-// $Id: NullSoundDriver.cc,v 1.2 2005/11/12 20:32:42 m9710797 Exp $
+// $Id: NullSoundDriver.cc 5924 2006-12-14 20:50:54Z m9710797 $
 
 #include "NullSoundDriver.hh"
 
 namespace openmsx {
 
-void NullSoundDriver::lock()
-{
-}
-
-void NullSoundDriver::unlock()
-{
-}
-
 void NullSoundDriver::mute()
 {
 }
@@ -27,11 +19,12 @@ unsigned NullSoundDriver::getFrequency() const
 
 unsigned NullSoundDriver::getSamples() const
 {
-	return 512;
+	return 0;
 }
 
-void NullSoundDriver::updateStream(const EmuTime& /*time*/)
+double NullSoundDriver::uploadBuffer(short* /*buffer*/, unsigned /*len*/)
 {
+	return 1.0;
 }
 
 } // namespace openmsx
