@@ -1,4 +1,4 @@
-// $Id: SCC.cc 6075 2007-02-12 20:59:56Z m9710797 $
+// $Id: SCC.cc 7197 2007-10-23 18:35:20Z m9710797 $
 
 //-----------------------------------------------------------------------------
 //
@@ -67,6 +67,9 @@
 //   - Channel 4-5 rotation speed is set by channel 5 freq (channel 4 freq
 //     is ignored for rotation)
 //
+// Also see this MRC thread:
+//  http://www.msx.org/forumtopicl7875.html
+//
 //-----------------------------------------------------------------------------
 //
 // On Sat, 09 Sep 2005, NYYRIKKI wrote (MRC post)
@@ -98,7 +101,6 @@
 #include "SCC.hh"
 #include "SimpleDebuggable.hh"
 #include "MSXMotherBoard.hh"
-#include <cmath>
 
 using std::string;
 
@@ -122,23 +124,25 @@ static string calcDescription(SCC::ChipMode mode)
 
 SCC::SCC(MSXMotherBoard& motherBoard, const string& name,
          const XMLElement& config, const EmuTime& time, ChipMode mode)
-	: SoundDevice(motherBoard.getMSXMixer(), name, calcDescription(mode))
-	, currentChipMode(mode)
-	, deformTimer(time)
+	: SoundDevice(motherBoard.getMSXMixer(), name, calcDescription(mode), 5)
+	, Resample(motherBoard.getGlobalSettings(), 1)
 	, debuggable(new SCCDebuggable(motherBoard, *this))
+	, deformTimer(time)
+	, currentChipMode(mode)
 {
-	// Clear wave forms.
+	// Clear all state that is unaffected by reset.
 	for (unsigned i = 0; i < 5; ++i) {
 		for (unsigned j = 0; j < 32; ++j) {
 			wave[i][j] = 0;
+			volAdjustedWave[i][j] = 0;
 		}
 		out[i] = 0;
-	}
-
-	nbSamples = 9999;
-
-	for (unsigned i = 0; i < sizeof(in)/sizeof(int); ++i) {
-		in[i] = 0;
+		count[i] = 0;
+		incr[i] = 0;
+		pos[i] = 0;
+		period[i] = 0;
+		orgPeriod[i] = 0;
+		volume[i] = 0;
 	}
 
 	reset(time);
@@ -157,31 +161,18 @@ void SCC::reset(const EmuTime& /*time*/)
 	}
 
 	for (unsigned i = 0; i < 5; ++i) {
-		for (unsigned j = 0; j < 32; ++j) {
-			// don't clear wave forms
-			volAdjustedWave[i][j] = 0;
-		}
-		count[i] = 0;
-		pos[i] = (unsigned)-1;
-		freq[i] = 0;
-		volume[i] = 0;
 		rotate[i] = false;
 		readOnly[i] = false;
 	}
 	deformValue = 0;
-	ch_enable = 0xFF;
-
-	checkMute();
+	ch_enable = 0;
 }
 
-void SCC::setSampleRate(int sampleRate)
+void SCC::setOutputRate(unsigned sampleRate)
 {
-	setResampleRatio(3579545.0 / 32, sampleRate);
-}
-
-void SCC::setVolume(int maxVolume)
-{
-	masterVolume = 2 * maxVolume;
+	double input = 3579545.0 / 32;
+	setInputRate(int(input + 0.5));
+	setResampleRatio(input, sampleRate);
 }
 
 void SCC::setChipMode(ChipMode newMode)
@@ -194,58 +185,58 @@ void SCC::setChipMode(ChipMode newMode)
 	currentChipMode = newMode;
 }
 
-byte SCC::readMemInterface(byte address, const EmuTime& time)
+byte SCC::readMem(byte addr, const EmuTime& time)
+{
+	// Deform-register locations:
+	//   SCC_Real:       0xE0..0xFF
+	//   SCC_Compatible: 0xC0..0xDF
+	//   SCC_plusmode:   0xC0..0xDF
+	if (((currentChipMode == SCC_Real) && (addr >= 0xE0)) ||
+	    ((currentChipMode != SCC_Real) && (0xC0 <= addr) && (addr < 0xE0))) {
+		setDeformReg(0xFF, time);
+	}
+	return peekMem(addr, time);
+}
+
+byte SCC::peekMem(byte address, const EmuTime& time) const
 {
 	byte result;
 	switch (currentChipMode) {
 	case SCC_Real:
 		if (address < 0x80) {
-			// read wave form 1..4
+			// 0x00..0x7F : read wave form 1..4
 			result = readWave(address >> 5, address, time);
-		} else if (address < 0xA0) {
-			// freq volume block
-			result = getFreqVol(address);
-		} else if (address < 0xE0) {
-			// no function
-			result = 0xFF;
 		} else {
-			// deformation register
-			setDeformReg(0xFF, time);
+			// 0x80..0x9F : freq volume block, write only
+			// 0xA0..0xDF : no function
+			// 0xE0..0xFF : deformation register
 			result = 0xFF;
 		}
 		break;
 	case SCC_Compatible:
 		if (address < 0x80) {
-			// read wave form 1..4
+			// 0x00..0x7F : read wave form 1..4
 			result = readWave(address >> 5, address, time);
 		} else if (address < 0xA0) {
-			// freq volume block
-			result = getFreqVol(address);
-		} else if (address < 0xC0) {
-			// read wave form 5
-			result = readWave(4, address, time);
-		} else if (address < 0xE0) {
-			// deformation register
-			setDeformReg(0xFF, time);
+			// 0x80..0x9F : freq volume block
 			result = 0xFF;
+		} else if (address < 0xC0) {
+			// 0xA0..0xBF : read wave form 5
+			result = readWave(4, address, time);
 		} else {
-			// no function
+			// 0xC0..0xDF : deformation register
+			// 0xE0..0xFF : no function
 			result = 0xFF;
 		}
 		break;
 	case SCC_plusmode:
 		if (address < 0xA0) {
-			// read wave form 1..5
+			// 0x00..0x9F : read wave form 1..5
 			result = readWave(address >> 5, address, time);
-		} else if (address < 0xC0) {
-			// freq volume block
-			result = getFreqVol(address);
-		} else if (address < 0xE0) {
-			// deformation register
-			setDeformReg(0xFF, time);
-			result = 0xFF;
 		} else {
-			// no function
+			// 0xA0..0xBF : freq volume block
+			// 0xC0..0xDF : deformation register
+			// 0xE0..0xFF : no function
 			result = 0xFF;
 		}
 		break;
@@ -257,30 +248,32 @@ byte SCC::readMemInterface(byte address, const EmuTime& time)
 	return result;
 }
 
-byte SCC::readWave(byte channel, byte address, const EmuTime& time)
+byte SCC::readWave(byte channel, byte address, const EmuTime& time) const
 {
 	if (!rotate[channel]) {
 		return wave[channel][address & 0x1F];
 	} else {
 		unsigned ticks = deformTimer.getTicksTill(time);
-		unsigned f = ((channel == 3) && (currentChipMode != SCC_plusmode)) ?
-			freq[4] : freq[channel];
-		unsigned shift = ticks / (f + 1);
+		unsigned periodCh = ((channel == 3) &&
+		                     (currentChipMode != SCC_plusmode) &&
+		                     ((deformValue & 0xC0) == 0x40))
+		                  ? 4 : channel;
+		unsigned shift = ticks / (period[periodCh] + 1);
 		return wave[channel][(address + shift) & 0x1F];
 	}
 }
 
 
-byte SCC::getFreqVol(byte address)
+byte SCC::getFreqVol(byte address) const
 {
 	address &= 0x0F;
 	if (address < 0x0A) {
 		// get frequency
 		byte channel = address / 2;
 		if (address & 1) {
-			return freq[channel] >> 8;
+			return orgPeriod[channel] >> 8;
 		} else {
-			return freq[channel] & 0xFF;
+			return orgPeriod[channel] & 0xFF;
 		}
 	} else if (address < 0x0F) {
 		// get volume
@@ -291,53 +284,53 @@ byte SCC::getFreqVol(byte address)
 	}
 }
 
-void SCC::writeMemInterface(byte address, byte value, const EmuTime& time)
+void SCC::writeMem(byte address, byte value, const EmuTime& time)
 {
 	updateStream(time);
 
 	switch (currentChipMode) {
 	case SCC_Real:
 		if (address < 0x80) {
-			// write wave form 1..4
+			// 0x00..0x7F : write wave form 1..4
 			writeWave(address >> 5, address, value);
 		} else if (address < 0xA0) {
-			// freq volume block
+			// 0x80..0x9F : freq volume block
 			setFreqVol(address, value);
 		} else if (address < 0xE0) {
-			// no function
+			// 0xA0..0xDF : no function
 		} else {
-			// deformation register
+			// 0xE0..0xFF : deformation register
 			setDeformReg(value, time);
 		}
 		break;
 	case SCC_Compatible:
 		if (address < 0x80) {
-			// write wave form 1..4
+			// 0x00..0x7F : write wave form 1..4
 			writeWave(address >> 5, address, value);
 		} else if (address < 0xA0) {
-			// freq volume block
+			// 0x80..0x9F : freq volume block
 			setFreqVol(address, value);
 		} else if (address < 0xC0) {
-			// ignore write wave form 5
+			// 0xA0..0xBF : ignore write wave form 5
 		} else if (address < 0xE0) {
-			// deformation register
+			// 0xC0..0xDF : deformation register
 			setDeformReg(value, time);
 		} else {
-			// no function
+			// 0xE0..0xFF : no function
 		}
 		break;
 	case SCC_plusmode:
 		if (address < 0xA0) {
-			// write wave form 1..5
+			// 0x00..0x9F : write wave form 1..5
 			writeWave(address >> 5, address, value);
 		} else if (address < 0xC0) {
-			// freq volume block
+			// 0xA0..0xBF : freq volume block
 			setFreqVol(address, value);
 		} else if (address < 0xE0) {
-			// deformation register
+			// 0xC0..0xDF : deformation register
 			setDeformReg(value, time);
 		} else {
-			// no function
+			// 0xE0..0xFF : no function
 		}
 		break;
 	default:
@@ -345,9 +338,10 @@ void SCC::writeMemInterface(byte address, byte value, const EmuTime& time)
 	}
 }
 
-static inline int adjust(signed char wav, byte vol)
+inline int SCC::adjust(signed char wav, byte vol)
 {
-	return (static_cast<int>(wav) * vol) / 16;
+	int tmp = (int(wav) * vol) / 16;
+	return tmp * 256;
 }
 
 void SCC::writeWave(byte channel, byte address, byte value)
@@ -370,32 +364,30 @@ void SCC::writeWave(byte channel, byte address, byte value)
 
 void SCC::setFreqVol(byte address, byte value)
 {
-	address &= 0x0F; // regio is twice visible
+	address &= 0x0F; // region is visible twice
 	if (address < 0x0A) {
 		// change frequency
 		byte channel = address / 2;
-		if (address & 1) {
-			freq[channel] = ((value & 0xF) << 8) |
-			                (freq[channel] & 0xFF);
-		} else {
-			freq[channel] = (freq[channel] & 0xF00) |
-			                (value & 0xFF);
-		}
-		if (deformValue & 0x20) {
-			count[channel] = 0;
-		}
-		unsigned frq = freq[channel];
+		unsigned per =
+			  (address & 1)
+			? ((value & 0xF) << 8) | (orgPeriod[channel] & 0xFF)
+			: (orgPeriod[channel] & 0xF00) | (value & 0xFF);
+		orgPeriod[channel] = per;
 		if (deformValue & 2) {
 			// 8 bit frequency
-			frq &= 0xFF;
+			per &= 0xFF;
 		} else if (deformValue & 1) {
 			// 4 bit frequency
-			frq >>= 8;
+			per >>= 8;
 		}
-		incr[channel] = (frq <= 8) ? 0 : (1 << 28) / (frq + 1);
-		count[channel] &= 0x0F800000; // reset to begin of byte
-		pos[channel] = (unsigned)-1;
-
+		period[channel] = per;
+		incr[channel] = (per <= 8) ? 0 : 32;
+		count[channel] = 0; // reset to begin of byte
+		if (deformValue & 0x20) {
+			pos[channel] = 0; // reset to begin of waveform
+		}
+		// after a freq change, update the output
+		out[channel] = volAdjustedWave[channel][pos[channel]];
 	} else if (address < 0x0F) {
 		// change volume
 		byte channel = address - 0x0A;
@@ -404,11 +396,9 @@ void SCC::setFreqVol(byte address, byte value)
 			volAdjustedWave[channel][i] =
 				adjust(wave[channel][i], volume[channel]);
 		}
-		checkMute();
 	} else {
 		// change enable-bits
 		ch_enable = value;
-		checkMute();
 	}
 }
 
@@ -424,123 +414,83 @@ void SCC::setDeformReg(byte value, const EmuTime& time)
 		value &= ~0x80;
 	}
 	switch (value & 0xC0) {
-		case 0x00:
-			for (unsigned i = 0; i < 5; ++i) {
-				rotate[i] = false;
-				readOnly[i] = false;
-			}
-			break;
-		case 0x40:
-			for (unsigned i = 0; i < 5; ++i) {
-				rotate[i] = true;
-				readOnly[i] = true;
-			}
-			break;
-		case 0x80:
-			for (unsigned i = 0; i < 3; ++i) {
-				rotate[i] = false;
-				readOnly[i] = false;
-			}
-			for (unsigned i = 3; i < 5; ++i) {
-				rotate[i] = true;
-				readOnly[i] = true;
-			}
-			break;
-		case 0xC0:
-			for (unsigned i = 0; i < 3; ++i) {
-				rotate[i] = true;
-				readOnly[i] = true;
-			}
-			for (unsigned i = 3; i < 5; ++i) {
-				rotate[i] = false;
-				readOnly[i] = true;
-			}
-			break;
-		default:
-			assert(false);
+	case 0x00:
+		for (unsigned i = 0; i < 5; ++i) {
+			rotate[i] = false;
+			readOnly[i] = false;
+		}
+		break;
+	case 0x40:
+		for (unsigned i = 0; i < 5; ++i) {
+			rotate[i] = true;
+			readOnly[i] = true;
+		}
+		break;
+	case 0x80:
+		for (unsigned i = 0; i < 3; ++i) {
+			rotate[i] = false;
+			readOnly[i] = false;
+		}
+		for (unsigned i = 3; i < 5; ++i) {
+			rotate[i] = true;
+			readOnly[i] = true;
+		}
+		break;
+	case 0xC0:
+		for (unsigned i = 0; i < 3; ++i) {
+			rotate[i] = true;
+			readOnly[i] = true;
+		}
+		for (unsigned i = 3; i < 5; ++i) {
+			rotate[i] = false;
+			readOnly[i] = true;
+		}
+		break;
+	default:
+		assert(false);
 	}
 }
 
-void SCC::generateInput(float* buffer, unsigned num)
+void SCC::generateChannels(int** bufs, unsigned num)
 {
-	nbSamples += num;
-	if ((deformValue & 0xC0) == 0x00) {
-		// No rotation stuff, this is almost always true. So it makes
-		// sense to have a special optimized routine for this case
-		for (unsigned j = 0; j < num; ++j) {
-			int mixed = 0;
-			byte enable = ch_enable;
-			for (int i = 0; i < 5; ++i, enable >>= 1) {
-				count[i] = (count[i] + incr[i]) & 0x0FFFFFFF;
-				unsigned newPos = count[i] >> 23;
-				if (newPos != pos[i]) {
-					pos[i] = newPos;
-					out[i] = volAdjustedWave[i][newPos];
-				}
-				if (enable & 1) {
-					mixed += out[i];
+	byte enable = ch_enable;
+	for (int i = 0; i < 5; ++i, enable >>= 1) {
+		if ((enable & 1) && (volume[i] || out[i])) {
+			for (unsigned j = 0; j < num; ++j) {
+				bufs[i][j] = out[i];
+				count[i] += incr[i];
+				// Note: Only for very small periods this loop will take
+				//       more than a single iteration.
+				while (count[i] > period[i]) {
+					pos[i] = (pos[i] + 1) % 32;
+					count[i] -= period[i] + 1;
+					out[i] = volAdjustedWave[i][pos[i]];
 				}
 			}
-			buffer[j] = (masterVolume * mixed) / 256;
-		}
-	} else {
-		// Rotation mode
-		//  TODO not completely correct
-		for (unsigned j = 0; j < num; ++j) {
-			int mixed = 0;
-			byte enable = ch_enable;
-			for (int i = 0; i < 5; ++i, enable >>= 1) {
-				unsigned cnt = count[i] + incr[i];
-				if (rotate[i]) {
-					cnt += (cnt >> 28) << 23;
-				}
-				count[i] = cnt & 0x0FFFFFFF;
-				unsigned newPos = count[i] >> 23;
-				if (newPos != pos[i]) {
-					pos[i] = newPos;
-					out[i] = volAdjustedWave[i][newPos];
-				}
-				if (enable & 1) {
-					mixed += out[i];
-				}
-			}
-			buffer[j] = (masterVolume * mixed) / 256;
+		} else {
+			bufs[i] = 0; // channel muted
+			// Update phase counter.
+			unsigned newCount = count[i] + num * incr[i];
+			count[i] = newCount % (period[i] + 1);
+			pos[i] = (pos[i] + newCount / (period[i] + 1)) % 32;
+			// Channel stays off until next waveform index.
+			out[i] = 0;
 		}
 	}
 }
 
-void SCC::updateBuffer(unsigned length, int* buffer,
-     const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
+bool SCC::generateInput(int* buffer, unsigned num)
 {
-	float tmpBuf[length];
-	generateOutput(tmpBuf, length);
-	for (unsigned i = 0; i < length; ++i) {
-		buffer[i] = lrintf(tmpBuf[i]);
-	}
+	return mixChannels(buffer, num);
 }
 
-void SCC::checkMute()
+bool SCC::updateBuffer(unsigned length, int* buffer,
+                       const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
 {
-	// SCC is muted unless an enabled channel with non-zero volume exists.
-	bool mute = true;
-	byte enable = ch_enable & 0x1F;
-	byte* volumePtr = volume;
-	while (enable) {
-		if ((enable & 1) && *volumePtr) {
-			mute = false;
-			break;
-		}
-		enable >>= 1;
-		++volumePtr;
-	}
-	if (!mute) {
-		nbSamples = 0;
-		setMute(false);
-	} else if (nbSamples > 4000) {
-		setMute(true);
-	}
+	return generateOutput(buffer, length);
 }
 
+
 // SimpleDebuggable
 
 SCCDebuggable::SCCDebuggable(MSXMotherBoard& motherBoard, SCC& scc_)
@@ -573,7 +523,7 @@ void SCCDebuggable::write(unsigned address, byte value, const EmuTime& time)
 		scc.writeWave(address >> 5, address, value);
 	} else if (address < 0xC0) {
 		// freq volume block
-		 scc.setFreqVol(address, value);
+		scc.setFreqVol(address, value);
 	} else if (address < 0xE0) {
 		// deformation register
 		scc.setDeformReg(value, time);
