@@ -1,4 +1,4 @@
-// $Id: SDLSoundDriver.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: SDLSoundDriver.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "SDLSoundDriver.hh"
 #include "MSXException.hh"
@@ -94,8 +94,8 @@ unsigned SDLSoundDriver::getSamples() const
 void SDLSoundDriver::audioCallbackHelper(void* userdata, byte* strm, int len)
 {
 	assert((len & 3) == 0); // stereo, 16-bit
-	((SDLSoundDriver*)userdata)->
-		audioCallback((short*)strm, len / sizeof(short));
+	static_cast<SDLSoundDriver*>(userdata)->
+		audioCallback(reinterpret_cast<short*>(strm), len / sizeof(short));
 }
 
 unsigned SDLSoundDriver::getBufferFilled() const
