@@ -1,4 +1,4 @@
-// $Id: SamplePlayer.cc 5954 2006-12-22 08:10:58Z mthuurne $
+// $Id: SamplePlayer.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "SamplePlayer.hh"
 #include <cassert>
@@ -7,7 +7,7 @@ namespace openmsx {
 
 SamplePlayer::SamplePlayer(MSXMixer& mixer, const std::string& name,
                            const std::string& desc, const XMLElement& config)
-	: SoundDevice(mixer, name, desc)
+	: SoundDevice(mixer, name, desc, 1)
 {
 	registerSound(config);
 	reset();
@@ -20,17 +20,12 @@ SamplePlayer::~SamplePlayer()
 
 void SamplePlayer::reset()
 {
-	setMute(true);
 	playing = false;
 }
 
-void SamplePlayer::setVolume(int newVolume)
-{
-	volume = newVolume * 3;
-}
-
-void SamplePlayer::setSampleRate(int sampleRate)
+void SamplePlayer::setOutputRate(unsigned sampleRate)
 {
+	setInputRate(sampleRate);
 	outFreq = sampleRate;
 }
 
@@ -46,7 +41,6 @@ void SamplePlayer::play(const void* buffer, unsigned bufferSize,
 
 	step = (inFreq << 8) / outFreq;
 
-	setMute(false);
 	playing = true;
 }
 
@@ -58,26 +52,28 @@ bool SamplePlayer::isPlaying() const
 inline int SamplePlayer::getSample(unsigned index)
 {
 	return bits8
-	     ? (((unsigned char*)sampBuf)[index] - 0x80) * 256
-	     : ((short*)sampBuf)[index];
+	     ? (static_cast<const unsigned char*>(sampBuf)[index] - 0x80) * 256
+	     :  static_cast<const short*        >(sampBuf)[index];
 }
 
-void SamplePlayer::updateBuffer(unsigned length, int* output,
-        const EmuTime& /*start*/, const EmuDuration& /*sampDur*/)
+void SamplePlayer::generateChannels(int** bufs, unsigned num)
 {
-	for (unsigned i = 0; i < length; ++i) {
+	if (!playing) {
+		bufs[0] = 0;
+		return;
+	}
+	for (unsigned i = 0; i < num; ++i) {
 		if (count < end) {
 			unsigned index = count >> 8;
 			int frac  = count & 0xFF;
 			int samp0 = getSample(index);
 			int samp1 = getSample(index + 1);
 			int samp  = ((0x100 - frac) * samp0 + frac * samp1) >> 8;
-			output[i] = (samp * volume) >> 15;
+			bufs[0][i] = 3 * samp;
 			count += step;
 		} else {
-			setMute(true);
 			playing = false;
-			output[i] = 0;
+			bufs[0][i] = 0;
 		}
 	}
 }
