@@ -1,4 +1,4 @@
-// $Id: WavAudioInput.cc 5074 2006-01-24 18:03:35Z m9710797 $
+// $Id: WavAudioInput.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "WavAudioInput.hh"
 #include "MSXException.hh"
@@ -11,13 +11,13 @@ using std::string;
 namespace openmsx {
 
 WavAudioInput::WavAudioInput(CommandController& commandController)
-	: length(0), buffer(0), freq(44100)
-	, reference(EmuTime::zero)
-	, plugged(false)
-	, audioInputFilenameSetting(new FilenameSetting(
+	: audioInputFilenameSetting(new FilenameSetting(
 		commandController, "audio-inputfilename",
 		"filename of the file where the sampler reads data from",
 		"audio-input.wav"))
+	, reference(EmuTime::zero)
+	, buffer(0), length(0), freq(44100)
+	, plugged(false)
 {
 	audioInputFilenameSetting->attach(*this);
 }
@@ -50,8 +50,8 @@ void WavAudioInput::loadWave()
 		throw MSXException("Couldn't build wav converter");
 	}
 
-	buffer = (Uint8 *)malloc(wavLen * audioCVT.len_mult);
-	audioCVT.buf = buffer;
+	buffer = static_cast<short*>(malloc(wavLen * audioCVT.len_mult));
+	audioCVT.buf = reinterpret_cast<byte*>(buffer);
 	audioCVT.len = wavLen;
 	memcpy(buffer, wavBuf, wavLen);
 	SDL_FreeWAV(wavBuf);
@@ -60,7 +60,7 @@ void WavAudioInput::loadWave()
 		freeWave();
 		throw MSXException("Couldn't convert wav file to internal format");
 	}
-	length = (int)(audioCVT.len * audioCVT.len_ratio) / 2;
+	length = int(audioCVT.len * audioCVT.len_ratio) / 2;
 }
 
 void WavAudioInput::freeWave()
@@ -126,7 +126,7 @@ short WavAudioInput::readSample(const EmuTime& time)
 {
 	int pos = (time - reference).getTicksAt(freq);
 	if (pos < length) {
-		return ((short *)buffer)[pos];
+		return buffer[pos];
 	} else {
 		return 0;
 	}
