@@ -1,8 +1,10 @@
-// $Id: WavWriter.cc 5989 2007-01-11 15:27:35Z m9710797 $
+// $Id: WavWriter.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "WavWriter.hh"
 #include "MSXException.hh"
+#include "Math.hh"
 #include "build-info.hh"
+#include <algorithm>
 
 namespace openmsx {
 
@@ -50,11 +52,11 @@ WavWriter::WavWriter(const std::string& filename,
 		0, 0, 0, 0,         // size of data block (filled in later)
 	};
 
-	*(short*)   (header + 22) = litEnd_16(channels);
-	*(unsigned*)(header + 24) = litEnd_32(frequency);
-	*(unsigned*)(header + 28) = litEnd_32((channels * frequency * bits) / 8);
-	*(short*)   (header + 32) = litEnd_16((channels * bits) / 8);
-	*(short*)   (header + 34) = litEnd_16(bits);
+	*reinterpret_cast<short*>   (header + 22) = litEnd_16(channels);
+	*reinterpret_cast<unsigned*>(header + 24) = litEnd_32(frequency);
+	*reinterpret_cast<unsigned*>(header + 28) = litEnd_32((channels * frequency * bits) / 8);
+	*reinterpret_cast<short*>   (header + 32) = litEnd_16((channels * bits) / 8);
+	*reinterpret_cast<short*>   (header + 34) = litEnd_16(bits);
 
 	fwrite(header, sizeof(header), 1, wavfp);
 }
@@ -98,6 +100,22 @@ void WavWriter::write16stereo(short* buffer, unsigned samples)
 	bytes += size;
 }
 
+void WavWriter::write16mono(int* buffer, unsigned samples)
+{
+	short buf[samples];
+	for (unsigned i = 0; i < samples; ++i) {
+		buf[i] = litEnd_16(Math::clipIntToShort(buffer[i]));
+	}
+	unsigned size = sizeof(short) * samples;
+	fwrite(buf, 1, size, wavfp);
+	bytes += size;
+}
+
+void WavWriter::write16stereo(int* buffer, unsigned samples)
+{
+	write16mono(buffer, 2 * samples);
+}
+
 void WavWriter::flush()
 {
 	// round totalsize up to next even number
