@@ -1,65 +1,47 @@
-// $Id: Y8950Adpcm.cc 5623 2006-09-12 15:42:58Z m9710797 $
+// $Id: Y8950Adpcm.cc 6933 2007-09-08 21:26:27Z m9710797 $
 
 #include "Y8950Adpcm.hh"
 #include "Y8950.hh"
 #include "Clock.hh"
 #include "Ram.hh"
 #include "MSXMotherBoard.hh"
+#include "Math.hh"
+#include <cstring>
 
 namespace openmsx {
 
 // Relative volume between ADPCM part and FM part,
 // value experimentally found by Manuel Bilderbeek
-const int ADPCM_VOLUME = 356;
+static const int ADPCM_VOLUME = 356;
 
 // Bitmask for register 0x07
 static const int R07_RESET        = 0x01;
 //static const int R07            = 0x02;.      // not used
 //static const int R07            = 0x04;.      // not used
-const int R07_SP_OFF       = 0x08;
-const int R07_REPEAT       = 0x10;
-const int R07_MEMORY_DATA  = 0x20;
-const int R07_REC          = 0x40;
-const int R07_START        = 0x80;
-const int R07_MODE         = 0xE0;
+static const int R07_SP_OFF       = 0x08;
+static const int R07_REPEAT       = 0x10;
+static const int R07_MEMORY_DATA  = 0x20;
+static const int R07_REC          = 0x40;
+static const int R07_START        = 0x80;
+static const int R07_MODE         = 0xE0;
 
 //Bitmask for register 0x08
-const int R08_ROM          = 0x01;
-const int R08_64K          = 0x02;
-const int R08_DA_AD        = 0x04;
-const int R08_SAMPL        = 0x08;
-//const int R08            = 0x10;.      // not used
-//const int R08            = 0x20;.      // not used
-const int R08_NOTE_SET     = 0x40;
-const int R08_CSM          = 0x80;
+static const int R08_ROM          = 0x01;
+static const int R08_64K          = 0x02;
+static const int R08_DA_AD        = 0x04;
+static const int R08_SAMPL        = 0x08;
+//static const int R08            = 0x10;.      // not used
+//static const int R08            = 0x20;.      // not used
+static const int R08_NOTE_SET     = 0x40;
+static const int R08_CSM          = 0x80;
 
-const int DMAX = 0x6000;
-const int DMIN = 0x7F;
-const int DDEF = 0x7F;
+static const int DMAX = 0x6000;
+static const int DMIN = 0x7F;
+static const int DDEF = 0x7F;
 
-const int DECODE_MAX = 32767;
-const int DECODE_MIN = -32768;
+static const int STEP_BITS = 16;
+static const int STEP_MASK = (1 << STEP_BITS) -1;
 
-const int GETA_BITS  = 14;
-const unsigned int MAX_STEP   = 1<<(16+GETA_BITS);
-
-
-//**************************************************//
-//                                                  //
-//  Helper functions                                //
-//                                                  //
-//**************************************************//
-
-static int CLAP(int min, int x, int max)
-{
-	return (x < min) ? min : ((max < x) ? max : x);
-}
-
-//**********************************************************//
-//                                                          //
-//  Y8950Adpcm                                              //
-//                                                          //
-//**********************************************************//
 
 Y8950Adpcm::Y8950Adpcm(Y8950& y8950_, MSXMotherBoard& motherBoard,
                        const std::string& name, unsigned sampleRam)
@@ -80,21 +62,16 @@ void Y8950Adpcm::reset(const EmuTime &time)
 	startAddr = 0;
 	stopAddr = 7;
 	delta = 0;
-	step = 0;
 	addrMask = (1 << 18) - 1;
 	reg7 = 0;
 	reg15 = 0;
 	readDelay = 0;
-	writeReg(0x12, 255, time);	// volume
+	romBank = false;
+	writeReg(0x12, 255, time); // volume
 	restart();
 	y8950.setStatus(Y8950::STATUS_BUF_RDY);
 }
 
-void Y8950Adpcm::setSampleRate(int sr)
-{
-	sampleRate = sr;
-}
-
 bool Y8950Adpcm::playing() const
 {
 	return (reg7 & 0xC0) == 0x80;
@@ -104,28 +81,22 @@ bool Y8950Adpcm::muted() const
 	return !playing() || (reg7 & R07_SP_OFF);
 }
 
-//**************************************************//
-//                                                  //
-//                       I/O Ctrl                   //
-//                                                  //
-//**************************************************//
-
 void Y8950Adpcm::restart()
 {
 	memPntr = startAddr;
-	nowStep = MAX_STEP - step;
+	nowStep = (1 << STEP_BITS) - delta;
 	out = output = 0;
 	diff = DDEF;
 	nextLeveling = 0;
 	sampleStep = 0;
-	volumeWStep = (int)((double)volume * step / MAX_STEP);
+	volumeWStep = (volume * delta) >> STEP_BITS;
 }
 
 void Y8950Adpcm::schedule(const EmuTime& time)
 {
 	if ((stopAddr > startAddr) && (delta != 0)) {
 		uint64 samples = stopAddr - memPntr + 1;
-		Clock<Y8950::CLK_FREQ> stop(time);
+		Clock<Y8950::CLOCK_FREQ> stop(time);
 		stop += (samples * (72 << 16) / delta);
 		setSyncPoint(stop.getTime());
 	}
@@ -199,24 +170,22 @@ void Y8950Adpcm::writeReg(byte rg, byte data, const EmuTime &time)
 
 	case 0x10: // DELTA-N (L)
 		delta = (delta & 0xFF00) | data;
-		step = Y8950::rate_adjust(delta << GETA_BITS, sampleRate);
-		volumeWStep = (int)((double)volume * step / MAX_STEP);
+		volumeWStep = (volume * delta) >> STEP_BITS;
 		break;
 	case 0x11: // DELTA-N (H)
 		delta = (delta & 0x00FF) | (data << 8);
-		step = Y8950::rate_adjust(delta << GETA_BITS, sampleRate);
-		volumeWStep = (int)((double)volume * step / MAX_STEP);
+		volumeWStep = (volume * delta) >> STEP_BITS;
 		break;
 
 	case 0x12: { // ENVELOP CONTROL
 		int oldVol = volume;
 		volume = (data * ADPCM_VOLUME) >> 8;
 		if (oldVol != 0) {
-			double factor = (double)volume / (double)oldVol;
-			output =     (int)((double)output     * factor);
-			sampleStep = (int)((double)sampleStep * factor);
+			double factor = double(volume) / double(oldVol);
+			output     = int(double(output)     * factor);
+			sampleStep = int(double(sampleStep) * factor);
 		}
-		volumeWStep = (int)((double)volume * step / MAX_STEP);
+		volumeWStep = (volume * delta) >> STEP_BITS;
 		break;
 	}
 	case 0x0D: // PRESCALE (L)
@@ -366,57 +335,54 @@ byte Y8950Adpcm::readMemory() const
 int Y8950Adpcm::calcSample()
 {
 	// This table values are from ymdelta.c by Tatsuyuki Satoh.
-	static const int F1[16] = { 1,   3,   5,   7,   9,  11,  13,  15,
-				   -1,  -3,  -5,  -7,  -9, -11, -13, -15};
-	static const int F2[16] = {57,  57,  57,  57,  77, 102, 128, 153,
-				   57,  57,  57,  57,  77, 102, 128, 153};
+	static const int F1[16] = {  1,   3,   5,   7,   9,  11,  13,  15,
+	                            -1,  -3,  -5,  -7,  -9, -11, -13, -15 };
+	static const int F2[16] = { 57,  57,  57,  57,  77, 102, 128, 153,
+	                            57,  57,  57,  57,  77, 102, 128, 153 };
 
 	if (muted()) {
 		return 0;
 	}
-	nowStep += step;
-	if (nowStep >= MAX_STEP) {
-		int nowLeveling;
-		do {
-			nowStep -= MAX_STEP;
-			byte val;
-			if (!(memPntr & 1)) {
-				// n-th nibble
-				if (reg7 & R07_MEMORY_DATA) {
-					adpcm_data = readMemory();
-				} else {
-					adpcm_data = reg15;
-					// set BRDY bit, ready to accept new data
-					y8950.setStatus(Y8950::STATUS_BUF_RDY);
-				}
-				val = adpcm_data >> 4;
+	nowStep += delta;
+	if (nowStep & ~STEP_MASK) {
+		nowStep &= STEP_MASK;
+		byte val;
+		if (!(memPntr & 1)) {
+			// n-th nibble
+			if (reg7 & R07_MEMORY_DATA) {
+				adpcm_data = readMemory();
 			} else {
-				// (n+1)-th nibble
-				val = adpcm_data & 0x0F;
+				adpcm_data = reg15;
+				// set BRDY bit, ready to accept new data
+				y8950.setStatus(Y8950::STATUS_BUF_RDY);
 			}
-			int prevOut = out;
-			out = CLAP(DECODE_MIN, out + (diff * F1[val]) / 8,
-			           DECODE_MAX);
-			diff = CLAP(DMIN, (diff * F2[val]) / 64, DMAX);
-			int deltaNext = out - prevOut;
-			nowLeveling = nextLeveling;
-			nextLeveling = prevOut + deltaNext / 2;
+			val = adpcm_data >> 4;
+		} else {
+			// (n+1)-th nibble
+			val = adpcm_data & 0x0F;
+		}
+		int prevOut = out;
+		out = Math::clipIntToShort(out + (diff * F1[val]) / 8);
+		diff = Math::clip<DMIN, DMAX>((diff * F2[val]) / 64);
+		int deltaNext = out - prevOut;
+		int nowLeveling = nextLeveling;
+		nextLeveling = prevOut + deltaNext / 2;
 
-			memPntr++;
-			if ((reg7 & R07_MEMORY_DATA) &&
-			    (memPntr > stopAddr)) {
-				if (reg7 & R07_REPEAT) {
-					restart();
-				} else {
-					reg7 = 0;
-					// decoupled from audio thread
-					//y8950.setStatus(Y8950::STATUS_EOS);
-				}
+		memPntr++;
+		if ((reg7 & R07_MEMORY_DATA) &&
+		    (memPntr > stopAddr)) {
+			if (reg7 & R07_REPEAT) {
+				restart();
+			} else {
+				reg7 = 0;
+				// decoupled from audio thread
+				//y8950.setStatus(Y8950::STATUS_EOS);
 			}
-		} while (nowStep >= MAX_STEP);
-		sampleStep = (nextLeveling - nowLeveling) * volumeWStep;
-		output = nowLeveling * volume;
-		output += (int)((double)sampleStep * ((double)nowStep/(double)step));
+		}
+		int deltaLeveling = nextLeveling - nowLeveling;
+		sampleStep = deltaLeveling * volumeWStep;
+		int tmp = deltaLeveling * ((volume * nowStep) >> STEP_BITS);
+		output = nowLeveling * volume + tmp;
 	}
 	output += sampleStep;
 	return output >> 12;
