@@ -1,9 +1,15 @@
-// $Id: YMF278.cc 6187 2007-03-21 23:06:21Z m9710797 $
+// $Id: YMF278.cc 6786 2007-08-04 10:29:59Z m9710797 $
+
+// Based on ymf278b.c written by R. Belmont and O. Galibert
 
 #include "YMF278.hh"
+#include "SoundDevice.hh"
+#include "Resample.hh"
 #include "Rom.hh"
 #include "SimpleDebuggable.hh"
 #include "MSXMotherBoard.hh"
+#include "Clock.hh"
+#include <algorithm>
 #include <cmath>
 
 namespace openmsx {
@@ -11,30 +17,164 @@ namespace openmsx {
 class DebugRegisters : public SimpleDebuggable
 {
 public:
-	DebugRegisters(YMF278& ymf278, MSXMotherBoard& motherBoard);
+	DebugRegisters(YMF278Impl& ymf278, MSXMotherBoard& motherBoard);
 	virtual byte read(unsigned address);
 	virtual void write(unsigned address, byte value, const EmuTime& time);
 private:
-	YMF278& ymf278;
+	YMF278Impl& ymf278;
 };
 
 class DebugMemory : public SimpleDebuggable
 {
 public:
-	DebugMemory(YMF278& ymf278, MSXMotherBoard& motherBoard);
+	DebugMemory(YMF278Impl& ymf278, MSXMotherBoard& motherBoard);
 	virtual byte read(unsigned address);
 	virtual void write(unsigned address, byte value);
 private:
-	YMF278& ymf278;
+	YMF278Impl& ymf278;
 };
 
+class YMF278Slot
+{
+public:
+	YMF278Slot();
+	void reset();
+	int compute_rate(int val);
+	unsigned decay_rate(int num, int sample_rate);
+	void envelope_next(int sample_rate);
+	inline int compute_vib();
+	inline int compute_am();
+	void set_lfo(int newlfo);
 
-const EmuDuration YMF278::REG_SELECT_DELAY = MasterClock::duration(88);
-const EmuDuration YMF278::REG_WRITE_DELAY = MasterClock::duration(88);
-const EmuDuration YMF278::MEM_READ_DELAY = MasterClock::duration(38);
-const EmuDuration YMF278::MEM_WRITE_DELAY = MasterClock::duration(28);
+	unsigned startaddr;
+	unsigned loopaddr;
+	unsigned endaddr;
+	unsigned step;		// fixed-point frequency step
+	unsigned stepptr;	// fixed-point pointer into the sample
+	unsigned pos;
+	short sample1, sample2;
+
+	int env_vol;
+	unsigned env_vol_step;
+	unsigned env_vol_lim;
+
+	int lfo_cnt;
+	int lfo_step;
+	int lfo_max;
+
+	int DL;
+	short wave;		// wavetable number
+	short FN;		// f-number
+	char OCT;		// octave
+	char PRVB;		// pseudo-reverb
+	char LD;		// level direct
+	char TL;		// total level
+	char pan;		// panpot
+	char lfo;		// LFO
+	char vib;		// vibrato
+	char AM;		// AM level
+	char AR;
+	char D1R;
+	char D2R;
+	char RC;		// rate correction
+	char RR;
+
+	byte bits;		// width of the samples
+	bool active;		// slot keyed on
+
+	byte state;
+	bool lfo_active;
+};
+
+class YMF278Impl : public SoundDevice, private Resample
+{
+public:
+	YMF278Impl(MSXMotherBoard& motherBoard, const std::string& name,
+	       int ramSize, const XMLElement& config, const EmuTime& time);
+	virtual ~YMF278Impl();
+	void reset(const EmuTime& time);
+	void writeRegOPL4(byte reg, byte data, const EmuTime& time);
+	byte readReg(byte reg, const EmuTime& time);
+	byte peekReg(byte reg) const;
+	byte readStatus(const EmuTime& time);
+	byte peekStatus(const EmuTime& time) const;
+
+private:
+	// SoundDevice
+	virtual void setOutputRate(unsigned sampleRate);
+	virtual void generateChannels(int** bufs, unsigned num);
+	virtual bool updateBuffer(unsigned length, int* buffer,
+		const EmuTime& time, const EmuDuration& sampDur);
+
+	// Resample
+	virtual bool generateInput(int* buffer, unsigned num);
+
+	void writeReg(byte reg, byte data, const EmuTime& time);
+	byte readMem(unsigned address) const;
+	void writeMem(unsigned address, byte value);
+	short getSample(YMF278Slot& op);
+	void advance();
+	bool anyActive();
+	void keyOnHelper(YMF278Slot& slot);
+
+	friend class DebugRegisters;
+	friend class DebugMemory;
+	const std::auto_ptr<DebugRegisters> debugRegisters;
+	const std::auto_ptr<DebugMemory>    debugMemory;
+
+	/** The master clock, running at 33MHz. */
+	typedef Clock<33868800> MasterClock;
+
+	/** Required delay between register select and register read/write.
+	  * TODO: Not used yet: register selection is done in MSXMoonSound class,
+	  *       but it should be moved here.
+	  */
+	static const EmuDuration REG_SELECT_DELAY;
+	/** Required delay after register write. */
+	static const EmuDuration REG_WRITE_DELAY;
+	/** Required delay after memory read. */
+	static const EmuDuration MEM_READ_DELAY;
+	/** Required delay after memory write (instead of register write delay). */
+	static const EmuDuration MEM_WRITE_DELAY;
+	/** Required delay after instrument load. */
+	static const EmuDuration LOAD_DELAY;
+
+	/** Time at which instrument loading is finished. */
+	EmuTime loadTime;
+	/** Time until which the YMF278 is busy. */
+	EmuTime busyTime;
+
+	YMF278Slot slots[24];
+
+	/** Global envelope generator counter. */
+	unsigned eg_cnt;
+
+	int memadr;
+
+	int fm_l, fm_r;
+	int pcm_l, pcm_r;
+
+	const std::auto_ptr<Rom> rom;
+	byte* ram;
+	unsigned endRom;
+	unsigned endRam;
+
+	/** Precalculated attenuation values with some marging for
+	  * enveloppe and pan levels.
+	  */
+	int volume[256 * 4];
+
+	byte regs[256];
+	char wavetblhdr;
+	char memmode;
+};
+
+const EmuDuration YMF278Impl::REG_SELECT_DELAY = MasterClock::duration(88);
+const EmuDuration YMF278Impl::REG_WRITE_DELAY = MasterClock::duration(88);
+const EmuDuration YMF278Impl::MEM_READ_DELAY = MasterClock::duration(38);
+const EmuDuration YMF278Impl::MEM_WRITE_DELAY = MasterClock::duration(28);
 // 10000 ticks is approx 300us; exact delay is unknown.
-const EmuDuration YMF278::LOAD_DELAY = MasterClock::duration(10000);
+const EmuDuration YMF278Impl::LOAD_DELAY = MasterClock::duration(10000);
 
 const int EG_SH = 16;	// 16.16 fixed point (EG timing)
 const unsigned EG_TIMER_OVERFLOW = 1 << EG_SH;
@@ -71,7 +211,7 @@ const int mix_level[8] = {
 
 // decay level table (3dB per step)
 // 0 - 15: 0, 3, 6, 9,12,15,18,21,24,27,30,33,36,39,42,93 (dB)
-#define SC(db) (unsigned)(db * (2.0 / ENV_STEP))
+#define SC(db) unsigned(db * (2.0 / ENV_STEP))
 const unsigned dl_tab[16] = {
  SC( 0), SC( 1), SC( 2), SC(3 ), SC(4 ), SC(5 ), SC(6 ), SC( 7),
  SC( 8), SC( 9), SC(10), SC(11), SC(12), SC(13), SC(14), SC(31)
@@ -149,7 +289,7 @@ const byte eg_rate_shift[64] = {
 
 //number of steps to take in quarter of lfo frequency
 //TODO check if frequency matches real chip
-#define O(a) ((int)((EG_TIMER_OVERFLOW / a) / 6))
+#define O(a) int((EG_TIMER_OVERFLOW / a) / 6)
 const int lfo_period[8] = {
 	O(0.168), O(2.019), O(3.196), O(4.206),
 	O(5.215), O(5.888), O(6.224), O(7.066)
@@ -157,7 +297,7 @@ const int lfo_period[8] = {
 #undef O
 
 
-#define O(a) ((int)(a * 65536))
+#define O(a) int(a * 65536)
 const int vib_depth[8] = {
 	O(0),	   O(3.378),  O(5.065),  O(6.750),
 	O(10.114), O(20.170), O(40.106), O(79.307)
@@ -165,7 +305,7 @@ const int vib_depth[8] = {
 #undef O
 
 
-#define SC(db) (unsigned) (db * (2.0 / ENV_STEP))
+#define SC(db) unsigned(db * (2.0 / ENV_STEP))
 const int am_depth[8] = {
 	SC(0),	   SC(1.781), SC(2.906), SC(3.656),
 	SC(4.406), SC(5.906), SC(7.406), SC(11.91)
@@ -222,14 +362,14 @@ int YMF278Slot::compute_rate(int val)
 
 int YMF278Slot::compute_vib()
 {
-	return (((lfo_step << 8) / lfo_max) * vib_depth[(int)vib]) >> 24;
+	return (((lfo_step << 8) / lfo_max) * vib_depth[int(vib)]) >> 24;
 }
 
 
 int YMF278Slot::compute_am()
 {
 	if (lfo_active && AM) {
-		return (((lfo_step << 8) / lfo_max) * am_depth[(int)AM]) >> 12;
+		return (((lfo_step << 8) / lfo_max) * am_depth[int(AM)]) >> 12;
 	} else {
 		return 0;
 	}
@@ -241,168 +381,159 @@ void YMF278Slot::set_lfo(int newlfo)
 	lfo_cnt  = (((lfo_cnt  << 8) / lfo_max) * newlfo) >> 8;
 
 	lfo = newlfo;
-	lfo_max = lfo_period[(int)lfo];
+	lfo_max = lfo_period[int(lfo)];
 }
 
 
-void YMF278::advance()
+void YMF278Impl::advance()
 {
-	eg_timer += eg_timer_add;
-	while (eg_timer >= EG_TIMER_OVERFLOW) {
-		eg_timer -= EG_TIMER_OVERFLOW;
-		eg_cnt++;
+	eg_cnt++;
+	for (int i = 0; i < 24; i++) {
+		YMF278Slot &op = slots[i];
 
-		for (int i = 0; i < 24; i++) {
-			YMF278Slot &op = slots[i];
+		if (op.lfo_active) {
+			op.lfo_cnt++;
+			if (op.lfo_cnt < op.lfo_max) {
+				op.lfo_step++;
+			} else if (op.lfo_cnt < (op.lfo_max * 3)) {
+				op.lfo_step--;
+			} else {
+				op.lfo_step++;
+				if (op.lfo_cnt == (op.lfo_max * 4)) {
+					op.lfo_cnt = 0;
+				}
+			}
+		}
 
-			if (op.lfo_active) {
-				op.lfo_cnt++;
-				if (op.lfo_cnt < op.lfo_max) {
-					op.lfo_step++;
-				} else if (op.lfo_cnt < (op.lfo_max * 3)) {
-					op.lfo_step--;
+		// Envelope Generator
+		switch(op.state) {
+		case EG_ATT: {	// attack phase
+			byte rate = op.compute_rate(op.AR);
+			if (rate < 4) {
+				break;
+			}
+			byte shift = eg_rate_shift[rate];
+			if (!(eg_cnt & ((1 << shift) -1))) {
+				byte select = eg_rate_select[rate];
+				op.env_vol += (~op.env_vol * eg_inc[select + ((eg_cnt >> shift) & 7)]) >> 3;
+				if (op.env_vol <= MIN_ATT_INDEX) {
+					op.env_vol = MIN_ATT_INDEX;
+					if (op.DL) {
+						op.state = EG_DEC;
+					} else {
+						op.state = EG_SUS;
+					}
+				}
+			}
+			break;
+		}
+		case EG_DEC: {	// decay phase
+			byte rate = op.compute_rate(op.D1R);
+			if (rate < 4) {
+				break;
+			}
+			byte shift = eg_rate_shift[rate];
+			if (!(eg_cnt & ((1 << shift) -1))) {
+				byte select = eg_rate_select[rate];
+				op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
+
+				if ((unsigned(op.env_vol) > dl_tab[6]) && op.PRVB) {
+					op.state = EG_REV;
 				} else {
-					op.lfo_step++;
-					if (op.lfo_cnt == (op.lfo_max * 4)) {
-						op.lfo_cnt = 0;
+					if (op.env_vol >= op.DL) {
+						op.state = EG_SUS;
 					}
 				}
 			}
-
-			// Envelope Generator
-			switch(op.state) {
-			case EG_ATT: {	// attack phase
-				byte rate = op.compute_rate(op.AR);
-				if (rate < 4) {
-					break;
-				}
-				byte shift = eg_rate_shift[rate];
-				if (!(eg_cnt & ((1 << shift) -1))) {
-					byte select = eg_rate_select[rate];
-					op.env_vol += (~op.env_vol * eg_inc[select + ((eg_cnt >> shift) & 7)]) >> 3;
-					if (op.env_vol <= MIN_ATT_INDEX) {
-						op.env_vol = MIN_ATT_INDEX;
-						if (op.DL) {
-							op.state = EG_DEC;
-						} else {
-							op.state = EG_SUS;
-						}
-					}
-				}
+			break;
+		}
+		case EG_SUS: {	// sustain phase
+			byte rate = op.compute_rate(op.D2R);
+			if (rate < 4) {
 				break;
 			}
-			case EG_DEC: {	// decay phase
-				byte rate = op.compute_rate(op.D1R);
-				if (rate < 4) {
-					break;
-				}
-				byte shift = eg_rate_shift[rate];
-				if (!(eg_cnt & ((1 << shift) -1))) {
-					byte select = eg_rate_select[rate];
-					op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
-
-					if (((unsigned)op.env_vol > dl_tab[6]) && op.PRVB) {
-						op.state = EG_REV;
-					} else {
-						if (op.env_vol >= op.DL) {
-							op.state = EG_SUS;
-						}
-					}
-				}
-				break;
-			}
-			case EG_SUS: {	// sustain phase
-				byte rate = op.compute_rate(op.D2R);
-				if (rate < 4) {
-					break;
-				}
-				byte shift = eg_rate_shift[rate];
-				if (!(eg_cnt & ((1 << shift) -1))) {
-					byte select = eg_rate_select[rate];
-					op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
-
-					if (((unsigned)op.env_vol > dl_tab[6]) && op.PRVB) {
-						op.state = EG_REV;
-					} else {
-						if (op.env_vol >= MAX_ATT_INDEX) {
-							op.env_vol = MAX_ATT_INDEX;
-							op.active = false;
-							checkMute();
-						}
-					}
-				}
-				break;
-			}
-			case EG_REL: {	// release phase
-				byte rate = op.compute_rate(op.RR);
-				if (rate < 4) {
-					break;
-				}
-				byte shift = eg_rate_shift[rate];
-				if (!(eg_cnt & ((1 << shift) -1))) {
-					byte select = eg_rate_select[rate];
-					op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
-
-					if (((unsigned)op.env_vol > dl_tab[6]) && op.PRVB) {
-						op.state = EG_REV;
-					} else {
-						if (op.env_vol >= MAX_ATT_INDEX) {
-							op.env_vol = MAX_ATT_INDEX;
-							op.active = false;
-							checkMute();
-						}
-					}
-				}
-				break;
-			}
-			case EG_REV: {	//pseudo reverb
-				//TODO improve env_vol update
-				byte rate = op.compute_rate(5);
-				//if (rate < 4) {
-				//	break;
-				//}
-				byte shift = eg_rate_shift[rate];
-				if (!(eg_cnt & ((1 << shift) - 1))) {
-					byte select = eg_rate_select[rate];
-					op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
+			byte shift = eg_rate_shift[rate];
+			if (!(eg_cnt & ((1 << shift) -1))) {
+				byte select = eg_rate_select[rate];
+				op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
 
+				if ((unsigned(op.env_vol) > dl_tab[6]) && op.PRVB) {
+					op.state = EG_REV;
+				} else {
 					if (op.env_vol >= MAX_ATT_INDEX) {
 						op.env_vol = MAX_ATT_INDEX;
 						op.active = false;
-						checkMute();
 					}
 				}
+			}
+			break;
+		}
+		case EG_REL: {	// release phase
+			byte rate = op.compute_rate(op.RR);
+			if (rate < 4) {
 				break;
 			}
-			case EG_DMP: {	//damping
-				//TODO improve env_vol update, damp is just fastest decay now
-				byte rate = 56;
-				byte shift = eg_rate_shift[rate];
-				if (!(eg_cnt & ((1 << shift) - 1))) {
-					byte select = eg_rate_select[rate];
-					op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
+			byte shift = eg_rate_shift[rate];
+			if (!(eg_cnt & ((1 << shift) -1))) {
+				byte select = eg_rate_select[rate];
+				op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
 
+				if ((unsigned(op.env_vol) > dl_tab[6]) && op.PRVB) {
+					op.state = EG_REV;
+				} else {
 					if (op.env_vol >= MAX_ATT_INDEX) {
 						op.env_vol = MAX_ATT_INDEX;
 						op.active = false;
-						checkMute();
 					}
 				}
-				break;
 			}
-			case EG_OFF:
-				// nothing
-				break;
+			break;
+		}
+		case EG_REV: {	//pseudo reverb
+			//TODO improve env_vol update
+			byte rate = op.compute_rate(5);
+			//if (rate < 4) {
+			//	break;
+			//}
+			byte shift = eg_rate_shift[rate];
+			if (!(eg_cnt & ((1 << shift) - 1))) {
+				byte select = eg_rate_select[rate];
+				op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
 
-			default:
-				assert(false);
-				break;
+				if (op.env_vol >= MAX_ATT_INDEX) {
+					op.env_vol = MAX_ATT_INDEX;
+					op.active = false;
+				}
 			}
+			break;
+		}
+		case EG_DMP: {	//damping
+			//TODO improve env_vol update, damp is just fastest decay now
+			byte rate = 56;
+			byte shift = eg_rate_shift[rate];
+			if (!(eg_cnt & ((1 << shift) - 1))) {
+				byte select = eg_rate_select[rate];
+				op.env_vol += eg_inc[select + ((eg_cnt >> shift) & 7)];
+
+				if (op.env_vol >= MAX_ATT_INDEX) {
+					op.env_vol = MAX_ATT_INDEX;
+					op.active = false;
+				}
+			}
+			break;
+		}
+		case EG_OFF:
+			// nothing
+			break;
+
+		default:
+			assert(false);
+			break;
 		}
 	}
 }
 
-short YMF278::getSample(YMF278Slot &op)
+short YMF278Impl::getSample(YMF278Slot &op)
 {
 	short sample;
 	switch (op.bits) {
@@ -437,12 +568,7 @@ short YMF278::getSample(YMF278Slot &op)
 	return sample;
 }
 
-void YMF278::checkMute()
-{
-	setMute(!anyActive());
-}
-
-bool YMF278::anyActive()
+bool YMF278Impl::anyActive()
 {
 	for (int i = 0; i < 24; i++) {
 		if (slots[i].active) {
@@ -452,17 +578,25 @@ bool YMF278::anyActive()
 	return false;
 }
 
-void YMF278::updateBuffer(unsigned length, int* buffer,
-     const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
+void YMF278Impl::generateChannels(int** bufs, unsigned num)
 {
+	if (!anyActive()) {
+		// TODO update internal state, even if muted
+		// TODO also mute individual channels
+		for (int i = 0; i < 24; ++i) {
+			bufs[i] = 0;
+		}
+		return;
+	}
+
 	int vl = mix_level[pcm_l];
 	int vr = mix_level[pcm_r];
-	while (length--) {
-		int left = 0;
-		int right = 0;
+	for (unsigned j = 0; j < num; ++j) {
 		for (int i = 0; i < 24; i++) {
-			YMF278Slot &sl = slots[i];
+			YMF278Slot& sl = slots[i];
 			if (!sl.active) {
+				bufs[i][2 * j + 0] = 0;
+				bufs[i][2 * j + 1] = 0;
 				continue;
 			}
 
@@ -470,19 +604,14 @@ void YMF278::updateBuffer(unsigned length, int* buffer,
 			                sl.sample2 * sl.stepptr) >> 16;
 			int vol = sl.TL + (sl.env_vol >> 2) + sl.compute_am();
 
-			int volLeft  = vol + pan_left [(int)sl.pan] + vl;
-			int volRight = vol + pan_right[(int)sl.pan] + vr;
-
+			int volLeft  = vol + pan_left [int(sl.pan)] + vl;
+			int volRight = vol + pan_right[int(sl.pan)] + vr;
 			// TODO prob doesn't happen in real chip
-			if (volLeft < 0) {
-				volLeft = 0;
-			}
-			if (volRight < 0) {
-				volRight = 0;
-			}
+			volLeft  = std::max(0, volLeft);
+			volRight = std::max(0, volRight);
 
-			left  += (sample * volume[volLeft] ) >> 16;
-			right += (sample * volume[volRight]) >> 16;
+			bufs[i][2 * j + 0] = (sample * volume[volLeft] ) >> 14;
+			bufs[i][2 * j + 1] = (sample * volume[volRight]) >> 14;
 
 			if (sl.lfo_active && sl.vib) {
 				int oct = sl.OCT;
@@ -493,7 +622,7 @@ void YMF278::updateBuffer(unsigned length, int* buffer,
 				unsigned step = (oct >= 0)
 					? ((sl.FN | 1024) + sl.compute_vib()) << oct
 					: ((sl.FN | 1024) + sl.compute_vib()) >> -oct;
-				sl.stepptr += (unsigned)(step * freqbase);
+				sl.stepptr += step;
 			} else {
 				sl.stepptr += sl.step;
 			}
@@ -508,17 +637,24 @@ void YMF278::updateBuffer(unsigned length, int* buffer,
 				sl.sample2 = getSample(sl);
 			}
 		}
-		*buffer++ = left;
-		*buffer++ = right;
-
 		advance();
 	}
 }
 
-void YMF278::keyOnHelper(YMF278Slot& slot)
+bool YMF278Impl::generateInput(int* buffer, unsigned num)
+{
+	return mixChannels(buffer, num);
+}
+
+bool YMF278Impl::updateBuffer(unsigned length, int* buffer,
+     const EmuTime& /*time*/, const EmuDuration& /*sampDur*/)
+{
+	return generateOutput(buffer, length);
+}
+
+void YMF278Impl::keyOnHelper(YMF278Slot& slot)
 {
 	slot.active = true;
-	setMute(false);
 
 	int oct = slot.OCT;
 	if (oct & 8) {
@@ -528,7 +664,7 @@ void YMF278::keyOnHelper(YMF278Slot& slot)
 	unsigned step = (oct >= 0)
 		? (slot.FN | 1024) << oct
 		: (slot.FN | 1024) >> -oct;
-	slot.step = (unsigned)(step * freqbase);
+	slot.step = step;
 	slot.state = EG_ATT;
 	slot.stepptr = 0;
 	slot.pos = 0;
@@ -537,13 +673,13 @@ void YMF278::keyOnHelper(YMF278Slot& slot)
 	slot.sample2 = getSample(slot);
 }
 
-void YMF278::writeRegOPL4(byte reg, byte data, const EmuTime& time)
+void YMF278Impl::writeRegOPL4(byte reg, byte data, const EmuTime& time)
 {
 	busyTime = time + REG_WRITE_DELAY;
 	writeReg(reg, data, time);
 }
 
-void YMF278::writeReg(byte reg, byte data, const EmuTime& time)
+void YMF278Impl::writeReg(byte reg, byte data, const EmuTime& time)
 {
 	updateStream(time); // TODO optimize only for regs that directly influence sound
 	// Handle slot registers specifically
@@ -592,7 +728,7 @@ void YMF278::writeReg(byte reg, byte data, const EmuTime& time)
 			unsigned step = (oct >= 0)
 				? (slot.FN | 1024) << oct
 				: (slot.FN | 1024) >> -oct;
-			slot.step = (unsigned)(step * freqbase);
+			slot.step = step;
 			break;
 		}
 		case 2: {
@@ -607,7 +743,7 @@ void YMF278::writeReg(byte reg, byte data, const EmuTime& time)
 			unsigned step = (oct >= 0)
 				? (slot.FN | 1024) << oct
 				: (slot.FN | 1024) >> -oct;
-			slot.step = (unsigned)(step * freqbase);
+			slot.step = step;
 			break;
 		}
 		case 3:
@@ -622,13 +758,20 @@ void YMF278::writeReg(byte reg, byte data, const EmuTime& time)
 			}
 			break;
 		case 4:
-			slot.pan = data & 0x0F;
+			if (data & 0x10) {
+				// output to DO1 pin:
+				// this pin is not used in moonsound
+				// we emulate this by muting the sound
+				slot.pan = 8; // both left/right -inf dB
+			} else {
+				slot.pan = data & 0x0F;
+			}
 
 			if (data & 0x020) {
 				// LFO reset
 				slot.lfo_active = false;
 				slot.lfo_cnt = 0;
-				slot.lfo_max = lfo_period[(int)slot.vib];
+				slot.lfo_max = lfo_period[int(slot.vib)];
 				slot.lfo_step = 0;
 			} else {
 				// LFO activate
@@ -641,15 +784,13 @@ void YMF278::writeReg(byte reg, byte data, const EmuTime& time)
 					slot.state = EG_REL;
 				}
 				break;
-			case 1:	//tone off, damp
-				slot.state = EG_DMP;
-				break;
 			case 2:	//tone on, no damp
 				if (!(regs[reg] & 0x080)) {
 					keyOnHelper(slot);
 				}
 				break;
-			case 3:	//tone on, damp
+			case 1:	//tone off, damp
+			case 3:	//tone on,  damp
 				slot.state = EG_DMP;
 				break;
 			}
@@ -720,7 +861,7 @@ void YMF278::writeReg(byte reg, byte data, const EmuTime& time)
 	regs[reg] = data;
 }
 
-byte YMF278::readReg(byte reg, const EmuTime& time)
+byte YMF278Impl::readReg(byte reg, const EmuTime& time)
 {
 	// no need to call updateStream(time)
 	byte result;
@@ -742,7 +883,7 @@ byte YMF278::readReg(byte reg, const EmuTime& time)
 	return result;
 }
 
-byte YMF278::peekReg(byte reg) const
+byte YMF278Impl::peekReg(byte reg) const
 {
 	byte result;
 	switch(reg) {
@@ -761,13 +902,13 @@ byte YMF278::peekReg(byte reg) const
 	return result;
 }
 
-byte YMF278::readStatus(const EmuTime& time)
+byte YMF278Impl::readStatus(const EmuTime& time)
 {
 	// no need to call updateStream(time)
 	return peekStatus(time);
 }
 
-byte YMF278::peekStatus(const EmuTime& time) const
+byte YMF278Impl::peekStatus(const EmuTime& time) const
 {
 	byte result = 0;
 	if (time < busyTime) result |= 0x01;
@@ -775,16 +916,18 @@ byte YMF278::peekStatus(const EmuTime& time) const
 	return result;
 }
 
-YMF278::YMF278(MSXMotherBoard& motherBoard, const std::string& name, int ramSize,
-               const XMLElement& config, const EmuTime& time)
-	: SoundDevice(motherBoard.getMSXMixer(), name, "MoonSound wave-part")
-	, rom(new Rom(motherBoard, name + " ROM", "rom", config))
-	, loadTime(time), busyTime(time)
+YMF278Impl::YMF278Impl(MSXMotherBoard& motherBoard, const std::string& name,
+                       int ramSize, const XMLElement& config, const EmuTime& time)
+	: SoundDevice(motherBoard.getMSXMixer(), name, "MoonSound wave-part",
+	              24, true)
+	, Resample(motherBoard.getGlobalSettings(), 2)
 	, debugRegisters(new DebugRegisters(*this, motherBoard))
 	, debugMemory   (new DebugMemory   (*this, motherBoard))
+	, loadTime(time), busyTime(time)
+	, rom(new Rom(motherBoard, name + " ROM", "rom", config))
 {
 	memadr = 0;	// avoid UMR
-	setSampleRate(44100);	// make valgrind happy
+	setOutputRate(44100);	// make valgrind happy
 
 	endRom = rom->getSize();
 	ramSize *= 1024;	// in kb
@@ -792,18 +935,25 @@ YMF278::YMF278(MSXMotherBoard& motherBoard, const std::string& name, int ramSize
 	endRam = endRom + ramSize;
 
 	reset(time);
-	registerSound(config, ChannelMode::STEREO);
+	registerSound(config);
+
+	// Volume table, 1 = -0.375dB, 8 = -3dB, 256 = -96dB
+	for (int i = 0; i < 256; i++) {
+		volume[i] = int(32768.0 * pow(2.0, (-0.375 / 6) * i));
+	}
+	for (int i = 256; i < 256 * 4; i++) {
+		volume[i] = 0;
+	}
 }
 
-YMF278::~YMF278()
+YMF278Impl::~YMF278Impl()
 {
 	unregisterSound();
 	delete[] ram;
 }
 
-void YMF278::reset(const EmuTime& time)
+void YMF278Impl::reset(const EmuTime& time)
 {
-	eg_timer = 0;
 	eg_cnt   = 0;
 
 	for (int i = 0; i < 24; i++) {
@@ -812,32 +962,19 @@ void YMF278::reset(const EmuTime& time)
 	for (int i = 255; i >= 0; i--) { // reverse order to avoid UMR
 		writeRegOPL4(i, 0, time);
 	}
-	setMute(true);
 	wavetblhdr = memmode = memadr = 0;
 	fm_l = fm_r = pcm_l = pcm_r = 0;
 	busyTime = time;
 	loadTime = time;
 }
 
-void YMF278::setSampleRate(int sampleRate)
+void YMF278Impl::setOutputRate(unsigned sampleRate)
 {
-	freqbase = 44100.0 / (double)sampleRate;
-	eg_timer_add = (unsigned)((1 << EG_SH) * freqbase);
+	setInputRate(44100);
+	setResampleRatio(44100, sampleRate);
 }
 
-void YMF278::setVolume(int newVolume)
-{
-	// Volume table, 1 = -0.375dB, 8 = -3dB, 256 = -96dB
-	for (int i = 0; i < 256; i++) {
-		volume[i] = (int)(4.0 * (double)newVolume * pow(2.0, (-0.375 / 6) * i));
-	}
-	for (int i = 256; i < 256 * 4; i++) {
-		volume[i] = 0;
-	}
-
-}
-
-byte YMF278::readMem(unsigned address) const
+byte YMF278Impl::readMem(unsigned address) const
 {
 	if (address < endRom) {
 		return (*rom)[address];
@@ -848,7 +985,7 @@ byte YMF278::readMem(unsigned address) const
 	}
 }
 
-void YMF278::writeMem(unsigned address, byte value)
+void YMF278Impl::writeMem(unsigned address, byte value)
 {
 	if (address < endRom) {
 		// can't write to ROM
@@ -862,7 +999,7 @@ void YMF278::writeMem(unsigned address, byte value)
 
 // class DebugRegisters
 
-DebugRegisters::DebugRegisters(YMF278& ymf278_,
+DebugRegisters::DebugRegisters(YMF278Impl& ymf278_,
                                        MSXMotherBoard& motherBoard)
 	: SimpleDebuggable(motherBoard, ymf278_.getName() + " regs",
 	                   "OPL4 registers", 0x100)
@@ -883,7 +1020,7 @@ void DebugRegisters::write(unsigned address, byte value, const EmuTime& time)
 
 // class DebugMemory
 
-DebugMemory::DebugMemory(YMF278& ymf278_, MSXMotherBoard& motherBoard)
+DebugMemory::DebugMemory(YMF278Impl& ymf278_, MSXMotherBoard& motherBoard)
 	: SimpleDebuggable(motherBoard, ymf278_.getName() + " mem",
 	                   "OPL4 memory (includes both ROM and RAM)", 0x400000) // 4MB
 	, ymf278(ymf278_)
@@ -901,4 +1038,46 @@ void DebugMemory::write(unsigned address, byte value)
 }
 
 
+// class YMF278
+
+YMF278::YMF278(MSXMotherBoard& motherBoard, const std::string& name,
+       int ramSize, const XMLElement& config, const EmuTime& time)
+	: pimple(new YMF278Impl(motherBoard, name, ramSize, config, time))
+{
+}
+
+YMF278::~YMF278()
+{
+}
+
+void YMF278::reset(const EmuTime& time)
+{
+	pimple->reset(time);
+}
+
+void YMF278::writeRegOPL4(byte reg, byte data, const EmuTime& time)
+{
+	pimple->writeRegOPL4(reg, data, time);
+}
+
+byte YMF278::readReg(byte reg, const EmuTime& time)
+{
+	return pimple->readReg(reg, time);
+}
+
+byte YMF278::peekReg(byte reg) const
+{
+	return pimple->peekReg(reg);
+}
+
+byte YMF278::readStatus(const EmuTime& time)
+{
+	return pimple->readStatus(time);
+}
+
+byte YMF278::peekStatus(const EmuTime& time) const
+{
+	return pimple->peekStatus(time);
+}
+
 } // namespace openmsx
