@@ -1,7 +1,7 @@
-// $Id: CondVar.cc,v 1.6 2004/12/15 09:09:51 m9710797 Exp $
+// $Id: $
 
-#include <SDL.h>
 #include "CondVar.hh"
+#include <SDL.h>
 
 namespace openmsx {
 
@@ -13,8 +13,8 @@ CondVar::CondVar()
 
 CondVar::~CondVar()
 {
-	SDL_DestroyMutex(mutex);
 	SDL_DestroyCond(cond);
+	SDL_DestroyMutex(mutex);
 }
 
 void CondVar::wait()
@@ -23,10 +23,11 @@ void CondVar::wait()
 	SDL_CondWait(cond, mutex);
 }
 
-int CondVar::waitTimeout(Uint32 to)
+bool CondVar::waitTimeout(unsigned us)
 {
 	SDL_mutexP(mutex);
-	return	SDL_CondWaitTimeout(cond, mutex, to);
+	int result = SDL_CondWaitTimeout(cond, mutex, us / 1000);
+	return result == SDL_MUTEX_TIMEDOUT;
 }
 
 void CondVar::signal()
