@@ -1,4 +1,4 @@
-// $Id: Thread.cc 5514 2006-07-13 19:49:41Z m9710797 $
+// $Id: Thread.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "Thread.hh"
 #include "MSXException.hh"
@@ -8,17 +8,17 @@
 
 namespace openmsx {
 
-static unsigned mainThreadId = (unsigned)-1;
+static unsigned mainThreadId = unsigned(-1);
 
 void Thread::setMainThread()
 {
-	assert(mainThreadId == (unsigned)-1);
+	assert(mainThreadId == unsigned(-1));
 	mainThreadId = SDL_ThreadID();
 }
 
 bool Thread::isMainThread()
 {
-	assert(mainThreadId != (unsigned)-1);
+	assert(mainThreadId != unsigned(-1));
 	return mainThreadId == SDL_ThreadID();
 }
 
