@@ -1,4 +1,4 @@
-// $Id: Timer.cc 4852 2005-11-12 17:48:41Z m9710797 $
+// $Id: Timer.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "Timer.hh"
 #include "probed_defs.hh"
@@ -20,11 +20,16 @@ namespace Timer {
 
 static inline unsigned long long getSDLTicks()
 {
-	return (unsigned long long)SDL_GetTicks() * 1000;
+	return static_cast<unsigned long long>(SDL_GetTicks()) * 1000;
 }
 
 unsigned long long getTime()
 {
+/* QueryPerformanceCounter() has problems on modern CPUs,
+ *  - on dual core CPUs time can ge backwards (a bit) when your process
+ *    get scheduled on the other core
+ *  - the resolution of the timer can vary on CPUs that can change its
+ *    clock frequency (for power managment)
 #if defined (WIN32)
 	static LONGLONG hfFrequency = 0;
 
@@ -41,18 +46,18 @@ unsigned long long getTime()
 	// Assumes that the timer never wraps. The mask is just to
 	// ensure that the multiplication doesn't wrap.
 	return (li.QuadPart & ((long long)-1 >> 20)) * 1000000 / hfFrequency;
-
-#elif defined (HAVE_GETTIMEOFDAY)
+*/
+#if defined (HAVE_GETTIMEOFDAY)
 	struct timeval tv;
 	gettimeofday(&tv, NULL);
-	return (unsigned long long)tv.tv_sec * 1000000 +
-	       (unsigned long long)tv.tv_usec;
+	return static_cast<unsigned long long>(tv.tv_sec) * 1000000 +
+	       static_cast<unsigned long long>(tv.tv_usec);
 #else
 	return getSDLTicks();
 #endif
 }
 
-#ifdef WIN32
+/*#ifdef WIN32
 static void CALLBACK timerCallback(unsigned int,
                                    unsigned int,
                                    unsigned long eventHandle,
@@ -61,11 +66,11 @@ static void CALLBACK timerCallback(unsigned int,
 {
     SetEvent((HANDLE)eventHandle);
 }
-#endif
+#endif*/
 
 void sleep(unsigned long long us)
 {
-#if defined (WIN32)
+/*#if defined (WIN32)
 	us /= 1000;
 	if (us > 0) {
 		static HANDLE timerEvent = NULL;
@@ -77,7 +82,8 @@ void sleep(unsigned long long us)
 		WaitForSingleObject(timerEvent, INFINITE);
 		timeKillEvent(id);
 	}
-#elif defined (HAVE_USLEEP)
+*/
+#if defined (HAVE_USLEEP)
 	usleep(us);
 #else
 	SDL_Delay(us / 1000);
