@@ -1,4 +1,4 @@
-// $Id: $
+// $Id: AviWriter.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 // Code based on DOSBox-0.65
 
@@ -6,9 +6,10 @@
 #include "ZMBVEncoder.hh"
 #include "CommandException.hh"
 #include "build-info.hh"
-#include <algorithm>
+#include "Version.hh"
 #include <cstring>
 #include <cstdlib>
+#include <ctime>
 #include <cassert>
 
 namespace openmsx {
@@ -30,10 +31,10 @@ static inline void writeLE4(unsigned char* p, unsigned x)
 
 AviWriter::AviWriter(const std::string& filename, unsigned width_,
                      unsigned height_, unsigned bpp, unsigned freq_)
-	: width(width_)
+	: fps(50.0)
+	, width(width_)
 	, height(height_)
 	, audiorate(freq_)
-	, fps(50.0)
 {
 	file = fopen(filename.c_str(), "wb");
 	if (!file) {
@@ -55,16 +56,18 @@ AviWriter::AviWriter(const std::string& filename, unsigned width_,
 AviWriter::~AviWriter()
 {
 	unsigned char avi_header[AVI_HEADER_SIZE];
+	memset(&avi_header, 0, AVI_HEADER_SIZE);
 	unsigned header_pos = 0;
 
 #define AVIOUT4(_S_) memcpy(&avi_header[header_pos],_S_,4);header_pos+=4;
 #define AVIOUTw(_S_) writeLE2(&avi_header[header_pos], _S_);header_pos+=2;
 #define AVIOUTd(_S_) writeLE4(&avi_header[header_pos], _S_);header_pos+=4;
+#define AVIOUTs(_S_) memcpy(&avi_header[header_pos],_S_,strlen(_S_)+1);header_pos+=(strlen(_S_)+1 + 1) & ~1;
 
 	bool hasAudio = audiorate != 0;
 
 	// write avi header
-	AVIOUT4("RIFF");                    // Riff header 
+	AVIOUT4("RIFF");                    // Riff header
 	AVIOUTd(AVI_HEADER_SIZE + written - 8 + index.size());
 	AVIOUT4("AVI ");
 	AVIOUT4("LIST");                    // List header
@@ -74,7 +77,7 @@ AviWriter::~AviWriter()
 
 	AVIOUT4("avih");
 	AVIOUTd(56);                        // # of bytes to follow
-	AVIOUTd((unsigned)(1000000 / fps)); // Microseconds per frame
+	AVIOUTd(unsigned(1000000 / fps));   // Microseconds per frame
 	AVIOUTd(0);
 	AVIOUTd(0);                         // PaddingGranularity (whatever that might be)
 	AVIOUTd(0x110);                     // Flags,0x10 has index, 0x100 interleaved
@@ -102,7 +105,7 @@ AviWriter::~AviWriter()
 	AVIOUTd(0);                         // Reserved, MS says: wPriority, wLanguage
 	AVIOUTd(0);                         // InitialFrames
 	AVIOUTd(1000000);                   // Scale
-	AVIOUTd((unsigned)(1000000 * fps)); // Rate: Rate/Scale == samples/second
+	AVIOUTd(unsigned(1000000 * fps));   // Rate: Rate/Scale == samples/second
 	AVIOUTd(0);                         // Start
 	AVIOUTd(frames);                    // Length
 	AVIOUTd(0);                         // SuggestedBufferSize
@@ -157,15 +160,39 @@ AviWriter::~AviWriter()
 		AVIOUTw(16);                // BitsPerSample
 	}
 
+	const char* versionStr = Version::FULL_VERSION.c_str();
+	char dateStr[11];
+	time_t t = time(NULL);
+	struct tm *tm = localtime(&t);
+	snprintf(dateStr, 11, "%04d-%02d-%02d", 1900 + tm->tm_year,
+		 tm->tm_mon + 1, tm->tm_mday);
+	AVIOUT4("LIST");
+	AVIOUTd(4 // list type
+		+ (4 + 4 + ((strlen(versionStr) + 1 + 1) & ~1)) // 1st chunk
+		+ (4 + 4 + ((strlen(dateStr   ) + 1 + 1) & ~1)) // 2nd chunk
+		); // size of the list
+	AVIOUT4("INFO");
+        AVIOUT4("ISFT");
+	AVIOUTd(strlen(versionStr) + 1); // # of bytes to follow
+	AVIOUTs(versionStr);
+        AVIOUT4("ICRD");
+	AVIOUTd(strlen(dateStr) + 1); // # of bytes to follow
+	AVIOUTs(dateStr);
+	// TODO: add artist (IART), comments (ICMT), name (INAM), etc.
+	// use a loop over chunks (type + string) to create the above bytes in
+	// a much nicer way
+
 	// Finish stream list, i.e. put number of bytes in the list to proper pos
 	int nmain = header_pos - main_list - 4;
 	int njunk = AVI_HEADER_SIZE - 8 - 12 - header_pos;
+	assert(njunk > 0); // increase AVI_HEADER_SIZE if this occurs
 	AVIOUT4("JUNK");
 	AVIOUTd(njunk);
 	// Fix the size of the main list
 	header_pos = main_list;
 	AVIOUTd(nmain);
 	header_pos = AVI_HEADER_SIZE - 12;
+	
 	AVIOUT4("LIST");
 	AVIOUTd(written + 4);               // Length of list in bytes
 	AVIOUT4("movi");
@@ -192,7 +219,7 @@ void AviWriter::addAviChunk(const char* tag, unsigned size, void* data, unsigned
 	chunk[1] = tag[1];
 	chunk[2] = tag[2];
 	chunk[3] = tag[3];
-	writeLE4(&chunk[4], size);   
+	writeLE4(&chunk[4], size);
 	fwrite(chunk, 1, 8, file);
 
 	unsigned writesize = (size + 1) & ~1;
