@@ -1,7 +1,8 @@
-// $Id: BitmapConverter.cc 5959 2006-12-23 16:11:43Z m9710797 $
+// $Id: BitmapConverter.cc 7330 2007-11-27 22:24:13Z mthuurne $
 
 #include "BitmapConverter.hh"
 #include "GLUtil.hh"
+#include "Math.hh"
 
 namespace openmsx {
 
@@ -79,14 +80,10 @@ void BitmapConverter<Pixel>::renderYJK(
 
 		for (unsigned n = 0; n < 4; ++n) {
 			int y = p[n] >> 3;
-			int r = y + j;
-			int g = y + k;
-			int b = (5 * y - 2 * j - k) / 4;
-			if (r < 0) r = 0; else if (r > 31) r = 31;
-			if (g < 0) g = 0; else if (g > 31) g = 31;
-			if (b < 0) b = 0; else if (b > 31) b = 31;
+			int r = Math::clip<0, 31>(y + j);
+			int g = Math::clip<0, 31>(y + k);
+			int b = Math::clip<0, 31>((5 * y - 2 * j - k) / 4);
 			int col = (r << 10) + (g << 5) + b;
-
 			pixelPtr[4 * i + n] = palette32768[col];
 		}
 	}
@@ -114,12 +111,9 @@ void BitmapConverter<Pixel>::renderYAE(
 			} else {
 				// YJK
 				int y = p[n] >> 3;
-				int r = y + j;
-				int g = y + k;
-				int b = (5 * y - 2 * j - k) / 4;
-				if (r < 0) r = 0; else if (r > 31) r = 31;
-				if (g < 0) g = 0; else if (g > 31) g = 31;
-				if (b < 0) b = 0; else if (b > 31) b = 31;
+				int r = Math::clip<0, 31>(y + j);
+				int g = Math::clip<0, 31>(y + k);
+				int b = Math::clip<0, 31>((5 * y - 2 * j - k) / 4);
 				pix = palette32768[(r << 10) + (g << 5) + b];
 			}
 			pixelPtr[4 * i + n] = pix;
@@ -138,6 +132,37 @@ void BitmapConverter<Pixel>::renderBogus(
 	}
 }
 
+template <class Pixel>
+void BitmapConverter<Pixel>::setDisplayMode(DisplayMode mode)
+{
+	// TODO: Support YJK on modes other than Graphic 6/7.
+	switch (mode.getByte() & ~DisplayMode::YAE) {
+	case DisplayMode::GRAPHIC4:
+		renderMethod = &BitmapConverter::renderGraphic4;
+		break;
+	case DisplayMode::GRAPHIC5:
+		renderMethod = &BitmapConverter::renderGraphic5;
+		break;
+	case DisplayMode::GRAPHIC6:
+		renderMethod = &BitmapConverter::renderGraphic6;
+		break;
+	case DisplayMode::GRAPHIC7:
+		renderMethod = &BitmapConverter::renderGraphic7;
+		break;
+	case DisplayMode::GRAPHIC6 | DisplayMode::YJK:
+	case DisplayMode::GRAPHIC7 | DisplayMode::YJK:
+		if (mode.getByte() & DisplayMode::YAE) {
+			renderMethod = &BitmapConverter::renderYAE;
+		} else {
+			renderMethod = &BitmapConverter::renderYJK;
+		}
+		break;
+	default:
+		renderMethod = &BitmapConverter::renderBogus;
+		break;
+	}
+}
+
 // Force template instantiation.
 template class BitmapConverter<word>;
 template class BitmapConverter<unsigned>;
