@@ -1,4 +1,4 @@
-// $Id: Display.cc 6086 2007-02-14 19:22:06Z m9710797 $
+// $Id: Display.cc 6834 2007-08-12 21:33:41Z mthuurne $
 
 #include "Display.hh"
 #include "Layer.hh"
@@ -21,6 +21,7 @@
 #include "MachineConfig.hh"
 #include "VideoSystemChangeListener.hh"
 #include "Version.hh"
+#include "build-info.hh"
 #include "checked_cast.hh"
 #include <algorithm>
 #include <cassert>
@@ -63,14 +64,14 @@ private:
 
 
 Display::Display(Reactor& reactor_)
-	: currentRenderer(RendererFactory::UNINITIALIZED)
-	, alarm(new RepaintAlarm(reactor_.getEventDistributor()))
+	: alarm(new RepaintAlarm(reactor_.getEventDistributor()))
 	, screenShotCmd(new ScreenShotCmd(
 		reactor_.getCommandController(), *this))
 	, fpsInfo(new FpsInfoTopic(
 	      reactor_.getGlobalCommandController().getOpenMSXInfoCommand(), *this))
 	, reactor(reactor_)
 	, renderSettings(new RenderSettings(reactor.getCommandController()))
+	, currentRenderer(RendererFactory::UNINITIALIZED)
 	, switchInProgress(false)
 {
 	frameDurationSum = 0;
@@ -218,6 +219,9 @@ bool Display::signalEvent(shared_ptr<const Event> event)
 void Display::setWindowTitle()
 {
 	string title = Version::FULL_VERSION;
+	if (!Version::RELEASE) {
+		title += " [" + BUILD_FLAVOUR + "]";
+	}
 	if (MSXMotherBoard* motherboard = reactor.getMotherBoard()) {
 		const XMLElement& config = motherboard->getMachineConfig().getConfig();
 		title += " - " +
