@@ -1,4 +1,4 @@
-// $Id: FBPostProcessor.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: FBPostProcessor.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "FBPostProcessor.hh"
 #include "RenderSettings.hh"
@@ -6,6 +6,7 @@
 #include "ScalerFactory.hh"
 #include "IntegerSetting.hh"
 #include "FloatSetting.hh"
+#include "EnumSetting.hh"
 #include "VisibleSurface.hh"
 #include "HostCPU.hh"
 #include "Math.hh"
@@ -16,7 +17,7 @@ namespace openmsx {
 
 static const unsigned NOISE_SHIFT = 8192;
 static const unsigned NOISE_BUF_SIZE = 2 * NOISE_SHIFT;
-static signed char noiseBuf[NOISE_BUF_SIZE];
+static signed char noiseBuf[NOISE_BUF_SIZE] __attribute__((__aligned__(16)));
 
 template <class Pixel>
 void FBPostProcessor<Pixel>::preCalcNoise(double factor)
@@ -47,7 +48,50 @@ void FBPostProcessor<Pixel>::drawNoiseLine(
 {
 	#ifdef ASM_X86
 	const HostCPU& cpu = HostCPU::getInstance();
-	if ((sizeof(Pixel) == 4) && cpu.hasMMXEXT()) {
+	if ((sizeof(Pixel) == 4) && cpu.hasSSE2()) {
+		// SSE2 32bpp
+		assert(((4 * width) % 64) == 0);
+		asm (
+			"pcmpeqb  %%xmm7, %%xmm7;"
+			"psllw    $15, %%xmm7;"
+			"packsswb %%xmm7, %%xmm7;"
+			".p2align 4,,15;"
+		"0:"
+			"movdqa     (%0, %3), %%xmm0;"
+			"movdqa   16(%0, %3), %%xmm1;"
+			"movdqa   32(%0, %3), %%xmm2;"
+			"pxor     %%xmm7, %%xmm0;"
+			"movdqa   48(%0, %3), %%xmm3;"
+			"pxor     %%xmm7, %%xmm1;"
+			"pxor     %%xmm7, %%xmm2;"
+			"paddsb     (%2, %3), %%xmm0;"
+			"pxor     %%xmm7, %%xmm3;"
+			"paddsb   16(%2, %3), %%xmm1;"
+			"paddsb   32(%2, %3), %%xmm2;"
+			"pxor     %%xmm7, %%xmm0;"
+			"paddsb   48(%2, %3), %%xmm3;"
+			"pxor     %%xmm7, %%xmm1;"
+			"pxor     %%xmm7, %%xmm2;"
+			"movdqa   %%xmm0,   (%1, %3);"
+			"pxor     %%xmm7, %%xmm3;"
+			"movdqa   %%xmm1, 16(%1, %3);"
+			"movdqa   %%xmm2, 32(%1, %3);"
+			"movdqa   %%xmm3, 48(%1, %3);"
+			"add      $64, %3;"
+			"jnz      0b;"
+
+			: // no output
+			: "r" (in    + width)     // 0
+			, "r" (out   + width)     // 1
+			, "r" (noise + 4 * width) // 2
+			, "r" (-4 * width)        // 3
+			#ifdef __SSE__
+			: "xmm0", "xmm1", "xmm2", "xmm3", "xmm7"
+			#endif
+		);
+		return;
+	}
+	if ((sizeof(Pixel) == 4) && cpu.hasSSE()) {
 		// extended-MMX 32bpp
 		assert(((4 * width) % 32) == 0);
 		asm (
@@ -148,12 +192,12 @@ void FBPostProcessor<Pixel>::drawNoiseLine(
 			// only 3 is significantly faster (~20%).
 			// Typical pixel layout for little endian is ABGR and for big
 			// endian is ARGB, so we can use the same computation.
-			unsigned c1 = std::min<unsigned>(std::max<int>(
-				(p & 0x000000FF) + (n <<  0), 0), 0x000000FF);
-			unsigned c2 = std::min<unsigned>(std::max<int>(
-				(p & 0x0000FF00) + (n <<  8), 0), 0x0000FF00);
-			unsigned c3 = std::min<unsigned>(std::max<int>(
-				(p & 0x00FF0000) + (n << 16), 0), 0x00FF0000);
+			unsigned c1 = Math::clip<0, 0x0000FF>(
+				(p & 0x0000FF) + (n <<  0));
+			unsigned c2 = Math::clip<0, 0x00FF00>(
+				(p & 0x00FF00) + (n <<  8));
+			unsigned c3 = Math::clip<0, 0xFF0000>(
+				(p & 0xFF0000) + (n << 16));
 			out[i] = c1 | c2 | c3;
 		}
 	} else {
@@ -187,7 +231,8 @@ void FBPostProcessor<Pixel>::drawNoise()
 	unsigned height = screen.getHeight();
 	unsigned width = screen.getWidth();
 	for (unsigned y = 0; y < height; ++y) {
-		Pixel* buf = screen.getLinePtr(y, (Pixel*)0);
+		Pixel* dummy = 0;
+		Pixel* buf = screen.getLinePtr(y, dummy);
 		drawNoiseLine(buf, buf, &noiseBuf[noiseShift[y]], width);
 	}
 }
@@ -212,8 +257,8 @@ FBPostProcessor<Pixel>::FBPostProcessor(CommandController& commandController,
 	, noiseShift(screen.getHeight())
 	, pixelOps(screen.getFormat())
 {
-	scaleAlgorithm = (RenderSettings::ScaleAlgorithm)-1; // not a valid scaler
-	scaleFactor = (unsigned)-1;
+	scaleAlgorithm = static_cast<RenderSettings::ScaleAlgorithm>(-1); // not a valid scaler
+	scaleFactor = unsigned(-1);
 
 	FloatSetting& noiseSetting = renderSettings.getNoise();
 	noiseSetting.attach(*this);
@@ -297,7 +342,7 @@ RawFrame* FBPostProcessor<Pixel>::rotateFrames(
 	const EmuTime& time)
 {
 	for (unsigned y = 0; y < screen.getHeight(); ++y) {
-		noiseShift[y] = rand() & (NOISE_SHIFT - 1) & ~7;
+		noiseShift[y] = rand() & (NOISE_SHIFT - 1) & ~15;
 	}
 
 	return PostProcessor::rotateFrames(finishedFrame, field, time);
