@@ -1,10 +1,9 @@
-// $Id: GLImage.cc 5271 2006-03-20 20:26:10Z mthuurne $
+// $Id: GLImage.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "GLImage.hh"
 #include "MSXException.hh"
 #include "Math.hh"
 #include "SDLImage.hh"
-#include <SDL_image.h>
 #include <SDL.h>
 
 using std::string;
@@ -20,8 +19,8 @@ GLImage::GLImage(SDL_Surface* /*output*/, const string& filename,
                  double scalefactor)
 {
 	texture = loadTexture(filename, width, height, texCoord);
-	width  = static_cast<unsigned>(scalefactor * width);
-	height = static_cast<unsigned>(scalefactor * height);
+	width  = unsigned(scalefactor * width);
+	height = unsigned(scalefactor * height);
 }
 
 GLImage::~GLImage()
@@ -62,8 +61,8 @@ GLuint GLImage::loadTexture(const string& filename,
 	int h2 = Math::powerOfTwo(height);
 	texCoord[0] = 0.0f;			// Min X
 	texCoord[1] = 0.0f;			// Min Y
-	texCoord[2] = (GLfloat)width  / w2;	// Max X
-	texCoord[3] = (GLfloat)height / h2;	// Max Y
+	texCoord[2] = GLfloat(width)  / w2;	// Max X
+	texCoord[3] = GLfloat(height) / h2;	// Max Y
 
 	SDL_Surface* image2 = SDL_CreateRGBSurface(SDL_SWSURFACE, w2, h2, 32,
 #if SDL_BYTEORDER == SDL_LIL_ENDIAN
