@@ -1,10 +1,11 @@
-// $Id: GLPostProcessor.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: GLPostProcessor.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "GLPostProcessor.hh"
 #include "GLScaler.hh"
 #include "GLScalerFactory.hh"
 #include "IntegerSetting.hh"
 #include "FloatSetting.hh"
+#include "EnumSetting.hh"
 #include "VisibleSurface.hh"
 #include "Math.hh"
 #include "MemoryOps.hh"
@@ -37,7 +38,7 @@ GLPostProcessor::GLPostProcessor(
 			"objects.");
 	}
 
-	scaleAlgorithm = (RenderSettings::ScaleAlgorithm)-1; // not a valid scaler
+	scaleAlgorithm = static_cast<RenderSettings::ScaleAlgorithm>(-1); // not a valid scaler
 
 	noiseTextureA.setImage(256, 256);
 	noiseTextureB.setImage(256, 256);
@@ -255,10 +256,10 @@ void GLPostProcessor::paint()
 			           ? (320.0f - 284.0f) / (2.0f * 320.0f)
 				   : 0.0f;
 			GLfloat x2 = 1.0f - x1;
-			glTexCoord2f(x1, 0.0f); glVertex2i(0, h); 
-			glTexCoord2f(x1, 1.0f); glVertex2i(0, 0); 
-			glTexCoord2f(x2, 1.0f); glVertex2i(w, 0); 
-			glTexCoord2f(x2, 0.0f); glVertex2i(w, h); 
+			glTexCoord2f(x1, 0.0f); glVertex2i(0, h);
+			glTexCoord2f(x1, 1.0f); glVertex2i(0, 0);
+			glTexCoord2f(x2, 1.0f); glVertex2i(w, 0);
+			glTexCoord2f(x2, 0.0f); glVertex2i(w, h);
 			glEnd();
 		}
 		glDisable(GL_TEXTURE_2D);
@@ -276,8 +277,8 @@ RawFrame* GLPostProcessor::rotateFrames(
 		PostProcessor::rotateFrames(finishedFrame, field, time);
 	uploadFrame();
 	++frameCounter;
-	noiseX = (double)rand() / RAND_MAX;
-	noiseY = (double)rand() / RAND_MAX;
+	noiseX = double(rand()) / RAND_MAX;
+	noiseY = double(rand()) / RAND_MAX;
 	return reuseFrame;
 }
 
@@ -344,8 +345,9 @@ void GLPostProcessor::uploadBlock(
 		pbo->bind();
 		unsigned* mapped = pbo->mapWrite();
 		for (unsigned y = srcStartY; y < srcEndY; ++y) {
+			unsigned* dummy = 0;
 			const unsigned* data =
-				paintFrame->getLinePtr(y, lineWidth, (unsigned*)0);
+				paintFrame->getLinePtr(y, lineWidth, dummy);
 			MemoryOps::stream_memcpy(mapped + y * lineWidth, data, lineWidth);
 			paintFrame->freeLineBuffers(); // ASAP to keep cache warm
 		}
@@ -367,8 +369,9 @@ void GLPostProcessor::uploadBlock(
 		unsigned remainingLines = srcEndY - srcStartY;
 		while (remainingLines) {
 			unsigned lines;
+			unsigned* dummy = 0;
 			const unsigned* data = paintFrame->getMultiLinePtr(
-				y, remainingLines, lines, lineWidth, (unsigned*)0);
+				y, remainingLines, lines, lineWidth, dummy);
 			glTexSubImage2D(
 				GL_TEXTURE_2D,     // target
 				0,                 // level
@@ -406,10 +409,10 @@ void GLPostProcessor::drawGlow(int glow)
 	glColor4f(0.0f, 0.0f, 0.0f, alpha);
 	int w = screen.getWidth();
 	int h = screen.getHeight();
-	glTexCoord2i(0, 0); glVertex2i(0, h); 
-	glTexCoord2i(0, 1); glVertex2i(0, 0); 
-	glTexCoord2i(1, 1); glVertex2i(w, 0); 
-	glTexCoord2i(1, 0); glVertex2i(w, h); 
+	glTexCoord2i(0, 0); glVertex2i(0, h);
+	glTexCoord2i(0, 1); glVertex2i(0, 0);
+	glTexCoord2i(1, 1); glVertex2i(w, 0);
+	glTexCoord2i(1, 0); glVertex2i(w, h);
 	glEnd();
 	glDisable(GL_BLEND);
 	glDisable(GL_TEXTURE_2D);
