@@ -1,7 +1,9 @@
-// $Id: GLScalerFactory.cc 5577 2006-08-12 16:48:02Z m9710797 $
+// $Id: GLScalerFactory.cc 6748 2007-07-27 17:59:12Z m9710797 $
 
 #include "GLScalerFactory.hh"
 #include "GLSimpleScaler.hh"
+#include "GLRGBScaler.hh"
+#include "GLSaIScaler.hh"
 #include "GLScaleNxScaler.hh"
 #include "GLTVScaler.hh"
 #include "GLHQScaler.hh"
@@ -14,18 +16,20 @@ using std::auto_ptr;
 
 namespace openmsx {
 
-auto_ptr<GLScaler> GLScalerFactory::createScaler(
-	RenderSettings& renderSettings
-	)
+auto_ptr<GLScaler> GLScalerFactory::createScaler(RenderSettings& renderSettings)
 {
 	switch (renderSettings.getScaleAlgorithm().getValue()) {
-	case RenderSettings::SCALER_SIMPLE:
-	// TODO: Until we have GL versions of these, map them to "simple".
 	case RenderSettings::SCALER_SAI:
+		// disabled for now:
+		//   - it doesn't work (yet) on ATI cards
+		//   - it probably has some bugs because (on nvidia cards)
+		//     it does not give the same result as the SW SaI scaler,
+		//     although it's reasonably close
+		//return auto_ptr<GLScaler>(new GLSaIScaler());
+	case RenderSettings::SCALER_SIMPLE:
+		return auto_ptr<GLScaler>(new GLSimpleScaler(renderSettings));
 	case RenderSettings::SCALER_RGBTRIPLET:
-		return auto_ptr<GLScaler>(
-			new GLSimpleScaler(renderSettings)
-			);
+		return auto_ptr<GLScaler>(new GLRGBScaler(renderSettings));
 	case RenderSettings::SCALER_SCALE:
 		return auto_ptr<GLScaler>(new GLScaleNxScaler());
 	case RenderSettings::SCALER_TV:
