@@ -1,4 +1,4 @@
-// $Id: GLSimpleScaler.cc 6100 2007-02-19 18:56:40Z m9710797 $
+// $Id: GLSimpleScaler.cc 6353 2007-04-23 18:28:00Z m9710797 $
 
 #include "GLSimpleScaler.hh"
 #include "GLUtil.hh"
@@ -20,11 +20,9 @@ GLSimpleScaler::GLSimpleScaler(RenderSettings& renderSettings_)
 		scalerProgram->activate();
 		GLint texLoc = scalerProgram->getUniformLocation("tex");
 		glUniform1i(texLoc, 0);
-		texSizeLoc = scalerProgram->getUniformLocation("texSize");
-		alphaLoc   = scalerProgram->getUniformLocation("alpha");
-		scanALoc   = scalerProgram->getUniformLocation("scan_a");
-		scanBLoc   = scalerProgram->getUniformLocation("scan_b");
-		scanCLoc   = scalerProgram->getUniformLocation("scan_c");
+		texSizeLoc  = scalerProgram->getUniformLocation("texSize");
+		texStepXLoc = scalerProgram->getUniformLocation("texStepX");
+		cnstLoc     = scalerProgram->getUniformLocation("cnst");
 	}
 #endif
 }
@@ -51,10 +49,11 @@ void GLSimpleScaler::scaleImage(
 		scalerProgram->activate();
 		GLfloat a = (yScale & 1) ? 0.5f : ((yScale + 1) / (2.0f * yScale));
 		glUniform2f(texSizeLoc, srcWidth, height);
-		glUniform1f(alphaLoc, blur);
-		glUniform1f(scanALoc, a);
-		glUniform1f(scanBLoc, 1.0f - scanline);
-		glUniform1f(scanCLoc, scanline * 0.5f);
+		glUniform3f(texStepXLoc, 1.0f / srcWidth, 1.0f / srcWidth, 0.0f);
+		glUniform4f(cnstLoc, a,                // scan_a
+		                     1.0f - scanline,  // scan_b
+		                     scanline * 0.5f,  // scan_c
+		                     blur);            // alpha
 	}
 	src.drawRect(0.0f,  srcStartY            / height,
 	             1.0f, (srcEndY - srcStartY) / height,
