@@ -1,4 +1,4 @@
-// $Id: GLSnow.cc 5496 2006-06-29 20:21:13Z m9710797 $
+// $Id: GLSnow.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "GLSnow.hh"
 #include "openmsx.hh"
@@ -15,7 +15,7 @@ GLSnow::GLSnow(unsigned width_, unsigned height_)
 	// Create noise texture.
 	byte buf[128 * 128];
 	for (int i = 0; i < 128 * 128; ++i) {
-		buf[i] = (byte)rand();
+		buf[i] = byte(rand());
 	}
 	glGenTextures(1, &noiseTextureId);
 	glBindTexture(GL_TEXTURE_2D, noiseTextureId);
@@ -48,8 +48,8 @@ void GLSnow::paint()
 	static unsigned cnt = 0;
 
 	// Draw noise texture.
-	double x = (double)rand() / RAND_MAX;
-	double y = (double)rand() / RAND_MAX;
+	double x = double(rand()) / RAND_MAX;
+	double y = double(rand()) / RAND_MAX;
 	cnt = (cnt + 1) % 8;
 	glEnable(GL_TEXTURE_2D);
 	glBindTexture(GL_TEXTURE_2D, noiseTextureId);
