@@ -1,4 +1,4 @@
-// $Id: GLUtil.cc 6011 2007-01-24 19:25:01Z m9710797 $
+// $Id: GLUtil.cc 6826 2007-08-09 16:50:00Z m9710797 $
 
 #include "GLUtil.hh"
 #include "File.hh"
@@ -224,8 +224,8 @@ void BitmapTexture::draw(
 	int srcL, int srcT, int srcR, int srcB,
 	int dstL, int dstT, int dstR, int dstB)
 {
-	static const GLfloat fx = 1.0f / static_cast<GLfloat>(WIDTH);
-	static const GLfloat fy = 1.0f / static_cast<GLfloat>(HEIGHT);
+	static const GLfloat fx = 1.0f / GLfloat(WIDTH);
+	static const GLfloat fy = 1.0f / GLfloat(HEIGHT);
 	const GLfloat srcLF = srcL * fx;
 	const GLfloat srcRF = srcR * fx;
 	const GLfloat srcTF = srcT * fy;
@@ -349,8 +349,8 @@ void StoredFrame::draw(int offsetX, int offsetY, int width, int height)
 	texture.bind();
 	glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
 	// TODO: Create display list(s)?
-	float x = static_cast<float>(width)  / textureWidth;
-	float y = static_cast<float>(height) / textureHeight;
+	float x = float(width)  / textureWidth;
+	float y = float(height) / textureHeight;
 	glBegin(GL_QUADS);
 	glTexCoord2f(0.0f,    y); glVertex2i(offsetX,         offsetY         );
 	glTexCoord2f(   x,    y); glVertex2i(offsetX + width, offsetY         );
@@ -426,6 +426,7 @@ void FrameBufferObject::pop()
 	glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, currentId);
 }
 
+bool PixelBuffers::enabled = true;
 
 // Utility function used by Shader.
 // Although this is not GL 2.0 dependent in itself, it is only used by GL 2.0
