@@ -1,10 +1,11 @@
-// $Id: IconLayer.cc 4881 2005-11-19 15:32:59Z m9710797 $
+// $Id: IconLayer.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "IconLayer.hh"
 #include "FileContext.hh"
 #include "Timer.hh"
 #include "SDLImage.hh"
 #include "IntegerSetting.hh"
+#include "FilenameSetting.hh"
 #include "CliComm.hh"
 #include "Display.hh"
 #include "IconStatus.hh"
@@ -18,6 +19,18 @@ using std::string;
 
 namespace openmsx {
 
+template <class IMAGE>
+class IconSettingChecker : public SettingChecker<FilenameSetting::Policy>
+{
+public:
+	IconSettingChecker(IconLayer<IMAGE>& iconLayer);
+	virtual void check(SettingImpl<FilenameSetting::Policy>& setting,
+	                   std::string& value);
+private:
+	IconLayer<IMAGE>& iconLayer;
+};
+
+
 template <class IMAGE>
 IconLayer<IMAGE>::IconLayer(CommandController& commandController,
                             Display& display_, IconStatus& iconStatus_,
@@ -28,6 +41,7 @@ IconLayer<IMAGE>::IconLayer(CommandController& commandController,
 	, iconStatus(iconStatus_)
 	, outputScreen(screen)
 	, scaleFactor(outputScreen->w / 640.0)
+	, iconSettingChecker(new IconSettingChecker<IMAGE>(*this))
 {
 	createSettings(commandController, LedEvent::POWER, "power");
 	createSettings(commandController, LedEvent::CAPS,  "caps");
@@ -44,7 +58,7 @@ void IconLayer<IMAGE>::createSettings(CommandController& commandController,
 	string icon_name = "icon." + name;
 	ledInfo[led].xcoord.reset(new IntegerSetting(commandController,
 		icon_name + ".xcoord", "X-coordinate for LED icon",
-		((int)led) * 60, 0, 640));
+		int(led) * 60, 0, 640));
 	//Default is 640x480 and we want the default icons on the bottom
 	ledInfo[led].ycoord.reset(new IntegerSetting(commandController,
 		icon_name + ".ycoord", "Y-coordinate for LED icon",
@@ -65,7 +79,7 @@ void IconLayer<IMAGE>::createSettings(CommandController& commandController,
 			"completely opaque to completely transparent", 5000, 0, 1000000));
 
 		try {
-			ledInfo[led].name[i]->setChecker(this);
+			ledInfo[led].name[i]->setChecker(iconSettingChecker.get());
 		} catch (MSXException& e) {
 			commandController.getCliComm().printWarning(e.getMessage());
 		}
@@ -108,10 +122,8 @@ void IconLayer<IMAGE>::paint()
 		}
 		IMAGE* icon = led.icon[status].get();
 		if (icon) {
-			unsigned x = static_cast<unsigned>(
-			                scaleFactor * led.xcoord->getValue());
-			unsigned y = static_cast<unsigned>(
-			                scaleFactor * led.ycoord->getValue());
+			unsigned x = unsigned(scaleFactor * led.xcoord->getValue());
+			unsigned y = unsigned(scaleFactor * led.ycoord->getValue());
 			icon->draw(x, y, alpha);
 		}
 	}
@@ -124,21 +136,30 @@ const string& IconLayer<IMAGE>::getName()
 	return NAME;
 }
 
+
+// class IconSettingChecker
+
 template <class IMAGE>
-void IconLayer<IMAGE>::check(SettingImpl<FilenameSetting::Policy>& setting,
-                             string& value)
+IconSettingChecker<IMAGE>::IconSettingChecker(IconLayer<IMAGE>& iconLayer_)
+	: iconLayer(iconLayer_)
+{
+}
+
+template <class IMAGE>
+void IconSettingChecker<IMAGE>::check(SettingImpl<FilenameSetting::Policy>& setting,
+                                      string& value)
 {
 	SystemFileContext context;
 	for (int i = 0; i < LedEvent::NUM_LEDS; ++i) {
 		for (int j = 0; j < 2; ++j) {
-			if (&setting == ledInfo[i].name[j].get()) {
+			if (&setting == iconLayer.ledInfo[i].name[j].get()) {
 				if (value.empty()) {
-					ledInfo[i].icon[j].reset();
+					iconLayer.ledInfo[i].icon[j].reset();
 				} else {
-					ledInfo[i].icon[j].reset(
-					    new IMAGE(outputScreen,
+					iconLayer.ledInfo[i].icon[j].reset(
+					    new IMAGE(iconLayer.outputScreen,
 					              context.resolve(value),
-					              scaleFactor));
+					              iconLayer.scaleFactor));
 				}
 				break;
 			}
