@@ -1,8 +1,9 @@
-// $Id: IconStatus.cc,v 1.4 2006/03/03 15:47:28 m9710797 Exp $
+// $Id: IconStatus.cc 5597 2006-09-02 10:15:03Z m9710797 $
 
 #include "IconStatus.hh"
 #include "EventDistributor.hh"
 #include "Timer.hh"
+#include "checked_cast.hh"
 #include <cassert>
 
 namespace openmsx {
@@ -34,16 +35,16 @@ unsigned long long IconStatus::getTime(int icon) const
 	return iconTime[icon];
 }
 
-void IconStatus::signalEvent(const Event& event)
+bool IconStatus::signalEvent(shared_ptr<const Event> event)
 {
-	assert(event.getType() == OPENMSX_LED_EVENT);
-	const LedEvent& ledEvent = static_cast<const LedEvent&>(event);
+	const LedEvent& ledEvent = checked_cast<const LedEvent&>(*event);
 	LedEvent::Led led = ledEvent.getLed();
 	bool status = ledEvent.getStatus();
 	if (status != iconStatus[led]) {
 		iconStatus[led] = status;
 		iconTime[led] = Timer::getTime();
 	}
+	return true;
 }
 
 } // namespace openmsx
