@@ -1,4 +1,4 @@
-// $Id: OutputSurface.cc 5254 2006-03-13 21:30:41Z mthuurne $
+// $Id: OutputSurface.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "OutputSurface.hh"
 
@@ -15,9 +15,9 @@ OutputSurface::~OutputSurface()
 
 unsigned OutputSurface::mapRGB(double dr, double dg, double db)
 {
-	int r = static_cast<int>(dr * 255.0);
-	int g = static_cast<int>(dg * 255.0);
-	int b = static_cast<int>(db * 255.0);
+	int r = int(dr * 255.0);
+	int g = int(dg * 255.0);
+	int b = int(db * 255.0);
 	return SDL_MapRGB(&format, r, g, b);
 }
 
