@@ -1,4 +1,4 @@
-// $Id: PixelRenderer.cc 5984 2007-01-08 22:03:21Z m9710797 $
+// $Id: PixelRenderer.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 /*
 TODO:
@@ -174,7 +174,7 @@ void PixelRenderer::frameStart(const EmuTime& time)
 				renderFrame = true;
 			} else {
 				renderFrame = realTime.timeLeft(
-					(unsigned)finishFrameDuration, time);
+					unsigned(finishFrameDuration), time);
 			}
 			if (renderFrame) {
 				frameSkipCounter = 0;
