@@ -1,4 +1,4 @@
-// $Id: PostProcessor.cc 6137 2007-03-03 14:03:31Z m9710797 $
+// $Id: PostProcessor.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "PostProcessor.hh"
 #include "Display.hh"
@@ -106,9 +106,11 @@ RawFrame* PostProcessor::rotateFrames(
 		const void* lines[240];
 		for (int i = 0; i < 240; ++i) {
 			if (getBpp() == 32) {
-				lines[i] = paintFrame->getLinePtr320_240(i, (unsigned*)0);
+				unsigned* dummy = 0;
+				lines[i] = paintFrame->getLinePtr320_240(i, dummy);
 			} else {
-				lines[i] = paintFrame->getLinePtr320_240(i, (word*)0);
+				word* dummy = 0;
+				lines[i] = paintFrame->getLinePtr320_240(i, dummy);
 			}
 		}
 		recorder->addImage(lines, time);
