@@ -1,4 +1,4 @@
-// $Id: RawFrame.cc,v 1.12 2006/01/05 23:10:12 mthuurne Exp $
+// $Id: RawFrame.cc 5958 2006-12-23 11:46:43Z m9710797 $
 
 #include "RawFrame.hh"
 #include "MemoryOps.hh"
@@ -20,6 +20,7 @@ RawFrame::RawFrame(
 	//  SSE instruction need 16 byte aligned data
 	//  cache line size on athlon and P4 CPUs is 64 bytes
 	pitch = ((bytesPerPixel * maxWidth) + 63) & ~63;
+	maxWidth = pitch / bytesPerPixel;
 	data = reinterpret_cast<char*>(
 			MemoryOps::mallocAligned(64, pitch * height));
 
@@ -56,4 +57,14 @@ void* RawFrame::getLinePtrImpl(unsigned line)
 	return data + line * pitch;
 }
 
+unsigned RawFrame::getRowLength() const
+{
+	return maxWidth; // in pixels (not in bytes)
+}
+
+bool RawFrame::hasContiguousStorage() const
+{
+	return true;
+}
+
 } // namespace openmsx
