@@ -1,4 +1,4 @@
-// $Id: RendererFactory.cc,v 1.75 2006/07/17 21:46:12 m9710797 Exp $
+// $Id: RendererFactory.cc 5993 2007-01-12 22:12:12Z m9710797 $
 
 #include "RendererFactory.hh"
 #include "RenderSettings.hh"
@@ -16,7 +16,6 @@
 // Renderers:
 #include "DummyRenderer.hh"
 #include "PixelRenderer.hh"
-#include "XRenderer.hh"
 #include "V9990DummyRenderer.hh"
 #include "V9990PixelRenderer.hh"
 
@@ -31,7 +30,6 @@ VideoSystem* RendererFactory::createVideoSystem(Reactor& reactor)
 			return new DummyVideoSystem();
 		case SDL:
 		case SDLGL:
-		case SDLGL2:
 		case SDLGL_PP:
 		case SDLGL_FB16:
 		case SDLGL_FB32:
@@ -49,15 +47,10 @@ Renderer* RendererFactory::createRenderer(VDP& vdp, Display& display)
 			return new DummyRenderer();
 		case SDL:
 		case SDLGL:
-		case SDLGL2:
 		case SDLGL_PP:
 		case SDLGL_FB16:
 		case SDLGL_FB32:
 			return new PixelRenderer(vdp, display);
-#ifdef HAVE_X11
-		case XLIB:
-			return new XRenderer(XLIB, vdp);
-#endif
 		default:
 			assert(false);
 			return 0;
@@ -72,7 +65,6 @@ V9990Renderer* RendererFactory::createV9990Renderer(
 			return new V9990DummyRenderer();
 		case SDL:
 		case SDLGL:
-		case SDLGL2:
 		case SDLGL_PP:
 		case SDLGL_FB16:
 		case SDLGL_FB32:
@@ -109,12 +101,7 @@ auto_ptr<RendererFactory::RendererSetting>
 		//  renderers and sdlgl-fb32 still has endian problems on PPC
 		rendererMap["SDLGL-FB16"] = SDLGL_FB16;
 		rendererMap["SDLGL-FB32"] = SDLGL_FB32;
-		rendererMap["SDLGL2"] = SDLGL2;
 	}
-#endif
-#ifdef HAVE_X11
-	// XRenderer is not ready for users.
-	// rendererMap["Xlib" ] = XLIB;
 #endif
 	auto_ptr<RendererSetting> setting(new RendererSetting(commandController,
 		"renderer", "rendering back-end used to display the MSX screen",
