@@ -1,4 +1,4 @@
-// $Id: SDLRasterizer.cc 5984 2007-01-08 22:03:21Z m9710797 $
+// $Id: SDLRasterizer.cc 6845 2007-08-20 21:15:32Z m9710797 $
 
 #include "SDLRasterizer.hh"
 #include "VDP.hh"
@@ -317,7 +317,8 @@ void SDLRasterizer<Pixel>::drawBorder(
 		unsigned width = (lineWidth == 512) ? 640 : 320;
 		MemoryOps::MemSet2<Pixel, MemoryOps::NO_STREAMING> memset;
 		for (int y = startY; y < endY; ++y) {
-			memset(workFrame->getLinePtr(y, (Pixel*)0) + x,
+			Pixel* dummy = 0;
+			memset(workFrame->getLinePtr(y, dummy) + x,
 			       num, border0, border1);
 			workFrame->setLineWidth(y, width);
 		}
@@ -397,12 +398,17 @@ void SDLRasterizer<Pixel>::drawDisplay(
 
 			int firstPageWidth = pageBorder - displayX;
 			if (firstPageWidth > 0) {
-				Pixel buf[512];
-				renderBitmapLine(buf, vramLine[scrollPage1]);
-				const Pixel* src = buf + displayX + hScroll;
-				Pixel* dst = workFrame->getLinePtr(y, (Pixel*)0)
+				Pixel* dummy = 0;
+				Pixel* dst = workFrame->getLinePtr(y, dummy)
 				           + leftBackground + displayX;
-				MemoryOps::stream_memcpy(dst, src, firstPageWidth);
+				if ((displayX + hScroll) == 0) {
+					renderBitmapLine(dst, vramLine[scrollPage1]);
+				} else {
+					Pixel buf[512];
+					renderBitmapLine(buf, vramLine[scrollPage1]);
+					const Pixel* src = buf + displayX + hScroll;
+					MemoryOps::stream_memcpy(dst, src, firstPageWidth);
+				}
 			} else {
 				firstPageWidth = 0;
 			}
@@ -413,7 +419,8 @@ void SDLRasterizer<Pixel>::drawDisplay(
 				Pixel buf[512];
 				renderBitmapLine(buf, vramLine[scrollPage2]);
 				const Pixel* src = buf + x;
-				Pixel* dst = workFrame->getLinePtr(y, (Pixel*)0)
+				Pixel* dummy = 0;
+				Pixel* dst = workFrame->getLinePtr(y, dummy)
 				           + leftBackground + displayX
 					   + firstPageWidth;
 				MemoryOps::stream_memcpy(dst, src, num);
@@ -427,12 +434,17 @@ void SDLRasterizer<Pixel>::drawDisplay(
 		for (int y = screenY; y < screenLimitY; y++) {
 			assert(!vdp.isMSX1VDP() || displayY < 192);
 
-			Pixel buf[512];
-			characterConverter->convertLine(buf, displayY);
-			const Pixel* src = buf + displayX;
-			Pixel* dst = workFrame->getLinePtr(y, (Pixel*)0)
+			Pixel* dummy = 0;
+			Pixel* dst = workFrame->getLinePtr(y, dummy)
 			           + leftBackground + displayX;
-			MemoryOps::stream_memcpy(dst, src, displayWidth);
+			if (displayX == 0) {
+				characterConverter->convertLine(dst, displayY);
+			} else {
+				Pixel buf[512];
+				characterConverter->convertLine(buf, displayY);
+				const Pixel* src = buf + displayX;
+				MemoryOps::stream_memcpy(dst, src, displayWidth);
+			}
 
 			workFrame->setLineWidth(y, (lineWidth == 512) ? 640 : 320);
 			displayY = (displayY + 1) & 255;
@@ -470,7 +482,8 @@ void SDLRasterizer<Pixel>::drawSprites(
 		vdp.getLeftSprites(),
 		vdp.getDisplayMode().getLineWidth() == 512);
 	for (int y = fromY; y < limitY; y++, screenY++) {
-		Pixel* pixelPtr = workFrame->getLinePtr(screenY, (Pixel*)0) + screenX;
+		Pixel* dummy = 0;
+		Pixel* pixelPtr = workFrame->getLinePtr(screenY, dummy) + screenX;
 		if (spriteMode == 1) {
 			spriteConverter->drawMode1(y, displayX, displayLimitX, pixelPtr);
 		} else {
