@@ -1,4 +1,4 @@
-// $Id: SDLSnow.cc 4862 2005-11-13 21:05:52Z m9710797 $
+// $Id: SDLSnow.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "SDLSnow.hh"
 #include "openmsx.hh"
@@ -37,11 +37,11 @@ void SDLSnow<Pixel>::paint()
 {
 	const unsigned WIDTH = screen->w;
 	const unsigned HEIGHT = screen->h;
-	Pixel* pixels = (Pixel*)screen->pixels;
+	Pixel* pixels = static_cast<Pixel*>(screen->pixels);
 	for (unsigned y = 0; y < HEIGHT; y += 2) {
 		Pixel* p = &pixels[WIDTH * y];
 		for (unsigned x = 0; x < WIDTH; x += 2) {
-			byte a = (byte)random();
+			byte a = byte(random());
 			p[x + 0] = p[x + 1] = gray[a];
 		}
 		memcpy(p + WIDTH, p, WIDTH * sizeof(Pixel));
