@@ -1,4 +1,4 @@
-// $Id: SDLVideoSystem.cc,v 1.51 2006/05/25 14:17:12 m9710797 Exp $
+// $Id: SDLVideoSystem.cc 6131 2007-03-02 12:00:24Z m9710797 $
 
 #include "SDLVideoSystem.hh"
 #include "SDLVisibleSurface.hh"
@@ -10,7 +10,6 @@
 #include "RenderSettings.hh"
 #include "BooleanSetting.hh"
 #include "IntegerSetting.hh"
-#include "VideoSourceSetting.hh"
 #include "EventDistributor.hh"
 #include "InputEventGenerator.hh"
 #include <cassert>
@@ -19,7 +18,6 @@
 #ifdef COMPONENT_GL
 #include "SDLGLVisibleSurface.hh"
 #include "GLRasterizer.hh"
-#include "GL2Rasterizer.hh"
 #include "V9990GLRasterizer.hh"
 #include "GLPostProcessor.hh"
 #endif
@@ -36,8 +34,7 @@ SDLVideoSystem::SDLVideoSystem(Reactor& reactor)
 	console = screen->createConsoleLayer(reactor);
 	snowLayer = screen->createSnowLayer();
 	iconLayer = screen->createIconLayer(
-		reactor.getCommandController(), display, reactor.getIconStatus()
-		);
+		reactor.getCommandController(), display, reactor.getIconStatus());
 	display.addLayer(*console);
 	display.addLayer(*snowLayer);
 	display.addLayer(*iconLayer);
@@ -72,17 +69,13 @@ Rasterizer* SDLVideoSystem::createRasterizer(VDP& vdp)
 				vdp, display, *screen,
 				std::auto_ptr<PostProcessor>(new FBPostProcessor<Uint16>(
 					reactor.getCommandController(),
-					display, *screen, VIDEO_MSX, 640, 240
-					))
-				);
+					display, *screen, VIDEO_MSX, 640, 240)));
 		case 4:
 			return new SDLRasterizer<Uint32>(
 				vdp, display, *screen,
 				std::auto_ptr<PostProcessor>(new FBPostProcessor<Uint32>(
 					reactor.getCommandController(),
-					display, *screen, VIDEO_MSX, 640, 240
-					))
-				);
+					display, *screen, VIDEO_MSX, 640, 240)));
 		default:
 			assert(false);
 			return NULL;
@@ -90,20 +83,13 @@ Rasterizer* SDLVideoSystem::createRasterizer(VDP& vdp)
 #ifdef COMPONENT_GL
 	case RendererFactory::SDLGL:
 		return new GLRasterizer(
-			reactor.getCommandController(), vdp, display, *screen
-			);
-	case RendererFactory::SDLGL2:
-		return new GL2Rasterizer(
-			reactor.getCommandController(), vdp, display, *screen
-			);
+			reactor.getCommandController(), vdp, display, *screen);
 	case RendererFactory::SDLGL_PP:
 		return new SDLRasterizer<Uint32>(
 			vdp, display, *screen,
 			std::auto_ptr<PostProcessor>(new GLPostProcessor(
 				reactor.getCommandController(),
-				display, *screen, VIDEO_MSX, 640, 240
-				))
-			);
+				display, *screen, VIDEO_MSX, 640, 240)));
 #endif
 	default:
 		assert(false);
@@ -123,33 +109,26 @@ V9990Rasterizer* SDLVideoSystem::createV9990Rasterizer(V9990& vdp)
 				vdp, display, *screen,
 				std::auto_ptr<PostProcessor>(new FBPostProcessor<Uint16>(
 					reactor.getCommandController(),
-					display, *screen, VIDEO_GFX9000, 1280, 240
-					))
-				);
+					display, *screen, VIDEO_GFX9000, 1280, 240)));
 		case 4:
 			return new V9990SDLRasterizer<Uint32>(
 				vdp, display, *screen,
 				std::auto_ptr<PostProcessor>(new FBPostProcessor<Uint32>(
 					reactor.getCommandController(),
-					display, *screen, VIDEO_GFX9000, 1280, 240
-					))
-				);
+					display, *screen, VIDEO_GFX9000, 1280, 240)));
 		default:
 			assert(false);
 			return NULL;
 		}
 #ifdef COMPONENT_GL
 	case RendererFactory::SDLGL:
-	case RendererFactory::SDLGL2:
 		return new V9990GLRasterizer(vdp);
 	case RendererFactory::SDLGL_PP:
 		return new V9990SDLRasterizer<unsigned>(
 			vdp, display, *screen,
 			std::auto_ptr<PostProcessor>(new GLPostProcessor(
 				reactor.getCommandController(),
-				display, *screen, VIDEO_GFX9000, 1280, 240
-				))
-			);
+				display, *screen, VIDEO_GFX9000, 1280, 240)));
 #endif
 	default:
 		assert(false);
@@ -168,7 +147,6 @@ void SDLVideoSystem::getWindowSize(unsigned& width, unsigned& height)
 		if (factor > 3) factor = 3;
 		break;
 	case RendererFactory::SDLGL:
-	case RendererFactory::SDLGL2:
 		// These renderers only support 2x scaling.
 		factor = 2;
 		break;
@@ -234,7 +212,6 @@ void SDLVideoSystem::resize()
 		break;
 #ifdef COMPONENT_GL
 	case RendererFactory::SDLGL:
-	case RendererFactory::SDLGL2:
 	case RendererFactory::SDLGL_PP:
 		screen.reset(new SDLGLVisibleSurface(width, height, fullscreen));
 		break;
@@ -264,15 +241,14 @@ void SDLVideoSystem::update(const Setting& subject)
 	}
 }
 
-void SDLVideoSystem::signalEvent(const Event& event)
+bool SDLVideoSystem::signalEvent(shared_ptr<const Event> /*event*/)
 {
 	// TODO: Currently window size depends only on scale factor.
 	//       Maybe in the future it will be handled differently.
-	(void)event;
-	assert(event.getType() == OPENMSX_RESIZE_EVENT);
-	//const ResizeEvent& resizeEvent = static_cast<const ResizeEvent&>(event);
+	//const ResizeEvent& resizeEvent = checked_cast<const ResizeEvent&>(event);
 	//resize(resizeEvent.getX(), resizeEvent.getY());
 	//resize();
+	return true;
 }
 
 } // namespace openmsx
