@@ -1,4 +1,4 @@
-// $Id: SDLVisibleSurface.cc 5204 2006-02-27 21:49:17Z m9710797 $
+// $Id: SDLVisibleSurface.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "SDLVisibleSurface.hh"
 #include "ScreenShotSaver.hh"
@@ -7,6 +7,7 @@
 #include "SDLConsole.hh"
 #include "IconLayer.hh"
 #include <cstring>
+#include <cassert>
 
 namespace openmsx {
 
@@ -17,7 +18,7 @@ SDLVisibleSurface::SDLVisibleSurface(
 	createSurface(width, height, flags);
 	memcpy(&format, surface->format, sizeof(SDL_PixelFormat));
 
-	data = (char*)surface->pixels;
+	data = static_cast<char*>(surface->pixels);
 	pitch = surface->pitch;
 }
 
