@@ -1,4 +1,4 @@
-// $Id: SaI3xScaler.cc 5907 2006-11-29 17:23:52Z m9710797 $
+// $Id: SaI3xScaler.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 // 2xSaI is Copyright (c) 1999-2001 by Derek Liauw Kie Fa.
 //   http://elektron.its.tudelft.nl/~dalikifa/
@@ -327,7 +327,8 @@ public:
 		const Pixel* src3, unsigned srcWidth,
 		OutputSurface& dst, unsigned& dstY)
 	{
-		Pixel* dp = dst.getLinePtr(dstY++, (Pixel*)0);
+		Pixel* dummy = 0;
+		Pixel* dp = dst.getLinePtr(dstY++, dummy);
 		// Calculate fixed point coordinate.
 		const unsigned y1 = ((NY - i) << 16) / NY;
 
