@@ -1,4 +1,4 @@
-// $Id: Simple3xScaler.cc 6097 2007-02-19 11:44:49Z m9710797 $
+// $Id: Simple3xScaler.cc 6598 2007-06-05 23:02:27Z mthuurne $
 
 #include "Simple3xScaler.hh"
 #include "LineScalers.hh"
@@ -43,7 +43,7 @@ template <typename ScaleOp>
 void Simple3xScaler<Pixel>::doScale1(FrameSource& src,
 	unsigned srcStartY, unsigned /*srcEndY*/, unsigned srcWidth,
 	OutputSurface& dst, unsigned dstStartY, unsigned dstEndY,
-	ScaleOp scale)
+	ScaleOp& scale)
 {
 	int scanlineFactor = settings.getScanlineFactor();
 	unsigned y = dstStartY;
@@ -84,7 +84,7 @@ template <typename ScaleOp>
 void Simple3xScaler<Pixel>::doScale2(FrameSource& src,
 	unsigned srcStartY, unsigned /*srcEndY*/, unsigned srcWidth,
 	OutputSurface& dst, unsigned dstStartY, unsigned dstEndY,
-	ScaleOp scale)
+	ScaleOp& scale)
 {
 	Pixel* dummy = 0;
 	int scanlineFactor = settings.getScanlineFactor();
@@ -109,8 +109,8 @@ void Simple3xScaler<Pixel>::scale2x1to9x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_2on9<Pixel>(pixelOps));
+	Scale_2on9<Pixel> op(pixelOps);
+	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -118,8 +118,8 @@ void Simple3xScaler<Pixel>::scale2x2to9x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_2on9<Pixel>(pixelOps));
+	Scale_2on9<Pixel> op(pixelOps);
+	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -129,10 +129,11 @@ void Simple3xScaler<Pixel>::scale1x1to3x3(FrameSource& src,
 {
 	if (settings.getBlurFactor()) {
 		doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-			 *blur_1on3);
+			*blur_1on3);
 	} else {
+		Scale_1on3<Pixel> op;
 		doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-			 Scale_1on3<Pixel>());
+			op);
 	}
 }
 
@@ -141,8 +142,8 @@ void Simple3xScaler<Pixel>::scale1x2to3x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_1on3<Pixel>());
+	Scale_1on3<Pixel> op;
+	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -150,8 +151,8 @@ void Simple3xScaler<Pixel>::scale4x1to9x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_4on9<Pixel>(pixelOps));
+	Scale_4on9<Pixel> op(pixelOps);
+	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -159,8 +160,8 @@ void Simple3xScaler<Pixel>::scale4x2to9x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_4on9<Pixel>(pixelOps));
+	Scale_4on9<Pixel> op(pixelOps);
+	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -168,8 +169,8 @@ void Simple3xScaler<Pixel>::scale2x1to3x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_2on3<Pixel>(pixelOps));
+	Scale_2on3<Pixel> op(pixelOps);
+	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -177,8 +178,8 @@ void Simple3xScaler<Pixel>::scale2x2to3x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_2on3<Pixel>(pixelOps));
+	Scale_2on3<Pixel> op(pixelOps);
+	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -186,8 +187,8 @@ void Simple3xScaler<Pixel>::scale8x1to9x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_8on9<Pixel>(pixelOps));
+	Scale_8on9<Pixel> op(pixelOps);
+	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -195,8 +196,8 @@ void Simple3xScaler<Pixel>::scale8x2to9x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_8on9<Pixel>(pixelOps));
+	Scale_8on9<Pixel> op(pixelOps);
+	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -204,8 +205,8 @@ void Simple3xScaler<Pixel>::scale4x1to3x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_4on3<Pixel>(pixelOps));
+	Scale_4on3<Pixel> op(pixelOps);
+	doScale1(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -213,8 +214,8 @@ void Simple3xScaler<Pixel>::scale4x2to3x3(FrameSource& src,
 		unsigned srcStartY, unsigned srcEndY, unsigned srcWidth,
 		OutputSurface& dst, unsigned dstStartY, unsigned dstEndY)
 {
-	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY,
-	         Scale_4on3<Pixel>(pixelOps));
+	Scale_4on3<Pixel> op(pixelOps);
+	doScale2(src, srcStartY, srcEndY, srcWidth, dst, dstStartY, dstEndY, op);
 }
 
 template <class Pixel>
@@ -275,7 +276,7 @@ void Simple3xScaler<Pixel>::scaleBlank2to3(
 
 template <class Pixel>
 Blur_1on3<Pixel>::Blur_1on3(const PixelOperations<Pixel>& pixelOps,
-                            const RenderSettings& settings_) 
+                            const RenderSettings& settings_)
 	: mult0(pixelOps.format)
 	, mult1(pixelOps.format)
 	, mult2(pixelOps.format)
@@ -290,7 +291,7 @@ void Blur_1on3<Pixel>::operator()(const Pixel* in, Pixel* out, unsigned long dst
 	/* The following code is equivalent to this loop. It is 2x unrolled
 	 * and common subexpressions have been eliminated. The last iteration
 	 * is also moved outside the for loop.
-	 * 
+	 *
 	 *  unsigned c0 = alpha / 2;
 	 *  unsigned c1 = c0 + alpha;
 	 *  unsigned c2 = 256 - c1;
@@ -310,7 +311,7 @@ void Blur_1on3<Pixel>::operator()(const Pixel* in, Pixel* out, unsigned long dst
 	unsigned long alpha = settings.getBlurFactor() / 3;
 	#ifdef ASM_X86
 	const HostCPU& cpu = HostCPU::getInstance();
-	if ((sizeof(Pixel) == 4) && cpu.hasMMXEXT()) {
+	if ((sizeof(Pixel) == 4) && cpu.hasSSE()) {
 		// MMX-EXT routine, 32bpp
 		alpha *= 256;
 		unsigned t0, t1, t2, t3;
@@ -389,10 +390,10 @@ void Blur_1on3<Pixel>::operator()(const Pixel* in, Pixel* out, unsigned long dst
 			"paddw     %%mm4, %%mm1;"          // b1 = t1 + s1 + g0
 			"packuswb  %%mm7, %%mm1;"          // b1 | b2
 			"add       $8, %[IN];"             // x += 2
-			"movq      %%mm1, 16(%[OUT],%[Y]);"// out[y + 4] = 
+			"movq      %%mm1, 16(%[OUT],%[Y]);"// out[y + 4] =
 			"add       $24, %[Y];"             // y += 6
 			"jnz       0b;"                    //
-			
+
 			"movq      %%mm5, %%mm1;"          // in[x + 1]
 			"movq      %%mm0, %%mm7;"          // p0
 			"punpckhbw   (%[CNST]), %%mm1;"    // p1 = unpack(in[x + 1])
@@ -418,7 +419,7 @@ void Blur_1on3<Pixel>::operator()(const Pixel* in, Pixel* out, unsigned long dst
 			"paddw     %%mm4, %%mm1;"          // s1 + g0
 			"paddw     %%mm2, %%mm1;"          // b1 = t1 + s1 + g0
 			"packuswb  %%mm7, %%mm1;"          // b1 | b2
-			"movq      %%mm1, 16(%[OUT]);"     // out[y + 4] = 
+			"movq      %%mm1, 16(%[OUT]);"     // out[y + 4] =
 
 			"emms;"
 
