@@ -1,11 +1,10 @@
-// $Id: SimpleScaler.cc,v 1.51 2006/03/01 22:32:36 m9710797 Exp $
+// $Id: SimpleScaler.cc 6131 2007-03-02 12:00:24Z m9710797 $
 
 #include "SimpleScaler.hh"
 #include "LineScalers.hh"
 #include "FrameSource.hh"
 #include "OutputSurface.hh"
 #include "RenderSettings.hh"
-#include "IntegerSetting.hh"
 #include "MemoryOps.hh"
 #include "HostCPU.hh"
 #include "openmsx.hh"
@@ -38,16 +37,15 @@ void SimpleScaler<Pixel>::scaleBlank1to2(
 	unsigned stopDstY = (dstEndY == dst.getHeight())
 	                  ? dstEndY : dstEndY - 2;
 	unsigned srcY = srcStartY, dstY = dstStartY;
+	MemoryOps::MemSet<Pixel, MemoryOps::STREAMING> memset;
 	for (/* */; dstY < stopDstY; srcY += 1, dstY += 2) {
 		Pixel* dummy = 0;
 		Pixel color0 = src.getLinePtr(srcY, dummy)[0];
 		Pixel* dstLine0 = dst.getLinePtr(dstY + 0, dummy);
-		MemoryOps::memset<Pixel, MemoryOps::STREAMING>(
-			dstLine0, dst.getWidth(), color0);
+		memset(dstLine0, dst.getWidth(), color0);
 		Pixel color1 = scanline.darken(color0, scanlineFactor);
 		Pixel* dstLine1 = dst.getLinePtr(dstY + 1, dummy);
-		MemoryOps::memset<Pixel, MemoryOps::STREAMING>(
-			dstLine1, dst.getWidth(), color1);
+		memset(dstLine1, dst.getWidth(), color1);
 	}
 	if (dstY != dst.getHeight()) {
 		unsigned nextLineWidth = src.getLineWidth(srcY + 1);
@@ -60,7 +58,7 @@ void SimpleScaler<Pixel>::scaleBlank1to2(
 
 template <class Pixel>
 void SimpleScaler<Pixel>::blur1on2(const Pixel* pIn, Pixel* pOut, unsigned alpha,
-                                   unsigned srcWidth)
+                                   unsigned long srcWidth)
 {
 	/* This routine is functionally equivalent to the following:
 	 *
@@ -151,7 +149,7 @@ void SimpleScaler<Pixel>::blur1on2(const Pixel* pIn, Pixel* pOut, unsigned alpha
 			"packuswb %%mm4, %%mm1;"
 			"movq	%%mm1, 8(%1,%4,2);"	// pOut[2*x+2] = ..  pOut[2*x+3] = ..
 
-			"addl	$8, %4;"
+			"add	$8, %4;"
 			"jnz	1b;"
 
 			"pmullw	%%mm6, %%mm0;"
@@ -181,8 +179,8 @@ void SimpleScaler<Pixel>::blur1on2(const Pixel* pIn, Pixel* pOut, unsigned alpha
 			: // no output
 			: "r" (pIn  +     (srcWidth - 2)) // 0
 			, "r" (pOut + 2 * (srcWidth - 2)) // 1
-			, "r" (c1)                        // 2
-			, "r" (c2)                        // 3
+			, "r" (c1)                         // 2
+			, "r" (c2)                         // 3
 			, "r" (-4 * (srcWidth - 2))       // 4
 			#ifdef __MMX__
 			: "mm0", "mm1", "mm2", "mm3", "mm4", "mm5", "mm6", "mm7"
@@ -234,7 +232,7 @@ void SimpleScaler<Pixel>::blur1on2(const Pixel* pIn, Pixel* pOut, unsigned alpha
 
 template <class Pixel>
 void SimpleScaler<Pixel>::blur1on1(const Pixel* pIn, Pixel* pOut, unsigned alpha,
-                                   unsigned srcWidth)
+                                   unsigned long srcWidth)
 {
 	/* This routine is functionally equivalent to the following:
 	 *
@@ -319,7 +317,7 @@ void SimpleScaler<Pixel>::blur1on1(const Pixel* pIn, Pixel* pOut, unsigned alpha
 			"packuswb %%mm7, %%mm4;"
 			"movq	%%mm4, (%1,%4);"	// pOut[x] = ..  pOut[x+1] = ..
 
-			"addl	$8, %4;"
+			"add	$8, %4;"
 			"jnz	1b;"
 
 			"movd	4(%0), %%mm1;"
@@ -345,9 +343,9 @@ void SimpleScaler<Pixel>::blur1on1(const Pixel* pIn, Pixel* pOut, unsigned alpha
 			: // no output
 			: "r" (pIn  + srcWidth - 2) // 0
 			, "r" (pOut + srcWidth - 2) // 1
-			, "r" (c1)                        // 2
-			, "r" (c2)                        // 3
-			, "r" (-4 * (srcWidth - 2))       // 4
+			, "r" (c1)                   // 2
+			, "r" (c2)                   // 3
+			, "r" (-4 * (srcWidth - 2)) // 4
 			#ifdef __MMX__
 			: "mm0", "mm1", "mm2", "mm3", "mm4", "mm5", "mm6", "mm7"
 			#endif
