@@ -1,4 +1,4 @@
-// $Id: SpriteChecker.cc,v 1.19 2006/01/23 19:35:25 m9710797 Exp $
+// $Id: SpriteChecker.cc 5940 2006-12-17 19:27:18Z m9710797 $
 
 /*
 TODO:
@@ -14,6 +14,7 @@ TODO:
 #include "SpriteChecker.hh"
 #include "RenderSettings.hh"
 #include "BooleanSetting.hh"
+#include <algorithm>
 #include <cassert>
 
 namespace openmsx {
@@ -30,7 +31,7 @@ SpriteChecker::SpriteChecker(VDP& vdp_, RenderSettings& renderSettings,
 
 void SpriteChecker::reset(const EmuTime& time)
 {
-	status = 0;
+	vdp.setSpriteStatus(0); // TODO 0x00 or 0x1F  (blueMSX has 0x1F)
 	collisionX = 0;
 	collisionY = 0;
 
@@ -40,38 +41,23 @@ void SpriteChecker::reset(const EmuTime& time)
 	mode0 = false;
 }
 
-inline SpriteChecker::SpritePattern SpriteChecker::doublePattern(SpriteChecker::SpritePattern a)
+static inline SpriteChecker::SpritePattern doublePattern(SpriteChecker::SpritePattern a)
 {
 	// bit-pattern "abcd...." gets expanded to "aabbccdd"
-	a =   a                     | (a >> 16);
-	a = ((a << 8) & 0x00ffff00) | (a & 0xff0000ff);
-	a = ((a << 4) & 0x0ff00ff0) | (a & 0xf00ff00f);
-	a = ((a << 2) & 0x3c3c3c3c) | (a & 0xc3c3c3c3);
-	a = ((a << 1) & 0x66666666) | (a & 0x99999999);
-	return a;
+	// upper 16 bits (of a 32 bit number) contain the pattern
+	// lower 16 bits must be zero
+	//                               // abcdefghijklmnop0000000000000000
+	a = (a | (a >> 8)) & 0xFF00FF00; // abcdefgh00000000ijklmnop00000000
+	a = (a | (a >> 4)) & 0xF0F0F0F0; // abcd0000efgh0000ijkl0000mnop0000
+	a = (a | (a >> 2)) & 0xCCCCCCCC; // ab00cd00ef00gh00ij00kl00mn00op00
+	a = (a | (a >> 1)) & 0xAAAAAAAA; // a0b0c0d0e0f0g0h0i0j0k0l0m0n0o0p0
+	return a | (a >> 1);             // aabbccddeeffgghhiijjkkllmmnnoopp
 }
 
-inline SpriteChecker::SpritePattern SpriteChecker::calculatePattern(
-	int patternNr, int y)
-{
-	// Note: For sprite pattern, mask and index never overlap.
-	const byte *patternPtr = vram.spritePatternTable.readArea(
-		planar ? 0x0FC00 : 0x1F800 );
-	int index = patternNr * 8 + y;
-	if (planar) index = ((index << 16) | (index >> 1)) & 0x1FFFF;
-	SpritePattern pattern = patternPtr[index] << 24;
-	if (vdp.getSpriteSize() == 16) {
-		pattern |= patternPtr[index + (planar ? 8 : 16)] << 16;
-	}
-	return vdp.getSpriteMag() == 1 ? pattern : doublePattern(pattern);
-}
-
-// TODO: Integrate with calculatePattern.
 inline SpriteChecker::SpritePattern SpriteChecker::calculatePatternNP(
 	int patternNr, int y)
 {
-	// Note: For sprite pattern, mask and index never overlap.
-	const byte *patternPtr = vram.spritePatternTable.readArea((-1u << 11) | 0);
+	const byte* patternPtr = vram.spritePatternTable.getReadArea(0, 256 * 8);
 	int index = patternNr * 8 + y;
 	SpritePattern pattern = patternPtr[index] << 24;
 	if (vdp.getSpriteSize() == 16) {
@@ -79,6 +65,27 @@ inline SpriteChecker::SpritePattern SpriteChecker::calculatePatternNP(
 	}
 	return vdp.getSpriteMag() == 1 ? pattern : doublePattern(pattern);
 }
+inline SpriteChecker::SpritePattern SpriteChecker::calculatePatternPlanar(
+	int patternNr, int y)
+{
+	const byte* ptr0;
+	const byte* ptr1;
+	vram.spritePatternTable.getReadAreaPlanar(0, 256 * 8, ptr0, ptr1);
+	int index = patternNr * 8 + y;
+	const byte* patternPtr = (index & 1) ? ptr1 : ptr0;
+	index /= 2;
+	SpritePattern pattern = patternPtr[index] << 24;
+	if (vdp.getSpriteSize() == 16) {
+		pattern |= patternPtr[index + (16 / 2)] << 16;
+	}
+	return vdp.getSpriteMag() == 1 ? pattern : doublePattern(pattern);
+}
+inline SpriteChecker::SpritePattern SpriteChecker::calculatePattern(
+	int patternNr, int y)
+{
+	return planar ? calculatePatternPlanar(patternNr, y)
+	              : calculatePatternNP    (patternNr, y);
+}
 
 inline int SpriteChecker::checkSprites1(
 	int line, SpriteChecker::SpriteInfo *visibleSprites)
@@ -97,7 +104,7 @@ inline int SpriteChecker::checkSprites1(
 	int sprite, visibleIndex = 0;
 	int size = vdp.getSpriteSize();
 	int mag = vdp.getSpriteMag();
-	const byte *attributePtr = vram.spriteAttribTable.readArea((-1u << 7) | 0);
+	const byte* attributePtr = vram.spriteAttribTable.getReadArea(0, 32 * 4);
 	byte patternIndexMask = size == 16 ? 0xFC : 0xFF;
 	for (sprite = 0; sprite < 32; sprite++, attributePtr += 4) {
 		int y = *attributePtr;
@@ -109,8 +116,10 @@ inline int SpriteChecker::checkSprites1(
 				// Five sprites on a line.
 				// According to TMS9918.pdf 5th sprite detection is only
 				// active when F flag is zero.
-				if (~status & 0xC0) {
-					status = (status & 0xE0) | 0x40 | sprite;
+				byte status = vdp.getStatusReg0();
+				if ((status & 0xC0) == 0) {
+					vdp.setSpriteStatus(
+					     0x40 | (status & 0x20) | sprite);
 				}
 				if (limitSprites) break;
 			}
@@ -122,9 +131,10 @@ inline int SpriteChecker::checkSprites1(
 			sip->colourAttrib = attributePtr[3];
 		}
 	}
+	byte status = vdp.getStatusReg0();
 	if (~status & 0x40) {
 		// No 5th sprite detected, store number of latest sprite processed.
-		status = (status & 0xE0) | (sprite < 32 ? sprite : 31);
+		vdp.setSpriteStatus((status & 0x60) | (std::min(sprite, 31)));
 	}
 
 	// Optimisation:
@@ -132,7 +142,7 @@ inline int SpriteChecker::checkSprites1(
 	// that state is stable until it is reset by a status reg read,
 	// so no need to execute the checks.
 	// The visibleSprites array is filled now, so we can bail out.
-	if (status & 0x20) return visibleIndex;
+	if (vdp.getStatusReg0() & 0x20) return visibleIndex;
 
 	/*
 	Model for sprite collision: (or "coincidence" in TMS9918 data sheet)
@@ -163,7 +173,7 @@ inline int SpriteChecker::checkSprites1(
 				}
 				if (pattern_i & pattern_j) {
 					// Collision!
-					status |= 0x20;
+					vdp.setSpriteStatus(vdp.getStatusReg0() | 0x20);
 					// TODO: Fill in collision coordinates in S#3..S#6.
 					// ...Unless this feature only works in sprite mode 2.
 					return visibleIndex;
@@ -194,18 +204,26 @@ inline int SpriteChecker::checkSprites2(
 	int sprite, visibleIndex = 0;
 	int size = vdp.getSpriteSize();
 	int mag = vdp.getSpriteMag();
-	// TODO: Should masks be applied while processing the tables?
-	//       For attribute, no (7 bits index), for
-	// Bit9 is set for attribute table, reset for colour table.
-	const byte *attributePtr = vram.spriteAttribTable.readArea(
-		planar ? 0x0FF00 : 0x1FE00 );
-	byte patternIndexMask = size == 16 ? 0xFC : 0xFF;
-	int index1 = planar ? 0x10000 : 1;
-	int index2 = planar ? 0x00001 : 2;
-	int indexIncr = planar ? 2 : 4;
+	int patternIndexMask = (size == 16) ? 0xFC : 0xFF;
+
+	const byte* attributePtr0;
+	const byte* attributePtr1;
+	if (planar) {
+		vram.spriteAttribTable.getReadAreaPlanar(
+			512, 32 * 4, attributePtr0, attributePtr1);
+	} else {
+		attributePtr0 = attributePtr1 =
+			vram.spriteAttribTable.getReadArea(512, 32 * 4);
+	}
+	const int index0 = planar ? (0 / 2) : 0;
+	const int index1 = planar ? (1 / 2) : 1;
+	const int index2 = planar ? (2 / 2) : 2;
+	const int indexIncr = planar ? 2 : 4;
+
 	// TODO: Verify CC implementation.
-	for (sprite = 0; sprite < 32; sprite++, attributePtr += indexIncr) {
-		int y = attributePtr[0];
+	for (sprite = 0; sprite < 32; ++sprite, attributePtr0 += indexIncr,
+		                                attributePtr1 += indexIncr) {
+		int y = attributePtr0[index0];
 		if (y == 216) break;
 		// Calculate line number within the sprite.
 		int spriteLine = ((line - y) & 0xFF) / mag;
@@ -214,29 +232,33 @@ inline int SpriteChecker::checkSprites2(
 				// Nine sprites on a line.
 				// According to TMS9918.pdf 5th sprite detection is only
 				// active when F flag is zero. Stuck to this for V9938.
-				if (~status & 0xC0) {
-					status = (status & 0xE0) | 0x40 | sprite;
+				// Dragon Quest 2 needs this
+				byte status = vdp.getStatusReg0();
+				if ((status & 0xC0) == 0) {
+					vdp.setSpriteStatus(
+					     0x40 | (status & 0x20) | sprite);
 				}
 				if (limitSprites) break;
 			}
-			int colourIndex = ((-1 << 10) | (sprite * 16 + spriteLine)) & 0x1FFFF;
-			if (planar) colourIndex =
-				((colourIndex << 16) | (colourIndex >> 1)) & 0x1FFFF;
-			byte colourAttrib = vram.spriteAttribTable.readNP(colourIndex);
+			int colorIndex = (-1 << 10) | (sprite * 16 + spriteLine);
+			byte colorAttrib = planar
+				? vram.spriteAttribTable.readPlanar(colorIndex)
+				: vram.spriteAttribTable.readNP    (colorIndex);
 			// Sprites with CC=1 are only visible if preceded by
 			// a sprite with CC=0.
-			if ((colourAttrib & 0x40) && visibleIndex == 0) continue;
-			SpriteInfo *sip = &visibleSprites[visibleIndex++];
-			int patternIndex = attributePtr[index2] & patternIndexMask;
+			if ((colorAttrib & 0x40) && visibleIndex == 0) continue;
+			SpriteInfo* sip = &visibleSprites[visibleIndex++];
+			int patternIndex = attributePtr0[index2] & patternIndexMask;
 			sip->pattern = calculatePattern(patternIndex, spriteLine);
-			sip->x = attributePtr[index1];
-			if (colourAttrib & 0x80) sip->x -= 32;
-			sip->colourAttrib = colourAttrib;
+			sip->x = attributePtr1[index1];
+			if (colorAttrib & 0x80) sip->x -= 32;
+			sip->colourAttrib = colorAttrib;
 		}
 	}
+	byte status = vdp.getStatusReg0();
 	if (~status & 0x40) {
 		// No 9th sprite detected, store number of latest sprite processed.
-		status = (status & 0xE0) | (sprite < 32 ? sprite : 31);
+		vdp.setSpriteStatus((status & 0x60) | (std::min(sprite, 31)));
 	}
 
 	// Optimisation:
@@ -244,7 +266,7 @@ inline int SpriteChecker::checkSprites2(
 	// that state is stable until it is reset by a status reg read,
 	// so no need to execute the checks.
 	// The visibleSprites array is filled now, so we can bail out.
-	if (status & 0x20) return visibleIndex;
+	if (vdp.getStatusReg0() & 0x20) return visibleIndex;
 
 	/*
 	Model for sprite collision: (or "coincidence" in TMS9918 data sheet)
@@ -284,7 +306,7 @@ inline int SpriteChecker::checkSprites2(
 				}
 				if (pattern_i & pattern_j) {
 					// Collision!
-					status |= 0x20;
+					vdp.setSpriteStatus(vdp.getStatusReg0() | 0x20);
 					// TODO: Fill in collision coordinates in S#3..S#6.
 					//       See page 97 for info.
 					// TODO: I guess the VDP checks for collisions while
