@@ -1,4 +1,4 @@
-// $Id: VDP.cc 6289 2007-04-12 21:48:52Z manuelbi $
+// $Id: VDP.cc 7199 2007-10-23 18:59:10Z m9710797 $
 
 /*
 TODO:
@@ -32,6 +32,7 @@ TODO:
 #include "MSXException.hh"
 #include "MSXCliComm.hh"
 #include <sstream>
+#include <cstring>
 #include <cassert>
 
 namespace openmsx {
@@ -70,17 +71,17 @@ VDP::VDP(MSXMotherBoard& motherBoard, const XMLElement& config,
          const EmuTime& time)
 	: MSXDevice(motherBoard, config, time)
 	, Schedulable(motherBoard.getScheduler())
+	, cliComm(motherBoard.getMSXCliComm())
+	, vdpRegDebug      (new VDPRegDebug      (*this))
+	, vdpStatusRegDebug(new VDPStatusRegDebug(*this))
+	, vdpPaletteDebug  (new VDPPaletteDebug  (*this))
 	, frameStartTime(time)
 	, irqVertical(motherBoard.getCPU())
 	, irqHorizontal(motherBoard.getCPU())
 	, displayStartSyncTime(time)
 	, vScanSyncTime(time)
 	, hScanSyncTime(time)
-	, cliComm(motherBoard.getMSXCliComm())
 	, warningPrinted(false)
-	, vdpRegDebug      (new VDPRegDebug      (*this))
-	, vdpStatusRegDebug(new VDPStatusRegDebug(*this))
-	, vdpPaletteDebug  (new VDPPaletteDebug  (*this))
 {
 	interlaced = false;
 
@@ -566,17 +567,18 @@ void VDP::writeIO(word port, byte value, const EmuTime& time)
 					// it's not a register write because
 					// that breaks "SNOW26" demo
 				}
-				if (isMSX1VDP()) { 
+				if (isMSX1VDP()) {
 					// For these VDP's the VRAM pointer is modified when
 					// writing to VDP registers. Without this some demos won't
 					// run as on real MSX1, e.g. Planet of the Epas, Utopia and
-					// Waves 1.2. Thanks to dvik for finding this out. 
+					// Waves 1.2. Thanks to dvik for finding this out.
+					// See also below about not using the latch on MSX1.
 					// Set read/write address.
-					vramPointer = ((word)value << 8 | dataLatch) & 0x3FFF;
+					vramPointer = (value << 8 | (vramPointer & 0xFF)) & 0x3FFF;
 				}
 			} else {
 				// Set read/write address.
-				vramPointer = ((word)value << 8 | dataLatch) & 0x3FFF;
+				vramPointer = (value << 8 | dataLatch) & 0x3FFF;
 				if (!(value & 0x40)) {
 					// Read ahead.
 					vramRead(time);
@@ -584,6 +586,13 @@ void VDP::writeIO(word port, byte value, const EmuTime& time)
 			}
 			registerDataStored = false;
 		} else {
+			// Note: on MSX1 there seems to be no
+			// latch used, but VDP address writes
+			// are done directly.
+			// Thanks to hap for finding this out. :)
+			if (isMSX1VDP()) {
+				vramPointer = (vramPointer & 0x3F00) | value;
+			} 
 			dataLatch = value;
 			registerDataStored = true;
 		}
@@ -686,19 +695,19 @@ byte VDP::peekStatusReg(byte reg, const EmuTime& time) const
 			| cmdEngine->getStatus(time);
 	}
 	case 3:
-		return (byte)spriteChecker->getCollisionX(time);
+		return byte(spriteChecker->getCollisionX(time));
 	case 4:
-		return (byte)(spriteChecker->getCollisionX(time) >> 8) | 0xFE;
+		return byte(spriteChecker->getCollisionX(time) >> 8) | 0xFE;
 	case 5:
-		return (byte)spriteChecker->getCollisionY(time);
+		return byte(spriteChecker->getCollisionY(time));
 	case 6:
-		return (byte)(spriteChecker->getCollisionY(time) >> 8) | 0xFC;
+		return byte(spriteChecker->getCollisionY(time) >> 8) | 0xFC;
 	case 7:
 		return cmdEngine->readColour(time);
 	case 8:
-		return (byte)cmdEngine->getBorderX(time);
+		return byte(cmdEngine->getBorderX(time));
 	case 9:
-		return (byte)(cmdEngine->getBorderX(time) >> 8) | 0xFE;
+		return byte(cmdEngine->getBorderX(time) >> 8) | 0xFE;
 	default: // non-existent status register
 		return 0xFF;
 	}
@@ -938,7 +947,7 @@ void VDP::changeRegister(byte reg, byte val, const EmuTime& time)
 	case 9:
 		if ((val & 1) && ! warningPrinted) {
 			warningPrinted=true;
-			cliComm.printWarning 
+			cliComm.printWarning
 				("The running MSX software has set bit 0 of VDP register 9 "
 				 "(dot clock direction) to one. In an ordinary MSX, "
 				 "the screen would go black and the CPU would stop running.");
