@@ -1,4 +1,4 @@
-// $Id: VDPCmdEngine.cc 5972 2006-12-29 18:46:11Z m9710797 $
+// $Id: VDPCmdEngine.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 /*
 TODO:
@@ -344,14 +344,14 @@ void VDPCmdEngine::createEngines(unsigned cmd) {
 
 VDPCmdEngine::VDPCmdEngine(VDP& vdp_, RenderSettings& renderSettings_,
 	CommandController& commandController)
-	: clock(EmuTime::zero)
-	, vdp(vdp_), vram(vdp.getVRAM())
+	: vdp(vdp_), vram(vdp.getVRAM())
 	, renderSettings(renderSettings_)
-	, hasExtendedVRAM(vram.getSize() == (192 * 1024))
-	, statusChangeTime(EmuTime::infinity)
 	, cmdTraceSetting(new BooleanSetting(
 		commandController, "vdpcmdtrace",
 		"VDP command tracing on/off", false))
+	, clock(EmuTime::zero)
+	, statusChangeTime(EmuTime::infinity)
+	, hasExtendedVRAM(vram.getSize() == (192 * 1024))
 {
 	status = 0;
 	transfer = false;
@@ -588,10 +588,10 @@ void VDPCmdEngine::reportVdpCommand()
 	};
 
 	std::cerr << "VDPCmd " << COMMANDS[CMD] << '-' << OPS[LOG]
-		<<  '(' << (int)SX << ',' << (int)SY << ")->("
-		        << (int)DX << ',' << (int)DY << ")," << (int)COL
-		<< " [" << (int)((ARG & DIX) ? -NX : NX)
-		<<  ',' << (int)((ARG & DIY) ? -NY : NY) << ']' << std::endl;
+		<<  '(' << int(SX) << ',' << int(SY) << ")->("
+		        << int(DX) << ',' << int(DY) << ")," << int(COL)
+		<< " [" << int((ARG & DIX) ? -NX : NX)
+		<<  ',' << int((ARG & DIY) ? -NY : NY) << ']' << std::endl;
 }
 
 void VDPCmdEngine::commandDone(const EmuTime& time)
