@@ -1,4 +1,4 @@
-// $Id: VideoLayer.cc 5300 2006-04-05 08:13:25Z m9710797 $
+// $Id: VideoLayer.cc 6807 2007-08-06 17:08:53Z m9710797 $
 
 #include "VideoLayer.hh"
 #include "RenderSettings.hh"
@@ -14,12 +14,13 @@ namespace openmsx {
 VideoLayer::VideoLayer(VideoSource videoSource_,
                        CommandController& commandController,
                        Display& display_)
-	: videoSource(videoSource_)
-	, display(display_)
+	: display(display_)
 	, renderSettings(display.getRenderSettings())
 	, videoSourceSetting(renderSettings.getVideoSource())
-	, videoSourceActivator(videoSourceSetting, videoSource)
+	, videoSourceActivator(new VideoSourceActivator(
+              videoSourceSetting, videoSource_))
 	, powerSetting(commandController.getGlobalSettings().getPowerSetting())
+	, videoSource(videoSource_)
 {
 	setCoverage(getCoverage());
 	setZ(calcZ());
