@@ -1,4 +1,4 @@
-// $Id: VideoSourceSetting.cc,v 1.2 2005/09/03 21:28:16 m9710797 Exp $
+// $Id: VideoSourceSetting.cc 5618 2006-09-10 12:42:47Z manuelbi $
 
 #include "VideoSourceSetting.hh"
 
@@ -45,7 +45,7 @@ const char* const VIDEOSOURCE = "videosource";
 VideoSourceSetting::VideoSourceSetting(CommandController& commandController)
 	: SettingImpl<VideoSourceSettingPolicy>(commandController,
 		VIDEOSOURCE, "selects the video source to display on the screen",
-		VIDEO_MSX, Setting::SAVE, VIDEOSOURCE, getVideoSourceMap())
+		VIDEO_MSX, Setting::DONT_SAVE, VIDEOSOURCE, getVideoSourceMap())
 {
 }
 
