@@ -1,4 +1,4 @@
-// $Id: VisibleSurface.cc 5053 2006-01-19 18:39:49Z mthuurne $
+// $Id: VisibleSurface.cc 6795 2007-08-04 13:35:50Z m9710797 $
 
 #include "VisibleSurface.hh"
 #include "InitException.hh"
@@ -67,8 +67,10 @@ void VisibleSurface::createSurface(unsigned width, unsigned height, int flags)
 	RECT windowRect;
 	GetWindowRect(handle, &windowRect);
 	// ...and adjust if needed
+	// HWND_TOP is #defined as ((HWND)0)
+	HWND OPENMSX_HWND_TOP = static_cast<HWND>(0);
 	if ((windowRect.right < 0) || (windowRect.bottom < 0)) {
-		SetWindowPos(handle, HWND_TOP, lastWindowX, lastWindowY,
+		SetWindowPos(handle, OPENMSX_HWND_TOP, lastWindowX, lastWindowY,
 		             0, 0, SWP_NOSIZE);
 	}
 #endif
