@@ -1,4 +1,4 @@
-// $Id: V9990CmdEngine.cc 5847 2006-11-04 20:50:36Z m9710797 $
+// $Id: V9990CmdEngine.cc 7040 2007-09-18 15:30:36Z m9710797 $
 
 #include "V9990CmdEngine.hh"
 #include "V9990.hh"
@@ -202,6 +202,11 @@ inline byte V9990CmdEngine::V9990P1::shift(
 	return (shift > 0) ? (value >> shift) : (value << -shift);
 }
 
+inline byte V9990CmdEngine::V9990P1::shiftMask(unsigned x)
+{
+	return (x & 1) ? 0x0F : 0xF0;
+}
+
 inline const byte* V9990CmdEngine::V9990P1::getLogOpLUT(byte op)
 {
 	return &logOpLUT[(op & 0x10) ? LOG_BPP4 : LOG_NO_T][op & 0xF][0][0];
@@ -221,7 +226,7 @@ inline void V9990CmdEngine::V9990P1::pset(
 	byte dstColor = vram.readVRAMDirect(addr);
 	byte newColor = logOp(lut, srcColor, dstColor);
 	byte mask1 = (addr & 0x40000) ? (mask >> 8) : (mask & 0xFF);
-	byte mask2 = mask1 & (0xF0 >> (4 * (x & 1)));
+	byte mask2 = mask1 & shiftMask(x);
 	byte result = (dstColor & ~mask2) | (newColor & mask2);
 	vram.writeVRAMDirect(addr, result);
 }
@@ -265,6 +270,11 @@ inline byte V9990CmdEngine::V9990P2::shift(
 	return (shift > 0) ? (value >> shift) : (value << -shift);
 }
 
+inline byte V9990CmdEngine::V9990P2::shiftMask(unsigned x)
+{
+	return (x & 1) ? 0x0F : 0xF0;
+}
+
 inline const byte* V9990CmdEngine::V9990P2::getLogOpLUT(byte op)
 {
 	return &logOpLUT[(op & 0x10) ? LOG_BPP4 : LOG_NO_T][op & 0xF][0][0];
@@ -284,7 +294,7 @@ inline void V9990CmdEngine::V9990P2::pset(
 	byte dstColor = vram.readVRAMDirect(addr);
 	byte newColor = logOp(lut, srcColor, dstColor);
 	byte mask1 = (addr & 0x40000) ? (mask >> 8) : (mask & 0xFF);
-	byte mask2 = mask1 & (0xF0 >> (4 * (x & 1)));
+	byte mask2 = mask1 & shiftMask(x);
 	byte result = (dstColor & ~mask2) | (newColor & mask2);
 	vram.writeVRAMDirect(addr, result);
 }
@@ -328,6 +338,11 @@ inline byte V9990CmdEngine::V9990Bpp2::shift(
 	return (shift > 0) ? (value >> shift) : (value << -shift);
 }
 
+inline byte V9990CmdEngine::V9990Bpp2::shiftMask(unsigned x)
+{
+	return 0xC0 >> (2 * (x & 3));
+}
+
 inline const byte* V9990CmdEngine::V9990Bpp2::getLogOpLUT(byte op)
 {
 	return &logOpLUT[(op & 0x10) ? LOG_BPP2 : LOG_NO_T][op & 0xF][0][0];
@@ -347,7 +362,7 @@ inline void V9990CmdEngine::V9990Bpp2::pset(
 	byte dstColor = vram.readVRAMDirect(addr);
 	byte newColor = logOp(lut, srcColor, dstColor);
 	byte mask1 = (addr & 0x40000) ? (mask >> 8) : (mask & 0xFF);
-	byte mask2 = mask1 & (0xC0 >> (2 * (x & 3)));
+	byte mask2 = mask1 & shiftMask(x);
 	byte result = (dstColor & ~mask2) | (newColor & mask2);
 	vram.writeVRAMDirect(addr, result);
 }
@@ -391,6 +406,11 @@ inline byte V9990CmdEngine::V9990Bpp4::shift(
 	return (shift > 0) ? (value >> shift) : (value << -shift);
 }
 
+inline byte V9990CmdEngine::V9990Bpp4::shiftMask(unsigned x)
+{
+	return (x & 1) ? 0x0F : 0xF0;
+}
+
 inline const byte* V9990CmdEngine::V9990Bpp4::getLogOpLUT(byte op)
 {
 	return &logOpLUT[(op & 0x10) ? LOG_BPP4 : LOG_NO_T][op & 0xF][0][0];
@@ -410,7 +430,7 @@ inline void V9990CmdEngine::V9990Bpp4::pset(
 	byte dstColor = vram.readVRAMDirect(addr);
 	byte newColor = logOp(lut, srcColor, dstColor);
 	byte mask1 = (addr & 0x40000) ? (mask >> 8) : (mask & 0xFF);
-	byte mask2 = mask1 & (0xF0 >> (4 * (x & 1)));
+	byte mask2 = mask1 & shiftMask(x);
 	byte result = (dstColor & ~mask2) | (newColor & mask2);
 	vram.writeVRAMDirect(addr, result);
 }
@@ -453,6 +473,11 @@ inline byte V9990CmdEngine::V9990Bpp8::shift(
 	return value;
 }
 
+inline byte V9990CmdEngine::V9990Bpp8::shiftMask(unsigned /*x*/)
+{
+	return 0xFF;
+}
+
 inline const byte* V9990CmdEngine::V9990Bpp8::getLogOpLUT(byte op)
 {
 	return &logOpLUT[(op & 0x10) ? LOG_BPP8 : LOG_NO_T][op & 0xF][0][0];
@@ -517,6 +542,11 @@ inline word V9990CmdEngine::V9990Bpp16::shift(
 	return value;
 }
 
+inline word V9990CmdEngine::V9990Bpp16::shiftMask(unsigned /*x*/)
+{
+	return 0xFFFF;
+}
+
 inline const byte* V9990CmdEngine::V9990Bpp16::getLogOpLUT(byte op)
 {
 	return &logOpLUT[LOG_NO_T][op & 0xF][0][0];
@@ -561,7 +591,7 @@ inline void V9990CmdEngine::V9990Bpp16::psetColor(
   */
 V9990CmdEngine::V9990CmdEngine(V9990& vdp_, const EmuTime& time,
                                RenderSettings& settings_)
-	: vdp(vdp_), settings(settings_)
+	: settings(settings_), vdp(vdp_)
 {
 	MSXMotherBoard::SharedStuff& info =
 		vdp.getMotherBoard().getSharedStuff("v9990cmdtrace");
@@ -644,6 +674,7 @@ void V9990CmdEngine::reset(const EmuTime& /*time*/)
 	currentCommand = NULL;
 	status = 0;
 	borderX = 0;
+	endAfterRead = false;
 }
 
 void V9990CmdEngine::setCmdReg(byte reg, byte value, const EmuTime& time)
@@ -778,12 +809,12 @@ void V9990CmdEngine::reportV9990Command()
 	          << " DY="  << std::dec << DY
 	          << " NX="  << std::dec << NX
 	          << " NY="  << std::dec << NY
-	          << " ARG=" << std::hex << (int)ARG
-	          << " LOG=" << std::hex << (int)LOG
+	          << " ARG=" << std::hex << int(ARG)
+	          << " LOG=" << std::hex << int(LOG)
 	          << " WM="  << std::hex << WM
 	          << " FC="  << std::hex << fgCol
 	          << " BC="  << std::hex << bgCol
-	          << " CMD=" << std::hex << (int)CMD
+	          << " CMD=" << std::hex << int(CMD)
 	          << std::endl;
 }
 
@@ -847,15 +878,15 @@ void V9990CmdEngine::CmdLMMC<Mode>::start(const EmuTime& /*time*/)
 	}
 	engine.ANX = engine.NX;
 	engine.ANY = engine.NY;
-	engine.status &= ~TR;
+	engine.status |= TR;
 }
 
 template <>
 void V9990CmdEngine::CmdLMMC<V9990CmdEngine::V9990Bpp16>::execute(
 	const EmuTime& time)
 {
-	if (engine.status & TR) {
-		engine.status &= ~TR;
+	if (!(engine.status & TR)) {
+		engine.status |= TR;
 		if (engine.bitsLeft) {
 			engine.bitsLeft = 0;
 			engine.partial = engine.data;
@@ -885,13 +916,14 @@ void V9990CmdEngine::CmdLMMC<V9990CmdEngine::V9990Bpp16>::execute(
 template <class Mode>
 void V9990CmdEngine::CmdLMMC<Mode>::execute(const EmuTime& time)
 {
-	if (engine.status & TR) {
-		engine.status &= ~TR;
+	if (!(engine.status & TR)) {
+		engine.status |= TR;
 		unsigned pitch = Mode::getPitch(engine.vdp.getImageWidth());
 		const byte* lut = Mode::getLogOpLUT(engine.LOG);
 		for (int i = 0; (engine.ANY > 0) && (i < Mode::PIXELS_PER_BYTE); ++i) {
+			byte data = Mode::shift(engine.data, i, engine.DX);
 			Mode::pset(vram, engine.DX, engine.DY, pitch,
-			           engine.data, engine.WM, lut, engine.LOG);
+			           data, engine.WM, lut, engine.LOG);
 
 			int dx = (engine.ARG & DIX) ? -1 : 1;
 			engine.DX += dx;
@@ -967,15 +999,54 @@ V9990CmdEngine::CmdLMCM<Mode>::CmdLMCM(V9990CmdEngine& engine,
 }
 
 template <class Mode>
-void V9990CmdEngine::CmdLMCM<Mode>::start(const EmuTime& time)
+void V9990CmdEngine::CmdLMCM<Mode>::start(const EmuTime& /*time*/)
 {
-	std::cout << "V9990: LMCM not yet implemented" << std::endl;
-	engine.cmdReady(time); // TODO dummy implementation
+	if (Mode::BITS_PER_PIXEL == 16) {
+		engine.bitsLeft = 0;
+	}
+	engine.ANX = engine.NX;
+	engine.ANY = engine.NY;
+	engine.status &= ~TR;
+	engine.endAfterRead = false;
 }
 
 template <class Mode>
 void V9990CmdEngine::CmdLMCM<Mode>::execute(const EmuTime& /*time*/)
 {
+	if (!(engine.status & TR)) {
+		engine.status |= TR;
+		if ((Mode::BITS_PER_PIXEL == 16) && engine.bitsLeft) {
+			engine.bitsLeft = 0;
+			engine.data = engine.partial;
+			return;
+		}
+		unsigned pitch = Mode::getPitch(engine.vdp.getImageWidth());
+		typename Mode::Type data = 0;
+		for (int i = 0; (engine.ANY > 0) && (i < Mode::PIXELS_PER_BYTE); ++i) {
+			typename Mode::Type src = Mode::point(vram, engine.SX, engine.SY, pitch);
+			data |= Mode::shift(src, engine.SX, i) & Mode::shiftMask(i);
+
+			int dx = (engine.ARG & DIX) ? -1 : 1;
+			engine.SX += dx;
+			if (!--(engine.ANX)) {
+				int dy = (engine.ARG & DIY) ? -1 : 1;
+				engine.SX -= (engine.NX * dx);
+				engine.SY += dy;
+				if (!--(engine.ANY)) {
+					engine.endAfterRead = true;
+				} else {
+					engine.ANX = engine.NX;
+				}
+			}
+		}
+		if (Mode::BITS_PER_PIXEL == 16) {
+			engine.data = data & 0xff;
+			engine.partial = data >> 8;
+			engine.bitsLeft = 1;
+		} else {
+			engine.data = data;
+		}
+	}
 }
 
 // ====================================================================
@@ -1045,14 +1116,14 @@ void V9990CmdEngine::CmdCMMC<Mode>::start(const EmuTime& /*time*/)
 {
 	engine.ANX = engine.NX;
 	engine.ANY = engine.NY;
-	engine.status &= ~TR;
+	engine.status |= TR;
 }
 
 template <class Mode>
 void V9990CmdEngine::CmdCMMC<Mode>::execute(const EmuTime& time)
 {
-	if (engine.status & TR) {
-		engine.status &= ~TR;
+	if (!(engine.status & TR)) {
+		engine.status |= TR;
 
 		unsigned pitch = Mode::getPitch(engine.vdp.getImageWidth());
 		int dx = (engine.ARG & DIX) ? -1 : 1;
@@ -1481,7 +1552,7 @@ void V9990CmdEngine::CmdSRCH<Mode>::execute(const EmuTime& time)
 	typename Mode::Type mask = (1 << Mode::BITS_PER_PIXEL) -1;
 
 	int TX = (engine.ARG & DIX) ? -1 : 1;
-	bool AEQ = engine.ARG & NEQ; 
+	bool AEQ = engine.ARG & NEQ;
 
 	while (clock.before(time)) {
 		clock += delta;
@@ -1491,7 +1562,7 @@ void V9990CmdEngine::CmdSRCH<Mode>::execute(const EmuTime& time)
 		if (Mode::BITS_PER_PIXEL == 16) {
 			value = Mode::point(vram, engine.ASX, engine.SY, pitch);
 			col = engine.fgCol;
-			mask2 = (typename Mode::Type)0xFFFF; // cast to avoid warning
+			mask2 = static_cast<typename Mode::Type>(0xFFFF); // cast to avoid warning
 		} else {
 			// TODO check
 			unsigned addr = Mode::addressOf(engine.ASX, engine.SY, pitch);
@@ -1593,7 +1664,7 @@ void V9990CmdEngine::setCmdData(byte value, const EmuTime& time)
 {
 	sync(time);
 	data = value;
-	status |= TR;
+	status &= ~TR;
 }
 
 byte V9990CmdEngine::getCmdData(const EmuTime& time)
@@ -1604,6 +1675,10 @@ byte V9990CmdEngine::getCmdData(const EmuTime& time)
 	if (status & TR) {
 		value = data;
 		status &= ~TR;
+		if (endAfterRead) {
+			endAfterRead = false;
+			cmdReady(time);
+		}
 	}
 	return value;
 }
@@ -1611,7 +1686,7 @@ byte V9990CmdEngine::getCmdData(const EmuTime& time)
 void V9990CmdEngine::cmdReady(const EmuTime& /*time*/)
 {
 	currentCommand = NULL;
-	status &= ~CE;
+	status &= ~(CE | TR);
 	vdp.cmdReady();
 }
 
