@@ -1,4 +1,4 @@
-// $Id: V9990DummyRasterizer.cc,v 1.10 2005/11/14 21:18:06 m9710797 Exp $
+// $Id: V9990DummyRasterizer.cc 5984 2007-01-08 22:03:21Z m9710797 $
 
 #include "V9990DummyRasterizer.hh"
 
@@ -17,7 +17,7 @@ void V9990DummyRasterizer::frameStart()
 {
 }
 
-void V9990DummyRasterizer::frameEnd()
+void V9990DummyRasterizer::frameEnd(const EmuTime& /*time*/)
 {
 }
 
@@ -45,4 +45,9 @@ void V9990DummyRasterizer::drawDisplay(int /*fromX*/, int /*fromY*/,
 {
 }
 
+bool V9990DummyRasterizer::isRecording() const
+{
+	return false;
+}
+
 } // namespace openmsx
