@@ -1,4 +1,4 @@
-// $Id: V9990GLRasterizer.cc,v 1.12 2005/11/14 21:18:06 m9710797 Exp $
+// $Id: V9990GLRasterizer.cc 5984 2007-01-08 22:03:21Z m9710797 $
 
 #include "V9990GLRasterizer.hh"
 #include "V9990.hh"
@@ -29,7 +29,7 @@ void V9990GLRasterizer::frameStart()
 {
 }
 
-void V9990GLRasterizer::frameEnd()
+void V9990GLRasterizer::frameEnd(const EmuTime& /*time*/)
 {
 }
 
@@ -55,6 +55,11 @@ void V9990GLRasterizer::drawDisplay(
 {
 }
 
+bool V9990GLRasterizer::isRecording() const
+{
+	return false;
+}
+
 } // namespace openmsx
 
 
