@@ -1,4 +1,4 @@
-// $Id: V9990P1Converter.cc 5944 2006-12-18 20:53:12Z m9710797 $
+// $Id: V9990P1Converter.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "V9990P1Converter.hh"
 #include "V9990.hh"
@@ -94,7 +94,7 @@ void V9990P1Converter<Pixel>::renderPattern2(
 {
 	x &= 511;
 	Pixel* palette = palette64 + pal;
-	
+
 	unsigned nameAddr = nameTable + (((y / 8) * 64 + (x / 8)) * 2);
 	y = (y & 7) * 128;
 
@@ -175,7 +175,7 @@ void V9990P1Converter<Pixel>::renderPattern2(
 			}
 			width -= 2;
 			buffer += 2;
-		} while ((int)width > 0);
+		} while (int(width) > 0);
 	}
 }
 
