@@ -1,4 +1,4 @@
-// $Id: V9990P2Converter.cc 6096 2007-02-19 10:06:26Z m9710797 $
+// $Id: V9990P2Converter.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "V9990P2Converter.hh"
 #include "V9990VRAM.hh"
@@ -61,7 +61,7 @@ void V9990P2Converter<Pixel>::renderPattern(
 
 	x &= 1023;
 	Pixel* palette = palette64 + pal;
-	
+
 	unsigned nameAddr = nameTable + (((y / 8) * 128 + (x / 8)) * 2);
 	y = (y & 7) * 256;
 
@@ -142,7 +142,7 @@ void V9990P2Converter<Pixel>::renderPattern(
 			}
 			width -= 2;
 			buffer += 2;
-		} while ((int)width > 0);
+		} while (int(width) > 0);
 	}
 }
 
