@@ -1,4 +1,4 @@
-// $Id: V9990PixelRenderer.cc 5984 2007-01-08 22:03:21Z m9710797 $
+// $Id: V9990PixelRenderer.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "V9990PixelRenderer.hh"
 #include "V9990.hh"
@@ -80,7 +80,7 @@ void V9990PixelRenderer::frameStart(const EmuTime& time)
 				drawFrame = true;
 			} else {
 				drawFrame = realTime.timeLeft(
-					(unsigned)finishFrameDuration, time);
+					unsigned(finishFrameDuration), time);
 			}
 			if (drawFrame) {
 				frameSkipCounter = 0;
