@@ -1,4 +1,4 @@
-// $Id: V9990SDLRasterizer.cc 6131 2007-03-02 12:00:24Z m9710797 $
+// $Id: V9990SDLRasterizer.cc 6786 2007-08-04 10:29:59Z m9710797 $
 
 #include "V9990SDLRasterizer.hh"
 #include "V9990.hh"
@@ -144,7 +144,8 @@ void V9990SDLRasterizer<Pixel>::drawBorder(
 	unsigned lineWidth = vdp.getLineWidth();
 	MemoryOps::MemSet<Pixel, MemoryOps::NO_STREAMING> memset;
 	for (int y = startY; y < endY; ++y) {
-		memset(workFrame->getLinePtr(y, (Pixel*)0) + startX,
+		Pixel* dummy = 0;
+		memset(workFrame->getLinePtr(y, dummy) + startX,
 		       endX - startX, bgColor);
 		workFrame->setLineWidth(y, lineWidth);
 	}
@@ -206,7 +207,8 @@ void V9990SDLRasterizer<Pixel>::drawP1Mode(
 	int displayWidth, int displayHeight)
 {
 	while (displayHeight--) {
-		Pixel* pixelPtr = workFrame->getLinePtr(fromY, (Pixel*)0) + fromX;
+		Pixel* dummy = 0;
+		Pixel* pixelPtr = workFrame->getLinePtr(fromY, dummy) + fromX;
 		p1Converter->convertLine(pixelPtr, displayX, displayWidth,
 		                         displayY);
 		workFrame->setLineWidth(fromY, 320);
@@ -221,7 +223,8 @@ void V9990SDLRasterizer<Pixel>::drawP2Mode(
 	int displayWidth, int displayHeight)
 {
 	while (displayHeight--) {
-		Pixel* pixelPtr = workFrame->getLinePtr(fromY, (Pixel*)0) + fromX;
+		Pixel* dummy = 0;
+		Pixel* pixelPtr = workFrame->getLinePtr(fromY, dummy) + fromX;
 		p2Converter->convertLine(pixelPtr, displayX, displayWidth,
 		                         displayY);
 		workFrame->setLineWidth(fromY, 640);
@@ -252,7 +255,8 @@ void V9990SDLRasterizer<Pixel>::drawBxMode(
 	while (displayHeight--) {
 		unsigned y = scrollYBase + ((displayY + scrollY) & rollMask);
 		unsigned address = vdp.XYtoVRAM(&x, y, colorMode);
-		Pixel* pixelPtr = workFrame->getLinePtr(fromY, (Pixel*)0) + fromX;
+		Pixel* dummy = 0;
+		Pixel* pixelPtr = workFrame->getLinePtr(fromY, dummy) + fromX;
 		bitmapConverter->convertLine(pixelPtr, address, displayWidth,
 		                             displayY);
 		workFrame->setLineWidth(fromY, vdp.getLineWidth());
@@ -292,7 +296,7 @@ void V9990SDLRasterizer<Pixel>::preCalcPalettes()
 			}
 		}
 	}
-	
+
 	resetPalette();
 }
 
